OC.L10N.register(
    "calendar",
    {
    "Calendar" : "ປະຕິທິນ",
    "Confirm" : "ຢືນຢັນ",
    "Today" : "ມື້ນີ້",
    "Copy link" : "ສຳເນົາລິງ",
    "Edit" : "ແກ້ໄຂ",
    "Delete" : "ລຶບ",
    "Create new" : "ສ້າງໃຫມ່",
    "Shared with you by" : "ແບ່ງປັນໂດຍທ່ານ",
    "Name" : "ຊື່",
    "Deleted" : "ລືບ",
    "Restore" : "ການກຸ້ຄຶນ",
    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
    "Share link" : "ແບ່ງປັນລິງ",
    "Delete share link" : "ລົບລິງແບ່ງປັນ",
    "Save" : "ບັນທຶກ",
    "Filename" : "ຊື່ຟາຍ",
    "Cancel" : "ຍົກເລີກ",
    "List view" : "ລາຍການທີ່ຈະເບິ່ງ",
    "Duration" : "ໄລຍະ",
    "Add" : "ເພີ່ມ",
    "Notification" : "ແຈ້ງການ",
    "Email" : "ອິເມວ",
    "Delete file" : "ລຶບຟາຍ",
    "Available" : "ມີຢູ່",
    "Not available" : "ບໍ່ມີ",
    "Unknown" : "ບໍ່ຮູ້",
    "never" : "ບໍ່ເຄີຍ",
    "Personal" : "ສ່ວນບຸກຄົນ",
    "Details" : "ລາຍລະອຽດ",
    "Close" : "ປິດ",
    "Daily" : "ລາຍວັນ",
    "Weekly" : "ອາທິດ"
},
"nplurals=1; plural=0;");
