OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "O endereço de e-mail fornecido é muito longo",
    "User-Session unexpectedly expired" : "Sessão do usuário expirou inesperadamente",
    "Provided email-address is not valid" : "O e-mail fornecido não é válido",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Erro inesperado ao enviar e-mail. Entre em contato com o administrador.",
    "Successfully sent email to %1$s" : "E-mail enviado com sucesso para %1$s",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Informamos que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Saudações!",
    "Upcoming events" : "Próximos eventos",
    "No more events today" : "Sem mais eventos para hoje",
    "No upcoming events" : "Nenhum evento próximo",
    "More events" : "Mais eventos",
    "%1$s with %2$s" : "%1$s com %2$s",
    "Calendar" : "Calendário",
    "New booking {booking}" : "Novo agendamento {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) criou um agendamento \"{config_display_name}\" em {date_time}.",
    "Appointments" : "Agendamentos",
    "Schedule appointment \"%s\"" : "Reservar agendamento \"%s\"",
    "Schedule an appointment" : "Reserve um agendamento",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Prepare para %s",
    "Follow up for %s" : "Acompanhamento para %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Seu agendamento \"%s\" com %s precisa de confirmação",
    "Dear %s, please confirm your booking" : "Caro %s, por favor confirme a sua reserva",
    "Confirm" : "Confirmar",
    "Appointment with:" : "Agendar com:",
    "Description:" : "Descrição:",
    "This confirmation link expires in %s hours." : "Este link de confirmação expira em %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Caso deseje cancelar o agendamento, por favor, entre em contato com o organizador respondendo este e-mail ou visitando sua página de perfil.",
    "Your appointment \"%s\" with %s has been accepted" : "Seu agendamento \"%s\" com %s foi aceito",
    "Dear %s, your booking has been accepted." : "Olá %s. Seu convite foi aceito.",
    "Appointment for:" : "Agendamento para:",
    "Date:" : "Data:",
    "You will receive a link with the confirmation email" : "Você receberá um link com o e-mail de confirmação",
    "Where:" : "Local:",
    "Comment:" : "Comentário:",
    "You have a new appointment booking \"%s\" from %s" : "Tem uma nova reserva \"%s\" de %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Caro %s, %s(%s) reservou um horário com você.",
    "A Calendar app for Nextcloud" : "Um aplicativo de Calendário para Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "O aplicativo Calendário é uma interface de usuário para o servidor CalDAV do Nextcloud. Sincronize facilmente eventos de vários dispositivos com o Nextcloud e edite-os online.\n\n* 🚀 **Integração com outros aplicativos Nextcloud!** Atualmente Contatos - mais por vir.\n* 🌐 **Suporte WebCal!** Deseja ver as partidas do seu time no calendário? Sem problemas!\n* 🙋 **Participantes!** Convide pessoas para seus eventos\n* ⌚️ **Disponibilidade:** Veja quando seus participantes estarão disponíveis para atender\n* ⏰ **Lembretes!** Receba alarmes para eventos no seu navegador e via e-mail.\n* 🔍 Pesquise! Encontre seus eventos facilmente\n* ☑️ Tarefas! Veja as tarefas com a data de entrega diretamente no calendário\n* 🙈 **Não estamos reinventando a roda!** Baseado nas excelentes bibliotecas [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) e [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Dia anterior",
    "Previous week" : "Semana anterior",
    "Previous year" : "Ano anterior",
    "Previous month" : "Mês anterior",
    "Next day" : "Próximo dia",
    "Next week" : "Próxima semana",
    "Next year" : "Próximo ano",
    "Next month" : "Próximo mês",
    "Event" : "Evento",
    "Create new event" : "Criar novo evento",
    "Today" : "Hoje",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Year" : "Ano",
    "List" : "Lista",
    "Preview" : "Previsão",
    "Copy link" : "Copiar o link",
    "Edit" : "Editar",
    "Delete" : "Excluir",
    "Appointment link was copied to clipboard" : "O link do agendamento foi copiado para a área de transferência",
    "Appointment link could not be copied to clipboard" : "Não foi possível copiar o link do agendamento para a área de transferência",
    "Appointment schedules" : "Agendamentos de compromissos",
    "Create new" : "Criar novo",
    "Untitled calendar" : "Calendário sem título",
    "Shared with you by" : "Compartilhado com você por",
    "Edit and share calendar" : "Editar e compartilhar calendário",
    "Edit calendar" : "Editar calendário",
    "Disable calendar \"{calendar}\"" : "Desativar calendário \"{calendar}\"",
    "Disable untitled calendar" : "Desativar calendário sem título",
    "Enable calendar \"{calendar}\"" : "Ativar calendário \"{calendar}\"",
    "Enable untitled calendar" : "Ativar calendário sem título",
    "An error occurred, unable to change visibility of the calendar." : "Erro ao alterar a visibilidade do calendário.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Descompartilhando o calendário em {countdown} segundo","Descompartilhando o calendário em {countdown} segundos","Descompartilhando o calendário em {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Excluindo o calendário em {countdown} segundo","Excluindo o calendário em {countdown} segundos","Excluindo o calendário em {countdown} segundos"],
    "Calendars" : "Calendários ",
    "Add new" : "Adicionar novo",
    "New calendar" : "Novo calendário",
    "Name for new calendar" : "Nome para o calendário",
    "Creating calendar …" : "Criando calendário...",
    "New calendar with task list" : "Novo calendário com lista de tarefas",
    "New subscription from link (read-only)" : "Nova subscrição do link (somente leitura)",
    "Creating subscription …" : "Criando assinatura...",
    "Add public holiday calendar" : "Adicionar calendário de feriados",
    "Add custom public calendar" : "Adicione um calendário público personalizado",
    "An error occurred, unable to create the calendar." : "Erro ao criar o calendário.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Digite um link válido (começando com http://, https://, webcal://, ou webcals://)",
    "Copy subscription link" : "Copiar link de inscrição",
    "Copying link …" : "Copiando link...",
    "Copied link" : "Link copiado",
    "Could not copy link" : "Não foi possível copiar o link",
    "Export" : "Exportar",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Não foi possível copiar o link da agenda para a área de transferência.",
    "Trash bin" : "Lixeira",
    "Loading deleted items." : "Carregando itens excluídos.",
    "You do not have any deleted items." : "Você não possui itens excluídos.",
    "Name" : "Nome",
    "Deleted" : "Excluído",
    "Restore" : "Restaurar",
    "Delete permanently" : "Excluir permanentemente",
    "Empty trash bin" : "Esvaziar lixeira",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos excluídos",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento",
    "Do you really want to empty the trash bin?" : "Tem certeza de que deseja esvaziar a lixeira?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Os itens na lixeira são excluídos após {numDays} dias","Os itens na lixeira são excluídos após {numDays} dias","Os itens na lixeira são excluídos após {numDays} dias"],
    "Shared calendars" : "Calendários compartilhados",
    "Deck" : "Deck",
    "Hidden" : "Oculto",
    "Could not update calendar order." : "Não foi possível atualizar o pedido da agenda.",
    "Internal link" : "Link interno",
    "A private link that can be used with external clients" : "Um link privado que pode ser usado com clientes externos",
    "Copy internal link" : "Copiar link interno",
    "Share link" : "Compartilhar link",
    "Copy public link" : "Copiar link público",
    "Send link to calendar via email" : "Enviar link para o calendário via e-mail",
    "Enter one address" : "Digite um endereço",
    "Sending email …" : "Enviando e-mail...",
    "Copy embedding code" : "Copiar código de incorporação",
    "Copying code …" : "Copiando código...",
    "Copied code" : "Código copiado",
    "Could not copy code" : "Não foi possível copiar o código",
    "Delete share link" : "Excluir compartilhamento do link",
    "Deleting share link …" : "Excluindo link de compartilhamento...",
    "An error occurred, unable to publish calendar." : "Erro ao publicar calendário.",
    "An error occurred, unable to send email." : "Erro ao tentar enviar o e-mail.",
    "Embed code copied to clipboard." : "Código de incorporação copiado para a área de transferência.",
    "Embed code could not be copied to clipboard." : "O código de incorporação não pôde ser copiado para a área de transferência.",
    "Unpublishing calendar failed" : "Erro ao remover a publicação do calendário",
    "can edit" : "pode editar",
    "Unshare with {displayName}" : "Descompartilhar com {displayName}",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipe)",
    "An error occurred while unsharing the calendar." : "Ocorreu um erro ao cancelar o compartilhamento do calendário.",
    "An error occurred, unable to change the permission of the share." : "Erro ao alterar a permissão do compartilhamento.",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "No users or groups" : "Nenhum usuário ou grupo",
    "Calendar name …" : "Nome do calendário…",
    "Never show me as busy (set this calendar to transparent)" : "Nunca me mostre ocupado (defina este calendário como transparente)",
    "Share calendar" : "Compartilhar calendário",
    "Unshare from me" : "Descompartilhar comigo",
    "Save" : "Salvar",
    "Failed to save calendar name and color" : "Falha ao salvar o nome e a cor do calendário",
    "Import calendars" : "Importar calendários",
    "Please select a calendar to import into …" : "Selecione o calendário para onde importar...",
    "Filename" : "Nome de arquivo",
    "Calendar to import into" : "Calendário a importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendário","Importar calendários","Importar calendários"],
    "Default attachments location" : "Default attachments location",
    "Select the default location for attachments" : "Select the default location for attachments",
    "Pick" : "Pick",
    "Invalid location selected" : "Invalidar localização selecionada",
    "Attachments folder successfully saved." : "Attachments folder successfully saved.",
    "Error on saving attachments folder." : "Error on saving attachments folder.",
    "{filename} could not be parsed" : "{filename} não pôde ser analisado",
    "No valid files found, aborting import" : "Nenhum arquivo válido encontrado, importação interrompida",
    "Import partially failed. Imported {accepted} out of {total}." : "Erro na importação. Importado {accepted} de {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Importado com sucesso %n evento","Importados com sucesso %n eventos","Importados com sucesso %n eventos"],
    "Automatic" : "Automático",
    "Automatic ({detected})" : "Automático ({detected})",
    "New setting was not saved successfully." : "A nova configuração não foi salva.",
    "Shortcut overview" : "Visão geral de atalhos",
    "or" : "ou",
    "Navigation" : "Navegação",
    "Previous period" : "Período anterior",
    "Next period" : "Próximo período",
    "Views" : "Visualizações",
    "Day view" : "Visão diária",
    "Week view" : "Visão semanal",
    "Month view" : "Visão mensal",
    "Year view" : "Visualização do ano",
    "List view" : "Exibição de lista",
    "Actions" : "Ações",
    "Create event" : "Criar evento",
    "Show shortcuts" : "Mostrar atalhos",
    "Editor" : "Editor",
    "Close editor" : "Fechar editor",
    "Save edited event" : "Salvar evento editado",
    "Delete edited event" : "Excluir evento editado",
    "Duplicate event" : "Evento duplicado",
    "Enable birthday calendar" : "Ativar calendário de aniversários",
    "Show tasks in calendar" : "Mostrar tarefas no calendário",
    "Enable simplified editor" : "Ativar o editor simplificado",
    "Limit the number of events displayed in the monthly view" : "Limitar número de eventos mostrados no modo de exibição mensal",
    "Show weekends" : "Mostrar fins de semana",
    "Show week numbers" : "Exibir o número das semanas",
    "Time increments" : "Incrementos de tempo",
    "Default calendar for incoming invitations" : "Calendário padrão para convites recebidos",
    "Default reminder" : "Lembrete padrão",
    "Copy primary CalDAV address" : "Copiar endereço CalDAV primário",
    "Copy iOS/macOS CalDAV address" : "Copiar endereço iOS/macOS CalDAV",
    "Personal availability settings" : "Configurações de disponibilidade pessoal",
    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
    "Calendar settings" : "Configurações do calendário",
    "At event start" : "No início do evento",
    "No reminder" : "Nenhum lembrete",
    "Failed to save default calendar" : "Falha ao salvar o calendário padrão",
    "CalDAV link copied to clipboard." : "Link CalDAV copiado para a área de transferência.",
    "CalDAV link could not be copied to clipboard." : "Link CalDAV não copiado para a área de transferência.",
    "Appointment schedule successfully created" : "Agendamento de compromissos criado com sucesso",
    "Appointment schedule successfully updated" : "Agendamento de compromissos atualizado com sucesso",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dias","{duration} dias"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mês","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} ano","{duration} anos","{duration} anos"],
    "To configure appointments, add your email address in personal settings." : "Para configurar agendamentos, adicione seu endereço de e-mail nas configurações pessoais.",
    "Public – shown on the profile page" : "Público - mostrado na página do perfil",
    "Private – only accessible via secret link" : "Privado - acessível apenas por meio de link secreto",
    "Appointment name" : "Nome do agendamento",
    "Location" : "Localização",
    "Create a Talk room" : "Criar uma sala de conversa",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Um link exclusivo será gerado para cada consulta agendada e enviado por e-mail de confirmação",
    "Description" : "Descrição",
    "Visibility" : "Visibilidade",
    "Duration" : "Duração:",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendários adicionais para verificar conflitos",
    "Pick time ranges where appointments are allowed" : "Escolha os intervalos de tempo onde serão permitidos agendamentos",
    "to" : "às",
    "Delete slot" : "Excluir vaga",
    "No times set" : "Nenhum horário definido",
    "Add" : "Adicionar",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Weekdays" : "Dias da semana",
    "Add time before and after the event" : "Adicionar um tempo antes e depois do evento",
    "Before the event" : "Antes do evento",
    "After the event" : "Depois do evento",
    "Planning restrictions" : "Restrições de planejamento",
    "Minimum time before next available slot" : "Tempo mínimo antes da próxima vaga disponível",
    "Max slots per day" : "Máximo de vagas por dia",
    "Limit how far in the future appointments can be booked" : "Limite de tempo para reserva de agendamentos futuros",
    "It seems a rate limit has been reached. Please try again later." : "Parece que um limite de taxa foi atingido. Por favor, tente novamente mais tarde.",
    "Appointment schedule saved" : "Agendamento de compromissos salvo",
    "Create appointment schedule" : "Criar agendamento de compromissos",
    "Edit appointment schedule" : "Editar agendamento de compromissos",
    "Update" : "Atualizar",
    "Please confirm your reservation" : "Por favor, confirme sua reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Enviamos a você um e-mail com os detalhes. Por favor, confirme seu agendamento usando o link no e-mail. Você pode fechar esta página agora.",
    "Your name" : "Seu nome",
    "Your email address" : "Seu endereço de e-mail",
    "Please share anything that will help prepare for our meeting" : "Por favor, compartilhe qualquer coisa que ajude a se preparar para nosso encontro",
    "Could not book the appointment. Please try again later or contact the organizer." : "Não foi possível reservar o agendamento. Tente novamente mais tarde ou entre em contato com o organizador.",
    "Back" : "Voltar",
    "Book appointment" : "Marcar consulta",
    "Reminder" : "Lembrete",
    "before at" : "antes das",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Audio notification" : "Notificação de áudio",
    "Other notification" : "Outras notificações",
    "Relative to event" : "Relativo ao evento",
    "On date" : "Na data",
    "Edit time" : "Editar horário",
    "Save time" : "Salvar horário",
    "Remove reminder" : "Remover lembrete",
    "on" : "ligado",
    "at" : "em",
    "+ Add reminder" : "+ Adicionar lembrete",
    "Add reminder" : "Adicionar lembrete ",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "No attachments" : "No attachments",
    "Add from Files" : "Adicionar a partir de Arquivos",
    "Upload from device" : "Enviar do dispositivo",
    "Delete file" : "Excluir arquivo",
    "Confirmation" : "Confirmação",
    "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
    "Choose a file to share as a link" : "Escolher um arquivo para compartilhar como link",
    "Attachment {name} already exist!" : "Attachment {name} already exist!",
    "Could not upload attachment(s)" : "Não foi possível enviar anexo(s)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Você está prestes a navegar para {host}. Tem certeza de que deseja prosseguir? Link:{link}",
    "Proceed" : "Prosseguir",
    "_{count} attachment_::_{count} attachments_" : ["{count} anexo","{count} anexos","{count} anexos"],
    "Invitation accepted" : "Convite aceito",
    "Available" : "Disponível",
    "Suggested" : "Sugerido",
    "Participation marked as tentative" : "Participação marcada como provisória",
    "Accepted {organizerName}'s invitation" : "Aceitou o convite de {organizerName}",
    "Not available" : "Indisponível",
    "Invitation declined" : "Convite recusado",
    "Declined {organizerName}'s invitation" : "Recusou o convite de {organizerName}",
    "Invitation is delegated" : "O convite é delegado",
    "Checking availability" : "Verificando disponibilidade",
    "Awaiting response" : "Esperando resposta",
    "Has not responded to {organizerName}'s invitation yet" : "Ainda não respondeu ao convite de {organizerName}",
    "Availability of attendees, resources and rooms" : "Disponibilidade de participantes, recursos e salas",
    "Find a time" : "Encontre um horário",
    "with" : "com",
    "Available times:" : "Horários disponíveis:",
    "Suggestion accepted" : "Sugestão aceita",
    "Done" : "Pronto",
    "Select automatic slot" : "Selecione slot automático",
    "chairperson" : "presidente",
    "required participant" : "participante obrigatório",
    "non-participant" : "não participante",
    "optional participant" : "participante opcional",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Free" : "Livre",
    "Busy (tentative)" : "Ocupado (talvez)",
    "Busy" : "Ocupado",
    "Out of office" : "Fora do escritório",
    "Unknown" : "Desconhecido",
    "Search room" : "Sala de pesquisa",
    "Room name" : "Nome da sala",
    "Check room availability" : "Verifique a disponibilidade de espaços",
    "Accept" : "Aceitar",
    "Decline" : "Recusar",
    "Tentative" : "Talvez",
    "The invitation has been accepted successfully." : "O convite foi aceito.",
    "Failed to accept the invitation." : "Falha ao aceitar o convite.",
    "The invitation has been declined successfully." : "O convite foi recusado.",
    "Failed to decline the invitation." : "Falha ao recusar o convite.",
    "Your participation has been marked as tentative." : "Sua participação foi marcada como incerta.",
    "Failed to set the participation status to tentative." : "Falha ao marcar sua participação como incerta.",
    "Attendees" : "Participantes",
    "Create Talk room for this event" : "Criar sala no Talk para este evento",
    "No attendees yet" : "Nenhum participante ainda",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} convidado, {confirmedCount} confirmado",
    "Successfully appended link to talk room to location." : "Link anexado com sucesso para a sala de conversação ao local.",
    "Successfully appended link to talk room to description." : "O link para a sala Talk foi adicionado com sucesso na descrição",
    "Error creating Talk room" : "Erro ao criar a sala Talk",
    "_%n more guest_::_%n more guests_" : ["%n mais convidados","%n mais convidados","%n mais convidados"],
    "Request reply" : "Solicitar resposta",
    "Chairperson" : "Organizador",
    "Required participant" : "Participante obrigatório",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "Não participante",
    "Remove group" : "Excluir grupo",
    "Remove attendee" : "Remover participante",
    "_%n member_::_%n members_" : ["%n membros","%n membros","%n membros"],
    "Search for emails, users, contacts, teams or groups" : "Pesquise e-mails, usuários, contatos, equipes ou grupos",
    "No match found" : "Nenhuma correspondência encontrada",
    "Note that members of circles get invited but are not synced yet." : "Observe que os membros dos círculos são convidados, mas ainda não estão sincronizados.",
    "(organizer)" : "(organizador)",
    "Make {label} the organizer" : "Faça de {label} o organizador",
    "Make {label} the organizer and attend" : "Faça {label} o organizador e participe",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar convites e gerenciar respostas, [linkopen]adicione seu endereço de e-mail nas configurações pessoais[linkclose].",
    "Remove color" : "Remover cor",
    "Event title" : "Título do evento",
    "From" : "De",
    "To" : "Para",
    "All day" : "Dia inteiro",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Não é possível modificar a configuração de dia inteiro para eventos que fazem parte de um conjunto de recorrência.",
    "Repeat" : "Repetir",
    "End repeat" : "Terminar repetição",
    "Select to end repeat" : "Selecione para finalizar a repetição",
    "never" : "nunca",
    "on date" : "na data",
    "after" : "após",
    "_time_::_times_" : ["vez","vezes","vezes"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento é a exceção de recorrência de um conjunto de recorrência. Você não pode adicionar uma regra de recorrência a ele.",
    "first" : "primeiro",
    "third" : "terceiro",
    "fourth" : "quarto",
    "fifth" : "quinto",
    "second to last" : "segundos atrás",
    "last" : "último",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Alterações na regra de recorrência serão aplicadas somente a esta e a todas as ocorrências futuras.",
    "Repeat every" : "Repetir a cada",
    "By day of the month" : "Pelo dia do mês",
    "On the" : "Em",
    "_month_::_months_" : ["mês","meses","meses"],
    "_year_::_years_" : ["ano","anos","anos"],
    "weekday" : "Dia da semana",
    "weekend day" : "dia da semana",
    "Does not repeat" : "Não repetir",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "A definição de recorrência deste evento não é totalmente suportada pelo Nextcloud. Se você editar as opções de recorrência, determinadas recorrências poderão ser perdidas.",
    "Suggestions" : "Sugestões",
    "No rooms or resources yet" : "Ainda não há salas ou recursos",
    "Add resource" : "Adicionar recurso",
    "Has a projector" : "Tem projetor",
    "Has a whiteboard" : "Tem quadro branco",
    "Wheelchair accessible" : "Acessível a cadeiras de rodas",
    "Remove resource" : "Remover recurso",
    "Show all rooms" : "Mostrar todos os espaços",
    "Projector" : "Projetor",
    "Whiteboard" : "Quadro branco",
    "Search for resources or rooms" : "Pesquise recursos ou salas",
    "available" : "disponível",
    "unavailable" : "indisponível",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} assento","{seatingCapacity} assentos","{seatingCapacity} assentos"],
    "Room type" : "Tipo de sala",
    "Any" : "Qualquer uma",
    "Minimum seating capacity" : "Capacidade mínima de assento",
    "More details" : "Mais detalhes",
    "Update this and all future" : "Atualizar este e todos os futuros",
    "Update this occurrence" : "Atualizar esta ocorrência",
    "Public calendar does not exist" : "Calendário público não existe",
    "Maybe the share was deleted or has expired?" : "Talvez o compartilhamento esteja excluído ou expirado?",
    "Select a time zone" : "Selecione um fuso horário",
    "Please select a time zone:" : "Selecione um fuso horário:",
    "Pick a time" : "Escolha um horário",
    "Pick a date" : "Escolha uma data",
    "from {formattedDate}" : "de {formattedDate}",
    "to {formattedDate}" : "até {formattedDate}",
    "on {formattedDate}" : "em {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "de {formattedDate} às {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "até {formattedDate} às {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "em {formattedDate} às {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} às {formattedTime}",
    "Please enter a valid date" : "Digite uma data válida",
    "Please enter a valid date and time" : "Digite uma data e hora válida",
    "Type to search time zone" : "Digite para pesquisar o fuso horário",
    "Global" : "Global",
    "Public holiday calendars" : "Calendários de feriados",
    "Public calendars" : "Adicione um calendário público personalizado",
    "No valid public calendars configured" : "Nenhum calendário público válido configurado",
    "Speak to the server administrator to resolve this issue." : "Fale com o administrador do servidor para resolver esse problema.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Os calendários de feriados públicos são fornecidos pelo Thunderbird. Os dados do calendário serão baixados de {website}",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Esses calendários públicos são sugeridos pelo administrador do servidor. Os dados do calendário serão baixados do respectivo site.",
    "By {authors}" : "Por {authors}",
    "Subscribed" : "Inscrita",
    "Subscribe" : "Se inscrever",
    "Holidays in {region}" : "Feriados em {region}",
    "An error occurred, unable to read public calendars." : "Ocorreu um erro: não foi possível ler calendários públicos.",
    "An error occurred, unable to subscribe to calendar." : "Ocorreu um erro, não foi possível assinar o calendário.",
    "Select a date" : "Selecione uma data",
    "Select slot" : "Selecionar vaga",
    "No slots available" : "Nenhuma vaga disponível",
    "Could not fetch slots" : "Não foi possível buscar slots",
    "The slot for your appointment has been confirmed" : "A vaga para o seu agendamento foi confirmada",
    "Appointment Details:" : "Detalhes do agendamento:",
    "Time:" : "Tempo:",
    "Booked for:" : "Reservado para:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Obrigada. Sua reserva de {startDate} a {endDate} foi confirmada.",
    "Book another appointment:" : "Marcar outro agendamento",
    "See all available slots" : "Ver todas as vagas disponíveis",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "A vaga para o seu agendamento de {startDate} a {endDate} não está mais disponível.",
    "Please book a different slot:" : "Reserve um slot diferente:",
    "Book an appointment with {name}" : "Marque um agendamento com {name}",
    "No public appointments found for {name}" : "Não foi encontrado nenhum agendamento público para {name}",
    "Personal" : "Pessoal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A detecção automática determinou que seu fuso horário seja UTC.\nProvavelmente, isso é resultado de medidas de segurança do seu navegador.\nDefina seu fuso horário manualmente nas configurações do calendário.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Seu fuso horário configurado ({timezoneId}) não foi encontrado. Retornando ao UTC.\nAltere seu fuso horário nas configurações e informe este problema.",
    "Event does not exist" : "O evento não existe",
    "Duplicate" : "Duplicada",
    "Delete this occurrence" : "Excluir esta ocorrência",
    "Delete this and all future" : "Excluir esta e todas as futuras",
    "Details" : "Detalhes",
    "Managing shared access" : "Gerenciar acesso compartilhado",
    "Deny access" : "Negar acesso",
    "Invite" : "Convidar",
    "Resources" : "Recursos",
    "_User requires access to your file_::_Users require access to your file_" : ["O usuário requer acesso ao seu arquivo","O usuário requer acesso aos seus arquivos","O usuário requer acesso aos seus arquivos"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Os anexos requerem acesso compartilhados","O usuário requer acesso aos seus arquivos","Anexos que exigem acesso compartilhado"],
    "Close" : "Fechar",
    "Untitled event" : "Evento sem título",
    "Subscribe to {name}" : "Inscrever-se em {name}",
    "Export {name}" : "Exportar {name}",
    "Anniversary" : "Aniversário",
    "Appointment" : "Agendamento",
    "Business" : "Negócio",
    "Education" : "Educação",
    "Holiday" : "Feriado",
    "Meeting" : "Reunião",
    "Miscellaneous" : "Diversos",
    "Non-working hours" : "Horas fora do expediente",
    "Not in office" : "Fora do escritório",
    "Phone call" : "Chamada telefônica",
    "Sick day" : "Dia ruim",
    "Special occasion" : "Ocasião especial",
    "Travel" : "Viagem",
    "Vacation" : "Férias",
    "Midnight on the day the event starts" : "Meia-noite do dia em que o evento começa",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia antes do evento às {formattedHourMinute}","%n dias antes do evento às {formattedHourMinute}","%n dias antes do evento às {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes do evento às {formattedHourMinute}","%n semanas antes do evento às {formattedHourMinute}","%n semanas antes do evento às {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "no dia do evento às {formattedHourMinute}",
    "at the event's start" : "no início do evento",
    "at the event's end" : "no fim do evento",
    "{time} before the event starts" : "{time} antes de iniciar o evento",
    "{time} before the event ends" : "{time} antes do evento terminar",
    "{time} after the event starts" : "{time} após o evento iniciar",
    "{time} after the event ends" : "{time} após o evento terminar",
    "on {time}" : "às {time}",
    "on {time} ({timezoneId})" : "às {time} ({timezoneId})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensalmente",
    "Yearly" : "Anualmente",
    "_Every %n day_::_Every %n days_" : ["A cada %n dia","A cada %n dias","A cada %n dias"],
    "_Every %n week_::_Every %n weeks_" : ["A cada %n semana","A cada %n semanas","A cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["A cada %n mês","A cada %n meses","A cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["A cada %n ano","A cada %n anos","A cada %n anos"],
    "_on {weekday}_::_on {weekdays}_" : ["em {weekday}","em {weekdays}","em {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["no dia {dayOfMonthList}","nos dias {dayOfMonthList}","nos dias {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "no {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "em {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "em {monthNames} no {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "até {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n vezes","%n vezes"],
    "Untitled task" : "Tarefa sem título",
    "Please ask your administrator to enable the Tasks App." : "Peça ao administrador para ativar o aplicativo Tarefas.",
    "W" : "S",
    "%n more" : "%n mais",
    "No events to display" : "Não há mais eventos a mostrar",
    "_+%n more_::_+%n more_" : ["mais +%n","mais +%n","mais +%n"],
    "No events" : "Sem eventos",
    "Create a new event or change the visible time-range" : "Crie um novo evento ou altere o intervalo de tempo visível",
    "Failed to save event" : "Falha ao salvar o evento",
    "It might have been deleted, or there was a typo in a link" : "Pode ter sido excluído ou houve um erro de digitação no link",
    "It might have been deleted, or there was a typo in the link" : "Pode ter sido excluído ou houve um erro de digitação no link",
    "Meeting room" : "Sala de reuniões",
    "Lecture hall" : "Auditório",
    "Seminar room" : "Sala de seminários",
    "Other" : "De Outro",
    "When shared show" : "Quando compartilhando mostrar",
    "When shared show full event" : "Quando compartilhado, mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado, mostrar somente ocupado",
    "When shared hide this event" : "Quando compartilhado, ocultar este evento",
    "The visibility of this event in shared calendars." : "A visibilidade deste evento em calendários compartilhados.",
    "Add a location" : "Adicionar uma localização",
    "Add a description" : "Adicionar uma descrição",
    "Status" : "Status",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Confirmation about the overall status of the event." : "Confirmação sobre o status geral do evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Leve esse evento em consideração ao calcular informações de disponibilidade.",
    "Categories" : "Categorias",
    "Categories help you to structure and organize your events." : "As categorias ajudam a estruturar e organizar seus eventos.",
    "Search or add categories" : "Pesquisar ou adicionar categorias",
    "Add this as a new category" : "Adicione isso como uma nova categoria",
    "Custom color" : "Cor personalizada",
    "Special color of this event. Overrides the calendar-color." : "Cor especial deste evento. Substitui a cor do calendário.",
    "Error while sharing file" : "Erro ao compartilhar arquivo",
    "Error while sharing file with user" : "Erro ao compartilhar arquivo com o usuário",
    "Attachment {fileName} already exists!" : "O anexo {fileName} já existe!",
    "An error occurred during getting file information" : "Ocorreu um erro ao obter informações sobre o arquivo",
    "Chat room for event" : "Sala de bato-papo para evento",
    "An error occurred, unable to delete the calendar." : "Erro ao excluir o calendário.",
    "Imported {filename}" : "Importado {filename}",
    "This is an event reminder." : "Este é um lembrete de evento.",
    "Error while parsing a PROPFIND error" : "Erro ao analisar um erro PROPFIND",
    "Appointment not found" : "Agendamento não encontrado",
    "User not found" : "Usuário não encontrado",
    "Default calendar for invitations and new events" : "Calendário padrão para convites e novos eventos",
    "Appointment was created successfully" : "O agendamento foi criado com sucesso",
    "Appointment was updated successfully" : "O agendamento foi atualizado com sucesso",
    "Create appointment" : "Criar agendamento",
    "Edit appointment" : "Editar agendamento",
    "Book the appointment" : "Marcar o agendamento",
    "You do not own this calendar, so you cannot add attendees to this event" : "Você não é o proprietário desta agenda, portanto não pode adicionar participantes a este evento",
    "Search for emails, users, contacts or groups" : "Pesquise e-mails, usuários, contatos ou grupos",
    "Select date" : "Selecionar data",
    "Create a new event" : "Criar um novo evento",
    "[Today]" : "[Hoje]",
    "[Tomorrow]" : "[Amanhã]",
    "[Yesterday]" : "[Ontem]",
    "[Last] dddd" : "[Último] dddd"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
