OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Внесената адреса на е-пошта е премногу долга",
    "User-Session unexpectedly expired" : "Корисничката-сесија е застарена",
    "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
    "%s has published the calendar »%s«" : "%s Објави календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
    "Successfully sent email to %1$s" : "Успешно испратена е-пошта до %1$s",
    "Hello," : "Здраво,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрав!",
    "Upcoming events" : "Престојни настани",
    "No more events today" : "Нема настани за денес",
    "No upcoming events" : "Нема престојни настани",
    "More events" : "Повеќе настани",
    "%1$s with %2$s" : "%1$s со %2$s",
    "Calendar" : "Календар",
    "New booking {booking}" : "Нова резервација {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) закажа состанок \"{config_display_name}\" на {date_time}.",
    "Appointments" : "Состаноци",
    "Schedule appointment \"%s\"" : "Закажан состанок \"%s\"",
    "Schedule an appointment" : "Закажи состанок",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Подготовки за %s",
    "Follow up for %s" : "Следи за %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Потребна е потврда за состанокот \"%s\" со %s",
    "Dear %s, please confirm your booking" : "Поритуван/а %s, ве молиме потврдете ја вашата резервација",
    "Confirm" : "Потврди",
    "Description:" : "Опис:",
    "This confirmation link expires in %s hours." : "Овој линк за потврда истекува за %s часа.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "И покрај се, ако сакате да го откажете состанокот, контактирајте го организаторот со тоа што ќе одговорите на оваа е-пошта или посетете го неговиот профил",
    "Your appointment \"%s\" with %s has been accepted" : "Состанокот \"%s\" со %s е прифатен",
    "Dear %s, your booking has been accepted." : "Почитуван/а %s, Вашата резервација е прифатена.",
    "Appointment for:" : "Состанок за:",
    "Date:" : "Датум:",
    "You will receive a link with the confirmation email" : "Ќе добиете линк со потврда на е-пошта",
    "Where:" : "Каде: ",
    "Comment:" : "Коментар:",
    "You have a new appointment booking \"%s\" from %s" : "Имате нов закажан состанок \"%s\" од %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Почитуван/а %s, %s (%s) закажа состанок со вас.",
    "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Апликацијата Calendar е кориснички интерфејс за серверот CalDAV на Nextcloud. Лесно синхронизирајте настани од различни уреди со вашиот Nextcloud и уредувајте ги онлајн.\n\n* 🚀 **Интеграција со други апликации Nextcloud!** Моментално Контакти - претстојат повеќе.\n* 🌐 **WebCal поддршка!** Сакате да ги видите натпреварите на вашиот омилен тим во вашиот календар? Нема проблем!\n* 🙋 **Присутни!** Поканете луѓе на вашите настани\n* ⌚️ **Слободно/Зафатено!** Погледнете кога вашите присутни се достапни за средба\n* ⏰ **Потсетници!** Добијте аларми за настани во вашиот прелистувач и преку е-пошта\n* 🔍 Барај! Најдете ги вашите настани лесно\n* ☑️ Задачи! Погледнете ги задачите со датум на доспевање директно во календарот\n* 🙈 **Ние не го измислуваме повторно тркалото!** Врз основа на одличната [c-dav библиотека](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/ mozilla-comm/ical.js) и библиотеки [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Предходен ден",
    "Previous week" : "Предходна недела",
    "Previous year" : "Предходна година",
    "Previous month" : "Предходен месец",
    "Next day" : "Следен ден",
    "Next week" : "Следна недела",
    "Next year" : "Следна година",
    "Next month" : "Следен месец",
    "Event" : "Настан",
    "Create new event" : "Креирај нов настан",
    "Today" : "Денес",
    "Day" : "Ден",
    "Week" : "Недела",
    "Month" : "Месец",
    "Year" : "Година",
    "List" : "Лист",
    "Preview" : "Преглед",
    "Copy link" : "Копирај линк",
    "Edit" : "Уреди",
    "Delete" : "Избриши",
    "Appointment link was copied to clipboard" : "Линкот за состанокот е копиран во клипборд",
    "Appointment link could not be copied to clipboard" : "Линкот за состанокот неможе за се копира во клипборд",
    "Create new" : "Креирај нова",
    "Untitled calendar" : "Неименуван календар",
    "Shared with you by" : "Споделено со вас од",
    "Edit and share calendar" : "Уреди и сподели календар",
    "Edit calendar" : "Уреди календар",
    "Disable calendar \"{calendar}\"" : "Оневозможи календар \"{calendar}\"",
    "Disable untitled calendar" : "Оневозможи неименуван календар",
    "Enable calendar \"{calendar}\"" : "Овозможи календар \"{calendar}\"",
    "Enable untitled calendar" : "Овозможи неименуван календар",
    "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за 1 секунда","Отстранување на споделување на календар за {countdown} секунди"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за 1 секунда","Бришење на календарот за {countdown} секунди"],
    "Calendars" : "Календари",
    "Add new" : "Додади нов",
    "New calendar" : "Нов календар",
    "Name for new calendar" : "Име за нов календар",
    "Creating calendar …" : "Креирање календар …",
    "New calendar with task list" : "Нов календар со листа на задачи",
    "New subscription from link (read-only)" : "Нова претплата од линк (само за читање)",
    "Creating subscription …" : "Креирање претплата  …",
    "Add public holiday calendar" : "Додади календар со државни празници",
    "An error occurred, unable to create the calendar." : "Настана грешка, неможе да се креира календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Внесете валиден линк (започнувајчи со http://, https://, webcal://, или webcals://)",
    "Copy subscription link" : "Копирај линк за претплата",
    "Copying link …" : "Копирање линк …",
    "Copied link" : "Линкот е копиран",
    "Could not copy link" : "Неможе да се копира линкот",
    "Export" : "Извези",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "Trash bin" : "Корпа за отпадоци",
    "Loading deleted items." : "Вчитување на избришаните работи.",
    "You do not have any deleted items." : "Немате избришани работи.",
    "Name" : "Име",
    "Deleted" : "Избришани",
    "Restore" : "Врати",
    "Delete permanently" : "Избриши",
    "Empty trash bin" : "Испразни ја корпата со отпадоци",
    "Untitled item" : "Неименуваи работи",
    "Unknown calendar" : "Непознат календар",
    "Could not load deleted calendars and objects" : "Неможат да се вчитаат избришаните календари и елементи",
    "Could not restore calendar or event" : "Неможе да се врати календар или настан",
    "Do you really want to empty the trash bin?" : "Дали навистина сакате да ја испразните kорпаta за отпадоци?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Работите од корпата за отпадоци ќе бидат избришани после {numDays} ден","Работите од корпата за отпадоци ќе бидат избришани после  {numDays} дена"],
    "Deck" : "Deck",
    "Hidden" : "Сокриен",
    "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
    "Internal link" : "Внатрешен линк",
    "A private link that can be used with external clients" : "Приватен линк што може да се користи со надворешни клиенти",
    "Copy internal link" : "Копирај внатрешен линк",
    "Share link" : "Сподели линк",
    "Copy public link" : "Копирај јавен линк",
    "Send link to calendar via email" : "Испрати линк до календарот преку е-пошта",
    "Enter one address" : "Внеси една адреса",
    "Sending email …" : "Испраќање е-пошта …",
    "Copy embedding code" : "Копирај код за вградување",
    "Copying code …" : "Копирање код …",
    "Copied code" : "Кодот е копиран",
    "Could not copy code" : "Неможе да се копира кодот",
    "Delete share link" : "Избриши го линкот за споделување",
    "Deleting share link …" : "Се брише линкот за споделување …",
    "An error occurred, unable to publish calendar." : "Настана грешка, неможе да се објави календарот.",
    "An error occurred, unable to send email." : "Настана грешка, неможе да се испрати е-пошта.",
    "Embed code copied to clipboard." : "Кодот за вградување е копиран во клипборд.",
    "Embed code could not be copied to clipboard." : "Кодот за вградување неможе да се копира во клипборд.",
    "Unpublishing calendar failed" : "Неуспешно од-објавување на календар",
    "can edit" : "може да се измени",
    "Unshare with {displayName}" : "Не споделувај со {displayName}",
    "An error occurred while unsharing the calendar." : "Настана грешка при откажување на споделување на календар.",
    "An error occurred, unable to change the permission of the share." : "Настана грешка, неможе да се променат дозволите за споделување.",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "Calendar name …" : "Име на календар ...",
    "Share calendar" : "Сподели календар",
    "Unshare from me" : "Не споделувај со мене",
    "Save" : "Зачувај",
    "Failed to save calendar name and color" : "Неуспешно зачувување на име на календар и боја",
    "Import calendars" : "Увези календари",
    "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
    "Filename" : "Име на датотека",
    "Calendar to import into" : "Календар за да направите увоз во него",
    "Cancel" : "Откажи",
    "_Import calendar_::_Import calendars_" : ["Увези календар","Увези календари"],
    "Default attachments location" : "Стандардна локација за прилози",
    "Select the default location for attachments" : "Избери стандардна локација за прилози",
    "Invalid location selected" : "Избрана невалидна локација",
    "Attachments folder successfully saved." : "Папката за прилози е успешно зачувана.",
    "Error on saving attachments folder." : "Грешка при зачувување на папка за прилози.",
    "{filename} could not be parsed" : "Датотеката {filename} не може да се анализира",
    "No valid files found, aborting import" : "Не е пронајдена валидна датотека, увозот е откажан",
    "Import partially failed. Imported {accepted} out of {total}." : "Увозот е делумно неуспешен. Увезени {accepted} од вкупно {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно увезен 1 настан","Успешно увезени %n настани"],
    "Automatic" : "Автоматски",
    "Automatic ({detected})" : "Автоматски ({detected})",
    "New setting was not saved successfully." : "Неуспешно зачувување на промените.",
    "Shortcut overview" : "Преглед на кратенки преку тастатура",
    "or" : "или",
    "Navigation" : "Навигација",
    "Previous period" : "Предходен период",
    "Next period" : "Следен период",
    "Views" : "Прегледи",
    "Day view" : "Дневен преглед",
    "Week view" : "Неделен преглед",
    "Month view" : "Месечен преглед",
    "Year view" : "Годишен преглед",
    "List view" : "Листа",
    "Actions" : "Акции",
    "Create event" : "Креирај настан",
    "Show shortcuts" : "Прикажи кратенки",
    "Editor" : "Уредник",
    "Close editor" : "Затвори го уредникот",
    "Save edited event" : "Зачувај го изменетиот настан",
    "Delete edited event" : "Избриши го изменетиот настан",
    "Duplicate event" : "Дуплицирај настај",
    "Enable birthday calendar" : "Овозможи календар со родендени",
    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
    "Enable simplified editor" : "Овозможи поедноставен уредувач",
    "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
    "Show weekends" : "Прикажи викенди",
    "Show week numbers" : "Прикажи броеви на неделите",
    "Time increments" : "Временско зголемување",
    "Default reminder" : "Стандарден потсетник",
    "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
    "Personal availability settings" : "Параметри за лична достапност",
    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
    "Calendar settings" : "Параметри за календар",
    "No reminder" : "Нема потсетник",
    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
    "_{duration} minute_::_{duration} minutes_" : ["1 минута","{duration} минути"],
    "0 minutes" : "0 минути",
    "_{duration} hour_::_{duration} hours_" : ["1 час","{duration} часа"],
    "_{duration} day_::_{duration} days_" : ["1 ден","{duration} дена"],
    "_{duration} week_::_{duration} weeks_" : ["1 недела","{duration} недели"],
    "_{duration} month_::_{duration} months_" : ["{duration} месец","{duration} месеци"],
    "_{duration} year_::_{duration} years_" : ["1 година","{duration} години"],
    "To configure appointments, add your email address in personal settings." : "За да ги конфигурирате состаноците, додајте ја вашата адреса за е-пошта во личните поставки.",
    "Public – shown on the profile page" : "Јавен - Прикажи на профилната страница",
    "Private – only accessible via secret link" : "Приватен - пристап само со безбедносен линк",
    "Appointment name" : "Име на состанокот",
    "Location" : "Локација",
    "Create a Talk room" : "Креирај соба за разговор",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Уникатен линк ќе се генерира за секој резервиран термин и ќе се испрати потврда преку е-пошта",
    "Description" : "Опис",
    "Visibility" : "Видливост",
    "Duration" : "Времетраење",
    "Increments" : "Зголемување",
    "Additional calendars to check for conflicts" : "Дополнителни календари за проверка на конфликти",
    "Pick time ranges where appointments are allowed" : "Изберете временски интервал кога термините се дозволени",
    "to" : "до",
    "Delete slot" : "Избриши термин",
    "No times set" : "Нема поставени времиња",
    "Add" : "Додади",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четврток",
    "Friday" : "Петок",
    "Saturday" : "Сабота",
    "Sunday" : "Недела",
    "Weekdays" : "Работни денови",
    "Add time before and after the event" : "Додадете време пред и по настанот",
    "Before the event" : "Пред настанот",
    "After the event" : "После настанот",
    "Planning restrictions" : "Планирани рестрикции",
    "Minimum time before next available slot" : "Минимално време пред следниот достапен термин",
    "Max slots per day" : "Максимален број термини на ден",
    "Limit how far in the future appointments can be booked" : "Ограничете колку во иднина може да се резервираат термини",
    "Update" : "Ажурирај",
    "Please confirm your reservation" : "Ве молиме потврдете ја вашата резервација",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ви испративме е-пошта со детали. Ве молиме потврдете го вашиот термин користејќи ја врската во е-поштата. Можете да ја затворите оваа страница сега.",
    "Your name" : "Вашето име",
    "Your email address" : "Вашата адреса за е-пошта",
    "Please share anything that will help prepare for our meeting" : "Ве молиме споделете сè што ќе помогне да се подготвиме за нашиот состанок",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не може да се резервира термин. Обидете се повторно подоцна или контактирајте со организаторот.",
    "Back" : "Назад",
    "Reminder" : "Потсетник",
    "before at" : "пред",
    "Notification" : "Известување",
    "Email" : "Е-пошта",
    "Audio notification" : "Аудио известување",
    "Other notification" : "Друго и звестување",
    "Relative to event" : "Релативно на настан",
    "On date" : "На датум",
    "Edit time" : "Удери време",
    "Save time" : "Зачувај време",
    "Remove reminder" : "Отстрани потсетник",
    "on" : "во",
    "at" : "во",
    "+ Add reminder" : "+ Додади потсетник",
    "Add reminder" : "Додади потсетник",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часа"],
    "_day_::_days_" : ["ден","дена"],
    "_week_::_weeks_" : ["недела","недели"],
    "No attachments" : "Нема прилози",
    "Add from Files" : "Додади од датотеките",
    "Upload from device" : "Прикачи од уред",
    "Delete file" : "Избриши датотека",
    "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
    "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
    "Attachment {name} already exist!" : "Прилогот {name} веќе постои!",
    "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
    "Invitation accepted" : "Поканата е прифатена",
    "Available" : "Достапно",
    "Suggested" : "Предложено",
    "Participation marked as tentative" : "Учеството е означено како пробно",
    "Accepted {organizerName}'s invitation" : "Прифатена е покана од {organizerName}",
    "Not available" : "Недостапно",
    "Invitation declined" : "Поканата е одбиена",
    "Declined {organizerName}'s invitation" : "Одбиена е покана од {organizerName}",
    "Invitation is delegated" : "Поканата е делегирана",
    "Checking availability" : "Проверување на достапност",
    "Has not responded to {organizerName}'s invitation yet" : "Сè уште не одговорил на поканата на {organizerName}",
    "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
    "Done" : "Готово",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Free" : "Слободен",
    "Busy (tentative)" : "Зафатен (привремено)",
    "Busy" : "Зафатен",
    "Out of office" : "Надвор од канцеларија",
    "Unknown" : "Непознат",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "Tentative" : "Пробно",
    "The invitation has been accepted successfully." : "Поканата е успешно прифатена.",
    "Failed to accept the invitation." : "Неуспешно прифаќање на поканата.",
    "The invitation has been declined successfully." : "Поканата е успешно одбиена.",
    "Failed to decline the invitation." : "Неуспешно одбивање на поканата.",
    "Your participation has been marked as tentative." : "Вашето учество е означено како пробно.",
    "Failed to set the participation status to tentative." : "Неуспешно поставување на статус за учество како пробен.",
    "Attendees" : "Присутни",
    "Create Talk room for this event" : "Креирај соба за разговор за овој настан",
    "No attendees yet" : "Сè уште нема присутни",
    "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
    "Chairperson" : "Претседавач",
    "Required participant" : "Задолжителен учесник",
    "Optional participant" : "Незадолжителен учесник",
    "Non-participant" : "Не-учесник",
    "Remove group" : "Отстрани група",
    "Remove attendee" : "Откажи присутност",
    "No match found" : "Нема совпаѓања",
    "(organizer)" : "(organizer)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
    "Remove color" : "Отстрани боја",
    "Event title" : "Наслов на настанот",
    "From" : "Од",
    "To" : "До",
    "All day" : "Цели денови",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се менуваат целодневните параметри за настани што се дел од множество за повторување.",
    "Repeat" : "Повтори",
    "End repeat" : "Крај на повторувањето",
    "Select to end repeat" : "Избери крај на повторувањето",
    "never" : "никогаш",
    "on date" : "на датум",
    "after" : "после",
    "_time_::_times_" : ["еднаш","пати"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Овој настан е повторување-исклучок на множество повторување. Не можете да додадете правило за повторување на него.",
    "first" : "прв",
    "third" : "трети",
    "fourth" : "четврти",
    "fifth" : "петти",
    "second to last" : "претпоследен",
    "last" : "последен",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Промените на правилото за повторување ќе важат само за оваа и за сите идни појави.",
    "Repeat every" : "Повтори секој",
    "By day of the month" : "По ден во месецот",
    "On the" : "На",
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "weekday" : "работен ден",
    "weekend day" : "ден од викенд",
    "Does not repeat" : "Не повторувај",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Дефиницијата за повторување на овој настан не е целосно поддржана од Nextcloud. Ако ги уредите опциите за повторување, одредени повторувања може да се изгубат.",
    "Suggestions" : "Предлози",
    "No rooms or resources yet" : "Сè уште нема простории или ресурси",
    "Add resource" : "Додади ресурс",
    "Has a projector" : "Има проектор",
    "Has a whiteboard" : "Има табла",
    "Wheelchair accessible" : "Достапно за инвалидска количка",
    "Remove resource" : "Отстрани ресурс",
    "Projector" : "Проектор",
    "Whiteboard" : "Табла",
    "Search for resources or rooms" : "Пребарајте ресурси или простории",
    "available" : "достапно",
    "unavailable" : "недостапно",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["1 седиште","{seatingCapacity} седишта"],
    "Room type" : "Вид на соба",
    "Any" : "Било кој",
    "Minimum seating capacity" : "Минимален капацитет за седење",
    "Update this and all future" : "Ажурирајте го овој и сите во иднина",
    "Update this occurrence" : "Ажурирајте ја оваа можност",
    "Public calendar does not exist" : "Јавниот календар не постои",
    "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
    "Please select a time zone:" : "Изберете временска зона:",
    "Pick a time" : "Избери време",
    "Pick a date" : "Избери датум",
    "from {formattedDate}" : "од {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "на {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "од {formattedDate} во {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} во {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "на {formattedDate} во {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
    "Please enter a valid date" : "Внесете валиден датум",
    "Please enter a valid date and time" : "Внесете валиден датум и време",
    "Type to search time zone" : "Пребарај временски зони",
    "Global" : "Глобално",
    "Public holiday calendars" : "Календар со државни празници",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календарите за државни празници се обезбедени од Thunderbird. Податоците од календарот ќе се преземат од {website}",
    "By {authors}" : "Од {authors}",
    "Subscribed" : "Претплатени",
    "Subscribe" : "Претплата",
    "Holidays in {region}" : "Празници во {region}",
    "Select a date" : "Избери датум",
    "Select slot" : "Избери термин",
    "No slots available" : "Нема достапни термини",
    "The slot for your appointment has been confirmed" : "Времето за вашиот термин е потврден",
    "Appointment Details:" : "Детали за терминот:",
    "Time:" : "Време:",
    "Booked for:" : "Резервирано за:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Ви благодариме. Вашата резервација од {startDate} до {endDate} е потврдена.",
    "Book another appointment:" : "Резервирај друг термин:",
    "See all available slots" : "Прегледај ги сите слободни термини",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Времето за вашиот термин од {startDate} до {endDate} не е достапен повеќе.",
    "Please book a different slot:" : "Ве молиме резервирајте друг термин:",
    "Book an appointment with {name}" : "Закажан е термин со {name}",
    "No public appointments found for {name}" : "Нема пронајдено јавни термини за {name}",
    "Personal" : "Лично",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
    "Event does not exist" : "Настанот не постои",
    "Duplicate" : "Дуплирај",
    "Delete this occurrence" : "Избришете ја оваа можност",
    "Delete this and all future" : "Избришете го овој и сите во иднина",
    "Details" : "Детали",
    "Managing shared access" : "Управување со споделен пристап",
    "Deny access" : "Забрани пристап",
    "Invite" : "Покани",
    "Resources" : "Ресурси",
    "_User requires access to your file_::_Users require access to your file_" : ["Корисник бара пристап до вашата датотека","Корисници бараат пристап до вашата датотека"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог за кој е потребен пристап","Прилози за кои е потребен пристап"],
    "Close" : "Затвори",
    "Untitled event" : "Неименуван настан",
    "Subscribe to {name}" : "Претплатете се на {name}",
    "Export {name}" : "Извези {name}",
    "Anniversary" : "Годишнина",
    "Appointment" : "Состанок",
    "Business" : "Бизнис",
    "Education" : "Образование",
    "Holiday" : "Празник",
    "Meeting" : "Средба",
    "Miscellaneous" : "Разно",
    "Non-working hours" : "Неработни часови",
    "Not in office" : "Не во канцеларија",
    "Phone call" : "Телефонски повик",
    "Sick day" : "Боледување",
    "Special occasion" : "Посебна пригода",
    "Travel" : "Патување",
    "Vacation" : "Одмор",
    "Midnight on the day the event starts" : "На полноќ на денот кога започнува настанот",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Еден ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Една недела пред настанот во {formattedHourMinute}","%n недели пред настанот во {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "На денот на настанот во {formattedHourMinute}",
    "at the event's start" : "на почетокот на настанот",
    "at the event's end" : "на kraj на настанот",
    "{time} before the event starts" : "{time} пред да започне настанот",
    "{time} before the event ends" : "{time} пред да заврши настанот",
    "{time} after the event starts" : "{time} откако ќе започне настанот",
    "{time} after the event ends" : "{time} одкако ќе заврши настанот",
    "on {time}" : "во {time}",
    "on {time} ({timezoneId})" : "во {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} недела од {year}",
    "Daily" : "Дневно",
    "Weekly" : "Неделно",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Секој ден","Секој %n дена"],
    "_Every %n week_::_Every %n weeks_" : ["Секоја недела","Секој %n недели"],
    "_Every %n month_::_Every %n months_" : ["Секој %n месец","Секој %n месеци"],
    "_Every %n year_::_Every %n years_" : ["Секоја година","Секој %n години"],
    "_on {weekday}_::_on {weekdays}_" : ["во {weekday}","во {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на ден {dayOfMonthList}","на денови {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "во {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
    "Untitled task" : "Неименувана задача",
    "Please ask your administrator to enable the Tasks App." : "Замолете го сервер администраторот да ја овозможи апликацијата задачи.",
    "W" : "Н",
    "%n more" : "%n други",
    "No events to display" : "Нема настани за приказ",
    "_+%n more_::_+%n more_" : ["+%n друг","+%n други"],
    "No events" : "Нема настани",
    "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
    "It might have been deleted, or there was a typo in a link" : "Можеби е избришан или има грешка во врската",
    "It might have been deleted, or there was a typo in the link" : "Можеби е избришан или има грешка во врската",
    "Meeting room" : "Соба за состаноци",
    "Lecture hall" : "Сала за предавање",
    "Seminar room" : "Семинарска сала",
    "Other" : "Останато",
    "When shared show" : "Приказ кога е споделен",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
    "Add a location" : "Додади локација",
    "Add a description" : "Додади опис",
    "Status" : "Статус",
    "Confirmed" : "Потврдено",
    "Canceled" : "Откажано",
    "Confirmation about the overall status of the event." : "Потврда за целокупниот статус на настанот.",
    "Show as" : "Прикажи како",
    "Take this event into account when calculating free-busy information." : "Го има во предвид овој настан при пресметување на информации за слободен-зафатен.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категориите ви помагаат да ги структурирате и организирате вашите настани.",
    "Search or add categories" : "Барај или додади категории",
    "Add this as a new category" : "Додади како нова категорија",
    "Custom color" : "Прилагодена боја",
    "Special color of this event. Overrides the calendar-color." : "Специјална боја на овој настан. Ја отфрла бојата на календарот.",
    "Error while sharing file" : "Грешка при споделување на датотека",
    "Error while sharing file with user" : "Грешка при споделување на датотека со корисник",
    "Attachment {fileName} already exists!" : "Прилогот {fileName} веќе постои!",
    "An error occurred during getting file information" : "Настана грешка при преземање на информации од датотека",
    "Chat room for event" : "Соба за разговор за настанот",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "Imported {filename}" : "Импортирано {filename}",
    "This is an event reminder." : "Ова е потсетник за настан.",
    "Appointment not found" : "Терминот не е пронајден",
    "User not found" : "Корисникот не е пронајден",
    "Appointment was created successfully" : "Состанокот е успешно креиран",
    "Appointment was updated successfully" : "Состанокот е успешно ажуриран",
    "Create appointment" : "Креирај термин",
    "Edit appointment" : "Уреди термин",
    "Book the appointment" : "Резервирај термин",
    "Select date" : "Избери датум",
    "Create a new event" : "Креирајте нов настан",
    "[Today]" : "[Денес]",
    "[Tomorrow]" : "[Утре]",
    "[Yesterday]" : "[Вчера]",
    "[Last] dddd" : "[Последна] dddd"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
