OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Наведена и-мејл адреса је предугачка",
    "User-Session unexpectedly expired" : "Корисничка сесија је неочекивано истекла",
    "Provided email-address is not valid" : "Наведена и-мејл адреса није исправна",
    "%s has published the calendar »%s«" : "%s је објавио календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Неочекивана грешка током слања и-мејла. Молимо вас да се обратите свом администратору.",
    "Successfully sent email to %1$s" : "И-мејл је успешно послат на %1$s",
    "Hello," : "Здраво, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Желимо да Вас обавестимо да је %s објавио календар »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Здраво!",
    "Upcoming events" : "Предстојећи догађаји",
    "No more events today" : "Данас нема више догађаја",
    "No upcoming events" : "Нема догађаја у блиској будућности",
    "More events" : "Још догађаја",
    "%1$s with %2$s" : "%1$s са %2$s",
    "Calendar" : "Календар",
    "New booking {booking}" : "Нова резервација {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) је резервисао састанак „{config_display_name}” у {date_time}.",
    "Appointments" : "Састанци",
    "Schedule appointment \"%s\"" : "Планирај састанак „%s”",
    "Schedule an appointment" : "Планирање састанка",
    "%1$s - %2$s" : "%1$s  %2$s",
    "Prepare for %s" : "Припрема за %s",
    "Follow up for %s" : "Праћење за %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Потребна је потврда за ваш састанак „%s” са  %s",
    "Dear %s, please confirm your booking" : "Поштовани %s, молим вас да потврдите своју резервацију",
    "Confirm" : "Потврди",
    "Appointment with:" : "Састанак са:",
    "Description:" : "Опис:",
    "This confirmation link expires in %s hours." : "Овај линк за потврду истиче за %s сати.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ако желите да откажете овај састанак, молимо вас да се обратите организатору одговором на овај и-мејл или посетом њихове странице профила.",
    "Your appointment \"%s\" with %s has been accepted" : "Ваш састанак „%s” са %s је прихваћен",
    "Dear %s, your booking has been accepted." : "Поштовани %s, ваша резервација је прихваћена.",
    "Appointment for:" : "Састанак за:",
    "Date:" : "Датум:",
    "You will receive a link with the confirmation email" : "Примићете линк у и-мејлу за потврду",
    "Where:" : "Место:",
    "Comment:" : "Коментар:",
    "You have a new appointment booking \"%s\" from %s" : "Имате нову резервацију састанака „%s” коју је послао %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Поштовани %s, %s (%s) је резервисао састанак са вама.",
    "A Calendar app for Nextcloud" : "Календар апликација за Некстклауд",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Апликација Календар је кориснички интерфејс за CalDAV сервер ваше Nextcloud инстанце. Једноставно синхронизујте догађаје из разних уређаја са вашим Nextcloud сервером и уређујте их на мрежи.\n\n* 🚀 **Интеграција са осталим Nextcloud апликацијама!** Тренутно Контакти - биће их још.\n* 🌐 **WebCal подршка!** Желите да у свом календару видите датуме мечева свог омиљеног тима? Нема проблема!\n* 🙋 **Учесници!** Позовите људе на своје догађаје\n* ⌚️ **Слободан/Заузет!** Видите када ваши учесници могу да присуствују састанку\n* ⏰ **Подсетници!** Примајте аларме за своје догађаје унутар прегледача и путем и-мејла\n* 🔍 Претрага! Једноставно пронађите своје догађаје\n* ☑️ Задаци! Видите задатке са постављеним роком директно у календару\n* 🙈 **Не измишљамо рупу на саксији!** Заснована на одличној [c-dav библиотеци](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) и [fullcalendar](https://github.com/fullcalendar/fullcalendar) библиотекама.",
    "Previous day" : "Претходни дан",
    "Previous week" : "Претходна недеља",
    "Previous year" : "Претходна година",
    "Previous month" : "Претходни месец",
    "Next day" : "Наредни дан",
    "Next week" : "Наредне недеље",
    "Next year" : "Наредна година",
    "Next month" : "Наредног месеца",
    "Event" : "Догађај",
    "Create new event" : "Креирај нови догађај",
    "Today" : "Данас",
    "Day" : "Дан",
    "Week" : "Недеља",
    "Month" : "Месец",
    "Year" : "Година",
    "List" : "Излистај",
    "Preview" : "Претпреглед",
    "Copy link" : "Копирај везу",
    "Edit" : "Измени",
    "Delete" : "Обриши",
    "Appointment link was copied to clipboard" : "Линк састанка је копиран у клипборд",
    "Appointment link could not be copied to clipboard" : "Линк састанка није могао да се копира у клипборд",
    "Appointment schedules" : "Распореди састанака",
    "Create new" : "Направи нови",
    "Untitled calendar" : "Неименовани календар",
    "Shared with you by" : "Са вама је поделио",
    "Edit and share calendar" : "Уреди и подели календар",
    "Edit calendar" : "Уреди календар",
    "Disable calendar \"{calendar}\"" : "Искључи календар „{calendar}”",
    "Disable untitled calendar" : "Искључи неименовани календар",
    "Enable calendar \"{calendar}\"" : "Укључи календар „{calendar}”",
    "Enable untitled calendar" : "Укључи неименовани календар",
    "An error occurred, unable to change visibility of the calendar." : "Дошло је до грешке, не може да се промени видљивост календара.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Календар престаје да се дели за {countdown} секунду","Календар престаје да се дели за {countdown} секунде","Календар престаје да се дели за {countdown} секунди"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календар се брише за {countdown} секунду","Календар се брише за {countdown} секунде","Календар се брише за {countdown} секунди"],
    "Calendars" : "Календари",
    "Add new" : "Додај нови",
    "New calendar" : "Нови календар",
    "Name for new calendar" : "Назив новог календара",
    "Creating calendar …" : "Календар се креира …",
    "New calendar with task list" : "Нови календар са листом задатака",
    "New subscription from link (read-only)" : "Нова претплата преко линка (само-за-читање)",
    "Creating subscription …" : "Претплата се креира …",
    "Add public holiday calendar" : "Додај календар државних празника",
    "Add custom public calendar" : "Додај прилагођени јавни календар",
    "An error occurred, unable to create the calendar." : "Дошло је до грешке, календар не може да се креира.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Молимо вас да унесете исправан линк (који полиње са http://, https://, webcal://, или webcals://)",
    "Copy subscription link" : "Копирај линк за претплату",
    "Copying link …" : "Линк се копира …",
    "Copied link" : "Линк је копиран",
    "Could not copy link" : "Линк није могао да се копира",
    "Export" : "Извези",
    "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
    "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
    "Trash bin" : "Корпа за отпатке",
    "Loading deleted items." : "Учитавање обрисаних ставки.",
    "You do not have any deleted items." : "Немате ниједну обрисану ставку.",
    "Name" : "Име",
    "Deleted" : "Обрисано",
    "Restore" : "Врати",
    "Delete permanently" : "Обриши заувек",
    "Empty trash bin" : "Испразни корпу за отпатке",
    "Untitled item" : "Неименована ставка",
    "Unknown calendar" : "Непознати календар",
    "Could not load deleted calendars and objects" : "Обрисани календари и објекти не могу да се учитају.",
    "Could not restore calendar or event" : "Календар или догађај није могао да се обнови",
    "Do you really want to empty the trash bin?" : "Да ли заиста желите да испразните корпу за отпатке?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Ставке у корпи за отпатке се бришу након {numDays} дана","Ставке у корпи за отпатке се бришу након {numDays} дана","Ставке у корпи за отпатке се бришу након {numDays} дана"],
    "Shared calendars" : "Дељени календари",
    "Deck" : "Deck",
    "Hidden" : "Сакривен",
    "Could not update calendar order." : "Није могао да се ажурира редослед календара.",
    "Internal link" : "Интерна веза",
    "A private link that can be used with external clients" : "Приватни линк који може да се користи са спољним клијентима",
    "Copy internal link" : "Копирај интерну везу",
    "Share link" : "Дели везу",
    "Copy public link" : "Копирај јавни линк",
    "Send link to calendar via email" : "Пошаљи и-мејлом линк на календар",
    "Enter one address" : "Унесите једну адресу",
    "Sending email …" : "И-мејл се шаље …",
    "Copy embedding code" : "Копирај кôд за уградњу",
    "Copying code …" : "Кôд се копира …",
    "Copied code" : "Кôд је копиран",
    "Could not copy code" : "Кôд није могао да се копира",
    "Delete share link" : "Обриши везу дељења",
    "Deleting share link …" : "Линк за дељење се брише …",
    "An error occurred, unable to publish calendar." : "Дошло је до грешке, календар не може да се објави.",
    "An error occurred, unable to send email." : "Дошло је до грешке, и-мејл не може да се пошаље.",
    "Embed code copied to clipboard." : "Кôд за уградњу је копиран у клипборд.",
    "Embed code could not be copied to clipboard." : "Кôд за уградњу није могао да се копира у клипборд.",
    "Unpublishing calendar failed" : "Није успео прекид објављивања календара",
    "can edit" : "може да мења",
    "Unshare with {displayName}" : "Уклони дељење са {displayName}",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Тим)",
    "An error occurred while unsharing the calendar." : "Дошло је до грешке приликом уклањања дељења календара.",
    "An error occurred, unable to change the permission of the share." : "Дошло је до грешке, не може да се измени дозвола дељења.",
    "Share with users or groups" : "Дели са корисницима или групама",
    "No users or groups" : "Нема корисника или група",
    "Calendar name …" : "Назив календара ...",
    "Never show me as busy (set this calendar to transparent)" : "Никад не приказуј статус заузет (поставља овај календар на транспарентно)",
    "Share calendar" : "Дели календар",
    "Unshare from me" : "Уклони дељење за мене",
    "Save" : "Сачувај",
    "Failed to save calendar name and color" : "Није успело чување назива календара и боје",
    "Import calendars" : "Увоз календара",
    "Please select a calendar to import into …" : "Молимо вас да изаберете календар у који се увози …",
    "Filename" : "Име фајла",
    "Calendar to import into" : "Календар у који се увози",
    "Cancel" : "Одустани",
    "_Import calendar_::_Import calendars_" : ["Увези календар","Увези календара","Увези календаре"],
    "Default attachments location" : "Подразумевана локација прилога",
    "Select the default location for attachments" : "Изаберите подразумевану локацију за прилоге",
    "Pick" : "Изаберите",
    "Invalid location selected" : "Изабрана је неисправна локација",
    "Attachments folder successfully saved." : "Фолдер за прилоге је успешно сачуван.",
    "Error on saving attachments folder." : "Грешка приликом чувања фолдера са додацима.",
    "{filename} could not be parsed" : "{filename} не може да се парсира",
    "No valid files found, aborting import" : "Нису пронађени исправни фајлови, увоз се прекида",
    "Import partially failed. Imported {accepted} out of {total}." : "Увоз делимично није био успешан. Увезено је {accepted} од {total} укупно.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n догађај је успешно увезен","%n догађаја је успешно увезено","%n догађаја је успешно увезено"],
    "Automatic" : "Аутоматски",
    "Automatic ({detected})" : "Аутоматски ({detected})",
    "New setting was not saved successfully." : "Ново подешавање није успешно сачувано.",
    "Shortcut overview" : "Преглед пречица",
    "or" : "или",
    "Navigation" : "Навигација",
    "Previous period" : "Претходни период",
    "Next period" : "Наредни период",
    "Views" : "Прикази",
    "Day view" : "Дневни приказ",
    "Week view" : "Недељни приказ",
    "Month view" : "Месечни приказ",
    "Year view" : "Годишњи приказ",
    "List view" : "Приказ листе",
    "Actions" : "Радње",
    "Create event" : "Креирај догађај",
    "Show shortcuts" : "Прикажи пречице",
    "Editor" : "Едитор",
    "Close editor" : "Затвори едитор",
    "Save edited event" : "Сачувај уређени догађај",
    "Delete edited event" : "Обриши уређени догађај",
    "Duplicate event" : "Дуплирај догађај",
    "Enable birthday calendar" : "Укључи календар рођендана",
    "Show tasks in calendar" : "Прикажи задатке у календару",
    "Enable simplified editor" : "Укључи поједностављени едитор",
    "Limit the number of events displayed in the monthly view" : "Ограничи број догађаја који се приказују у месечном приказу",
    "Show weekends" : "Прикажи викенде",
    "Show week numbers" : "Прикажи број седмице",
    "Time increments" : "Временски кораци",
    "Default calendar for incoming invitations" : "Подразумевани календар за долазеће позивнице",
    "Default reminder" : "Подразумевани подсетник",
    "Copy primary CalDAV address" : "Копирај примарну CalDAV адресу",
    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адресу",
    "Personal availability settings" : "Подешавања личне доступности",
    "Show keyboard shortcuts" : "Прикажи пречице тастатуре",
    "Calendar settings" : "Подешавања календара",
    "At event start" : "На почетку догађаја",
    "No reminder" : "Нема подсетника",
    "Failed to save default calendar" : "Није успело чување подразумеваног календара",
    "CalDAV link copied to clipboard." : "CalDAV линк је копиран у клипборд.",
    "CalDAV link could not be copied to clipboard." : "CalDAV линк није могао да се копира у клипборд.",
    "Appointment schedule successfully created" : "Успешно је креиран распоред састанка",
    "Appointment schedule successfully updated" : "Успешно је ажуриран распоред састанка",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минут","{duration} минута","{duration} минута"],
    "0 minutes" : "0 минута",
    "_{duration} hour_::_{duration} hours_" : ["{duration} сат","{duration} сата","{duration} сати"],
    "_{duration} day_::_{duration} days_" : ["{duration} дан","{duration} дана","{duration} дана"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} седмица","{duration} седмице","{duration} седмица"],
    "_{duration} month_::_{duration} months_" : ["{duration} месец","{duration} месеца","{duration} месеци"],
    "_{duration} year_::_{duration} years_" : ["{duration} година","{duration} године","{duration} година"],
    "To configure appointments, add your email address in personal settings." : "Да бисте подесили састанке, додајте своу и-мејл адресу у личним подешавањима.",
    "Public – shown on the profile page" : "Јавно – приказује се на страници профила",
    "Private – only accessible via secret link" : "Приватно – доступно само путем тајног линка",
    "Appointment name" : "Назив састанка",
    "Location" : "Локација",
    "Create a Talk room" : "Креирај Talk собу",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "За сваки заказани састанак ће се креирати јединствени линк који ће се послати и-мејлом за потврду",
    "Description" : "Опис",
    "Visibility" : "Видљивост",
    "Duration" : "Трајање",
    "Increments" : "Кораци",
    "Additional calendars to check for conflicts" : "Додатни календари у којима се проверавају конфликти",
    "Pick time ranges where appointments are allowed" : "Изаберите опсеге времена у којима су дозвољени састанци",
    "to" : "за",
    "Delete slot" : "Обриши термин",
    "No times set" : "Није постављено ниједно време",
    "Add" : "Додај",
    "Monday" : "Понедељак",
    "Tuesday" : "Уторак",
    "Wednesday" : "Среда",
    "Thursday" : "Четвртак",
    "Friday" : "Петак",
    "Saturday" : "Субота",
    "Sunday" : "Недеља",
    "Weekdays" : "Дани у недељи",
    "Add time before and after the event" : "Додај време пре и након догађаја",
    "Before the event" : "Пре догађаја",
    "After the event" : "Након догађаја",
    "Planning restrictions" : "Ограничења планирања",
    "Minimum time before next available slot" : "Минимално време пре наредног доступног термина",
    "Max slots per day" : "Максимални број термина у дану",
    "Limit how far in the future appointments can be booked" : "Ограничава колико далеко у будућност могу да се закажу састанци",
    "It seems a rate limit has been reached. Please try again later." : "Изгледа да је достигнуто ограничење учесталости. Молимо вас да касније покушајте поново.",
    "Appointment schedule saved" : "Сачуван је распоред састанка",
    "Create appointment schedule" : "Креирај распоред састанка",
    "Edit appointment schedule" : "Уреди распоред састанка",
    "Update" : "Ажурирај",
    "Please confirm your reservation" : "Молимо вас да потврдите своју резервацију",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Послали смо вам и-мејл са детаљима. Молимо вас да за потврђивање састанка употребите линк у и-мејлу. Сада можете да затворите ову страницу.",
    "Your name" : "Ваше име",
    "Your email address" : "Адреса Ваше е-поште",
    "Please share anything that will help prepare for our meeting" : "Молимо вас да поделите све што нам може помоћи у припреми нашег састанка",
    "Could not book the appointment. Please try again later or contact the organizer." : "Састанак није могао да се закаже. Молимо вас покушајте касније поново, или се обратите организатору.",
    "Back" : "Назад",
    "Book appointment" : "Закажи састанак",
    "Reminder" : "Подсетник",
    "before at" : "раније у",
    "Notification" : "Обавештење",
    "Email" : "Е-пошта",
    "Audio notification" : "Звучно обавештење",
    "Other notification" : "Друго обавештење",
    "Relative to event" : "Релативно у односу на догађај",
    "On date" : "Дана",
    "Edit time" : "Уреди време",
    "Save time" : "Сачувај време",
    "Remove reminder" : "Уклони подсетник",
    "on" : "дана",
    "at" : "у",
    "+ Add reminder" : "+ Додај подсетник",
    "Add reminder" : "Додавање подсетника",
    "_second_::_seconds_" : ["секунда","секунде","секунди"],
    "_minute_::_minutes_" : ["минут","минута","минута"],
    "_hour_::_hours_" : ["сат","сата","сати"],
    "_day_::_days_" : ["дан","дана","дана"],
    "_week_::_weeks_" : ["седмица","седмице","седмица"],
    "No attachments" : "Без прилога",
    "Add from Files" : "Додај из Фајлова",
    "Upload from device" : "Отпреми са уређаја",
    "Delete file" : "Обриши фајл",
    "Confirmation" : "Потврда",
    "Choose a file to add as attachment" : "Изаберите фајл за прилог",
    "Choose a file to share as a link" : "Одаберите фајл који желите да поделите као везу",
    "Attachment {name} already exist!" : "Прилог {name} веђ постоји!",
    "Could not upload attachment(s)" : "Не могу да се отпреме прилози",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Управо ћете да посетите {host}. Да ли желите да наставите? Линк: {link}",
    "Proceed" : "Настави",
    "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилога","{count} прилога"],
    "Invitation accepted" : "Позивница је прихваћена",
    "Available" : "Доступно",
    "Suggested" : "Предложени",
    "Participation marked as tentative" : "Пристуство је обележено као несигурно",
    "Accepted {organizerName}'s invitation" : "Позивница коју је послао {organizerName} је прихваћена",
    "Not available" : "Није доступно",
    "Invitation declined" : "Позивница је одбијена",
    "Declined {organizerName}'s invitation" : "Позивница коју је послао {organizerName} је одбијена",
    "Invitation is delegated" : "Позивница је прослеђена",
    "Checking availability" : "Провера доступности",
    "Awaiting response" : "Чека се одговор",
    "Has not responded to {organizerName}'s invitation yet" : "Још увек није одговорено на позивницу коју је послао {organizerName}",
    "Availability of attendees, resources and rooms" : "Доступност учесника, ресурса и соба",
    "Find a time" : "Пронађи време",
    "with" : "са",
    "Available times:" : "Времена доступности:",
    "Suggestion accepted" : "Сугестија је прихваћена",
    "Done" : "Завршено",
    "Select automatic slot" : "Изабери аутоматски термин",
    "chairperson" : "председавајући",
    "required participant" : "обавезни учесник",
    "non-participant" : "особа која није учесник",
    "optional participant" : "необавезни учесник",
    "{organizer} (organizer)" : "{organizer} (организатор)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Free" : "Слободан",
    "Busy (tentative)" : "Заузет (несигурно)",
    "Busy" : "Заузет",
    "Out of office" : "Ван канцеларије",
    "Unknown" : "Непознато",
    "Search room" : "Претражи собу",
    "Room name" : "Име собе",
    "Check room availability" : "Провери доступност собе",
    "Accept" : "Прихвати",
    "Decline" : "Одбиј",
    "Tentative" : "Условна потврда",
    "The invitation has been accepted successfully." : "Позивница је успешно прихваћена.",
    "Failed to accept the invitation." : "Није успело прихватање позивнице.",
    "The invitation has been declined successfully." : "Позивница је успешно одбијена.",
    "Failed to decline the invitation." : "Није успело одбијање позивнице.",
    "Your participation has been marked as tentative." : "Ваше учешће је означено као несигурно.",
    "Failed to set the participation status to tentative." : "Није успело постављање статуса учесника као несигуно.",
    "Attendees" : "Присутни",
    "Create Talk room for this event" : "Креирај Talk собу за овај догађај",
    "No attendees yet" : "Још увек нема учесника",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} позваних, {confirmedCount} потврдило",
    "Successfully appended link to talk room to location." : "У локацију је успешно додат линк на Talk собу.",
    "Successfully appended link to talk room to description." : "У опис је успешно додат линк на Talk собу.",
    "Error creating Talk room" : "Грешка приликом креирања Talk собе",
    "_%n more guest_::_%n more guests_" : ["још %n гост","још %n госта","још %n гостију"],
    "Request reply" : "Захтевај одговор",
    "Chairperson" : "Председавајући",
    "Required participant" : "Обавезни учесник",
    "Optional participant" : "Необавезни учесник",
    "Non-participant" : "Особа која није учесник",
    "Remove group" : "Уклони групу",
    "Remove attendee" : "Уклони учесника",
    "_%n member_::_%n members_" : ["%n члан","%n члана","%n чланова"],
    "Search for emails, users, contacts, teams or groups" : "Претрага и-мејлова, корисника, контакта, тимова или група",
    "No match found" : "Нема подударања",
    "Note that members of circles get invited but are not synced yet." : "Чланови кругова се позивају али се још увек не синхронизују.",
    "Note that members of contact groups get invited but are not synced yet." : "Чланови група контаката се позивају али се још увек не синхронизују.",
    "(organizer)" : "(организатор)",
    "Make {label} the organizer" : "Учини {label} организатором",
    "Make {label} the organizer and attend" : "Учини {label} организатором и учествуј",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Да бисте слали позивнице и обрађивали одговоре, [linkopen]додајте своју и-мејл адресу у своја лична подешавања[linkclose].",
    "Remove color" : "Уклони боју",
    "Event title" : "Назив догађаја",
    "From" : "Од",
    "To" : "За",
    "All day" : "Цео дан",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Подешавање трајања цео дан не може да се измени за догађаје који су део скупа догађаја који се понављају.",
    "Repeat" : "Понављај",
    "End repeat" : "Заврши понављање",
    "Select to end repeat" : "Изаберите да бисте завршили понављање",
    "never" : "никада",
    "on date" : "дана",
    "after" : "након",
    "_time_::_times_" : ["време","времена","времена"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Овај догађај је изузетак од понављања у скупу понављајућих догађаја. Њему не може да се додели правило понављања.",
    "first" : "прва",
    "third" : "трећи",
    "fourth" : "четврти",
    "fifth" : "пети",
    "second to last" : "претпоследњи",
    "last" : "последња",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Измене правила понављања ће се применити само на ово и на сва будућа појављивања.",
    "Repeat every" : "Понављај сваки",
    "By day of the month" : "По дану у месецу",
    "On the" : "На",
    "_month_::_months_" : ["месец","месеца","месеци"],
    "_year_::_years_" : ["година","године","година"],
    "weekday" : "дан у недељи",
    "weekend day" : "дан викенда",
    "Does not repeat" : "Не понавља се",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud не подржава у потпуности дефиницију понављања овог догађаја. Ако уредите опције понављања, могуће је да ће се нека понављања изгубити.",
    "Suggestions" : "Предлози",
    "No rooms or resources yet" : "Још увек нема соба или ресурса",
    "Add resource" : "Додај ресурс",
    "Has a projector" : "Поседује пројектор",
    "Has a whiteboard" : "Поседује таблу",
    "Wheelchair accessible" : "Приступ инвалидским колицима",
    "Remove resource" : "Уклони ресурс",
    "Show all rooms" : "Прикажи све собе",
    "Projector" : "Пројектор",
    "Whiteboard" : "Табла",
    "Search for resources or rooms" : "Претрага ресурса или соба",
    "available" : "доступно",
    "unavailable" : "није доступно",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} седиште","{seatingCapacity} седишта","{seatingCapacity} седишта"],
    "Room type" : "Тип собе",
    "Any" : "Било који",
    "Minimum seating capacity" : "Минимални број места за седење",
    "More details" : "Још детаља",
    "Update this and all future" : "Ажурирај ово и сва будућа",
    "Update this occurrence" : "Ажурирај ово појављивање",
    "Public calendar does not exist" : "Јавни календар не постоји",
    "Maybe the share was deleted or has expired?" : "Можда је дељење обрисано или истекло?",
    "Select a time zone" : "Изаберите временску зону",
    "Please select a time zone:" : "Молимо вас да изаберете временску зону:",
    "Pick a time" : "Изаберите време",
    "Pick a date" : "Изаберите датум",
    "from {formattedDate}" : "од {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "дана {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "од {formattedDate} у {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} у {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "дана {formattedDate} у {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} у {formattedTime}",
    "Please enter a valid date" : "Молимо вас да унесете исправни датум",
    "Please enter a valid date and time" : "Молимо вас да унесете исправни датум и време",
    "Type to search time zone" : "Куцајте да потражите временску зону",
    "Global" : "Цео свет",
    "Public holiday calendars" : "Календари државних празника",
    "Public calendars" : "Јавни календари",
    "No valid public calendars configured" : "Није подешен ниједан исправан јавни календар",
    "Speak to the server administrator to resolve this issue." : "Да бисте решили овај проблем, разговарајте са администратором сервера.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Календаре државних празника обезбеђује Thunderbird. Подаци за календар ће да се преузму са {website}",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Администратор сервера предлаже ове јавне календаре. Подаци за календар ће се преузети са одговарајућег веб сајта.",
    "By {authors}" : "Урадили {authors}",
    "Subscribed" : "Претплаћен",
    "Subscribe" : "Претплати се",
    "Holidays in {region}" : "Празници у {region}",
    "An error occurred, unable to read public calendars." : "Дошло је до грешке, не могу да се прочитају јавни календари.",
    "An error occurred, unable to subscribe to calendar." : "Дошло је до грешке, не може да се претплати на календар.",
    "Select a date" : "Изаберите датум",
    "Select slot" : "Изаберите термин",
    "No slots available" : "Нема доступних термина",
    "Could not fetch slots" : "Не могу да се добаве термини",
    "The slot for your appointment has been confirmed" : "Термин за ваш састанак је потврђен",
    "Appointment Details:" : "Детаљи састанка:",
    "Time:" : "Време:",
    "Booked for:" : "Резервисано за:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Хвала вам. Ваша резервација од {startDate} до {endDate} је потврђена.",
    "Book another appointment:" : "Резервишите још један састанак:",
    "See all available slots" : "Погледајте све доступне термине",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Термин за ваш састанак од {startDate} до {endDate} више није слободан.",
    "Please book a different slot:" : "Молимо вас да резервишете други термин:",
    "Book an appointment with {name}" : "Резервиши састанак са {name}",
    "No public appointments found for {name}" : "Није пронађен ниједан јавни састанак са {name}",
    "Personal" : "Лично",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Аутоматска детекција временске зоне је одредила да је ваша временска зона UTC.\nОво је највероватније последица безбедносних мера у вашем веб прегледачу.\nМолимо вас да ручно подесите своју временску зону у подешавањима календара.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Није пронађена временска зона ({timezoneId}) коју сте подесили. Стога се поставља на UTC.\nМолимо вас да промените своју временску зону у подешавањима и пријавите проблем.",
    "Event does not exist" : "Догађај не постоји",
    "Duplicate" : "Дупликат",
    "Delete this occurrence" : "Обриши ово појављивање",
    "Delete this and all future" : "Обриши ово и сва будућа",
    "Details" : "Детаљи",
    "Managing shared access" : "Управљање дељеним приступом",
    "Deny access" : "Одбиј приступ",
    "Invite" : "Позив",
    "Resources" : "Ресурси",
    "_User requires access to your file_::_Users require access to your file_" : ["Корисник тражи приступ вашем фајлу","Корисника траже приступ вашем фајлу","Корисника тражи приступ вашем фајлу"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог тражи дељени приступ","Прилога траже дељени приступ","Прилога тражи дељени приступ"],
    "Close" : "Затвори",
    "Untitled event" : "Неименовани догађај",
    "Subscribe to {name}" : "Претплати се на {name}",
    "Export {name}" : "Извези {name}",
    "Anniversary" : "Годишњица",
    "Appointment" : "Састанак",
    "Business" : "Посао",
    "Education" : "Образовање",
    "Holiday" : "Одмор",
    "Meeting" : "Састанак",
    "Miscellaneous" : "Разно",
    "Non-working hours" : "Нерадни сати",
    "Not in office" : "Ван канцеларије",
    "Phone call" : "Телефонски позив",
    "Sick day" : "Боловање",
    "Special occasion" : "Посебна прилика",
    "Travel" : "Путовање",
    "Vacation" : "Летовање",
    "Midnight on the day the event starts" : "Поноћ на дан почетка догађаја",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n дан пре догађаја у {formattedHourMinute}","%n дана пре догађаја у {formattedHourMinute}","%n дана пре догађаја у {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n седмица пре догађаја у {formattedHourMinute}","%n седмице пре догађаја у {formattedHourMinute}","%n седмица пре догађаја у {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "на дан догађаја у {formattedHourMinute}",
    "at the event's start" : "на почетку догађаја",
    "at the event's end" : "на крају догађаја",
    "{time} before the event starts" : "{time} пре почетка догађаја",
    "{time} before the event ends" : "{time} пре краја догађаја",
    "{time} after the event starts" : "{time} након почетка догађаја",
    "{time} after the event ends" : "{time} након краја догађаја",
    "on {time}" : "у {time}",
    "on {time} ({timezoneId})" : "у {time} ({timezoneId})",
    "Week {number} of {year}" : "Недеља {number} у {year}",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "Monthly" : "Месечно",
    "Yearly" : "Годишње",
    "_Every %n day_::_Every %n days_" : ["Сваки %n дан","Свака %n дана","Сваких %n дана"],
    "_Every %n week_::_Every %n weeks_" : ["Сваку %n седмицу","Сваке %n седмице","Сваких %n седмица"],
    "_Every %n month_::_Every %n months_" : ["Сваки %n месец","Свака %n месеца","Сваких %n месеци"],
    "_Every %n year_::_Every %n years_" : ["Сваку %n годину","Сваке %n године","Сваких %n година"],
    "_on {weekday}_::_on {weekdays}_" : ["у {weekday}","у {weekdays}","у {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на дан {dayOfMonthList}","на дане {dayOfMonthList}","на дане {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "у {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "у {monthNames} на {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n пут","%n пута","%n пута"],
    "Untitled task" : "Неименовани задатак",
    "Please ask your administrator to enable the Tasks App." : "Молимо вас да замолите свог администратора да укључи апликацију Задаци.",
    "W" : "С",
    "%n more" : "Још %n",
    "No events to display" : "Нема више догађаја за приказ",
    "_+%n more_::_+%n more_" : ["+%n још","+%n још","+%n још"],
    "No events" : "Нема догађаја",
    "Create a new event or change the visible time-range" : "Креирање новог догађаја или измена временског опсега видљивости",
    "Failed to save event" : "Није успело чување догађаја",
    "It might have been deleted, or there was a typo in a link" : "Можда је обрисан, или је било грешке у куцању линка",
    "It might have been deleted, or there was a typo in the link" : "Можда је обрисан, или је било грешке у куцању линка",
    "Meeting room" : "Соба за састанке",
    "Lecture hall" : "Хала за предавања",
    "Seminar room" : "Соба за семинаре",
    "Other" : "Остало",
    "When shared show" : "Када се дели, прикажи",
    "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
    "When shared show only busy" : "Прикажи само да сте заузети када је догађај дељен",
    "When shared hide this event" : "Сакриј догађај када је догађај дељен",
    "The visibility of this event in shared calendars." : "Видљивост овог догађаја у дељеним календарима.",
    "Add a location" : "Додај локацију",
    "Add a description" : "Додај опис",
    "Status" : "Статус",
    "Confirmed" : "Потврђен",
    "Canceled" : "Отказано",
    "Confirmation about the overall status of the event." : "Потврда о свеобухватном статусу догађаја.",
    "Show as" : "Прикажи као",
    "Take this event into account when calculating free-busy information." : "Узми у обзир овај догађај када се одређује информација слободан-заузет.",
    "Categories" : "Категорије",
    "Categories help you to structure and organize your events." : "Категорије вам помажу да класификујете и организујете своје догађаје.",
    "Search or add categories" : "Претражи или додај категорије",
    "Add this as a new category" : "Додај ово као нову категорију",
    "Custom color" : "Прилагођена боја",
    "Special color of this event. Overrides the calendar-color." : "Посебна боја овог догађаја. Преиначује боју календара.",
    "Error while sharing file" : "Грешка приликом дељења фајла",
    "Error while sharing file with user" : "Грешка приликом дељења фајла са корисником",
    "Attachment {fileName} already exists!" : "Прилог {fileName} већ постоји!",
    "An error occurred during getting file information" : "Дошло је до грешке током преузимања информација о фајлу",
    "Chat room for event" : "Чет соба за догађај",
    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
    "Imported {filename}" : "Увезен {filename}",
    "This is an event reminder." : "Ово је подсетник за догађај.",
    "Error while parsing a PROPFIND error" : "Грешка приликом парсирања PROPFIND грешке",
    "Appointment not found" : "Састанак није пронађен",
    "User not found" : "Корисник није нађен",
    "Default calendar for invitations and new events" : "Подразумевани календар за позивнице и нове догађаје",
    "Appointment was created successfully" : "Састанак је успешно креиран",
    "Appointment was updated successfully" : "Састанак је успешно ажуриран",
    "Create appointment" : "Креирај састанак",
    "Edit appointment" : "Уреди састанак",
    "Book the appointment" : "Резервиши састанак",
    "You do not own this calendar, so you cannot add attendees to this event" : "Ово није ваш календар, тако да немате права да додате учеснике у овај догађај",
    "Search for emails, users, contacts or groups" : "Претражи и-мејлове, кориснике, контакте или групе",
    "Select date" : "Изаберите датум",
    "Create a new event" : "Креирај нови догађај",
    "[Today]" : "[Данас]",
    "[Tomorrow]" : "[Сутра]",
    "[Yesterday]" : "[Јуче]",
    "[Last] dddd" : "[Последњи] dddd"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
