OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s avaldas kalendri »%s«",
    "Hello," : "Tere,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
    "Open »%s«" : "Ava »%s«",
    "Cheers!" : "Tervist!",
    "Upcoming events" : "Tulekul sündmused",
    "No more events today" : "Täna rohkem sündmuseid pole",
    "No upcoming events" : "Tulekul sündmuseid pole",
    "More events" : "Rohkem sündmuseid",
    "Calendar" : "Kalender",
    "Confirm" : "Kinnita",
    "Description:" : "Kirjeldus:",
    "Date:" : "Kuupäev:",
    "Where:" : "Kus:",
    "Comment:" : "Kommentaar:",
    "Previous day" : "Eelmine päev",
    "Previous week" : "Eelmine nädal",
    "Previous year" : "Eelmine aasta",
    "Previous month" : "Eelmine kuu",
    "Next day" : "Järgmine päev",
    "Next week" : "Järgmine nädal",
    "Next year" : "Järgmine aasta",
    "Next month" : "Järgmine kuu",
    "Event" : "Sündmus",
    "Create new event" : "Lisa uus sündmus",
    "Today" : "Täna",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Year" : "Aasta",
    "List" : "Nimekiri",
    "Preview" : "Eelvaade",
    "Copy link" : "Kopeeri link",
    "Edit" : "Redigeeri",
    "Delete" : "Kustuta",
    "Untitled calendar" : "Nimetu kalender",
    "Edit calendar" : "Muuda kalendrit",
    "Calendars" : "Kalendrid",
    "Add new" : "Lisa uus",
    "New calendar" : "Uus kalender",
    "Export" : "Ekspordi",
    "Trash bin" : "Prügikast",
    "Name" : "Nimi",
    "Deleted" : "Kustutatud",
    "Restore" : "Taasta",
    "Delete permanently" : "Kustuta jäädavalt",
    "Empty trash bin" : "Tühjenda prügikast",
    "Hidden" : "Peidetud",
    "Internal link" : "Sisemine link",
    "Copy internal link" : "Kopeeri sisemine link",
    "Share link" : "Jaga link",
    "Copy public link" : "Kopeeri avalik link",
    "Delete share link" : "Kustuta jagamise link",
    "can edit" : "saab muuta",
    "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "Save" : "Salvesta",
    "Import calendars" : "Impordi kalendrid",
    "Filename" : "Faili nimi",
    "Cancel" : "Loobu",
    "Invalid location selected" : "Vigane asukoht valitud",
    "Automatic" : "Automaatne",
    "Previous period" : "Eelmine periood",
    "Next period" : "Järgmine periood",
    "Views" : "Vaated",
    "Day view" : "Päeva vaade",
    "Week view" : "Nädala vaade",
    "Month view" : "Kuu vaade",
    "Year view" : "Aasta vaade",
    "List view" : "Nimekirjavaade",
    "Actions" : "Tegevused",
    "Create event" : "Lisa sündmus",
    "Show week numbers" : "Näita nädalanumberid",
    "Calendar settings" : "Kalendri seaded",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minutit"],
    "0 minutes" : "0 minutit",
    "_{duration} hour_::_{duration} hours_" : ["{duration} tund","{duration} tundi"],
    "_{duration} day_::_{duration} days_" : ["{duration} päev","{duration} päeva"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} nädal","{duration} nädalat"],
    "_{duration} month_::_{duration} months_" : ["{duration} kuu","{duration} kuud"],
    "_{duration} year_::_{duration} years_" : ["{duration} aasta","{duration} aastat"],
    "Location" : "Asukoht",
    "Description" : "Kirjeldus",
    "Visibility" : "Nähtavus",
    "Duration" : "Kestus",
    "to" : "saaja",
    "Add" : "Lisa",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sunday" : "Pühapäev",
    "Update" : "Uuenda",
    "Your email address" : "Sinu e-posti aadress",
    "Notification" : "Teavitus",
    "Email" : "E-post",
    "On date" : "Kuupäeval",
    "_second_::_seconds_" : ["sekund","sekundit"],
    "_minute_::_minutes_" : ["minut","minutit"],
    "_hour_::_hours_" : ["tund","tundi"],
    "_day_::_days_" : ["päev","päeva"],
    "_week_::_weeks_" : ["nädal","nädalat"],
    "No attachments" : "Manuseid pole",
    "Add from Files" : "Lisa failidest",
    "Upload from device" : "Laadi üles seadmest",
    "Delete file" : "Kustuta fail",
    "Choose a file to add as attachment" : "Vali fail, mida manustada",
    "Attachment {name} already exist!" : "Manus {name} on juba olemas!",
    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
    "Done" : "Valmis",
    "Unknown" : "Teadmata",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Tentative" : "Esialgne",
    "Attendees" : "Osalejad",
    "Remove group" : "Eemalda grupp",
    "From" : "Saatja",
    "To" : "Saaja",
    "All day" : "Kogu päev",
    "Repeat" : "Korda",
    "never" : "mitte kunagi",
    "after" : "pärast",
    "_month_::_months_" : ["kuu","kuud"],
    "Does not repeat" : "Ei kordu",
    "Global" : "Üldine",
    "Subscribe" : "Telli",
    "Personal" : "Isiklik",
    "Details" : "Üksikasjad",
    "Resources" : "Ressursid",
    "Close" : "Sulge",
    "Anniversary" : "Aastapäev",
    "Appointment" : "Kohtumine",
    "Vacation" : "Puhkus",
    "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
    "Daily" : "Iga päev",
    "Weekly" : "Iga nädal",
    "Monthly" : "Igakuine",
    "Yearly" : "Igaastane",
    "Other" : "Muu",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Status" : "Staatus",
    "Confirmed" : "Kinnitatud",
    "Categories" : "Kategooriad",
    "User not found" : "Kasutajat ei leitud"
},
"nplurals=2; plural=(n != 1);");
