OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Awitay",
    "Confirm" : "Serggeg",
    "Today" : "Ass-a",
    "Copy link" : "Nɣel aseɣwen",
    "Edit" : "Ẓreg",
    "Delete" : "Kkes",
    "Create new" : "Rnu tura",
    "Name" : "Nom",
    "Deleted" : "Yettwakkes",
    "Share link" : "Fren aseɣwen",
    "Save" : "Sekles",
    "Filename" : "Isem n ufaylu",
    "Cancel" : "Sefsex",
    "List view" : "Timeẓri n tebdart",
    "Location" : "Adig",
    "Add" : "Rnu",
    "Back" : "Retour",
    "Notification" : "Alɣu",
    "Email" : "Imayl",
    "Proceed" : "Kemmel",
    "Done" : "Immed",
    "Unknown" : "Arussin",
    "Personal" : "Udmawan",
    "Details" : "Talqayt",
    "Close" : "Mdel",
    "Daily" : "S wass",
    "Weekly" : "S umalas",
    "Other" : "Wayeḍ",
    "Status" : "État"
},
"nplurals=2; plural=(n != 1);");
