OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Eingegebene E-Mail-Adresse ist zu lang",
    "User-Session unexpectedly expired" : "Sitzung unerwartet abgelaufen",
    "Provided email-address is not valid" : "Angegebene E-Mail-Adresse ist ungültig",
    "%s has published the calendar »%s«" : "%s hat den Kalender »%s« veröffentlicht",
    "Unexpected error sending email. Please contact your administrator." : "Unerwarteter Fehler beim Senden der E-Mail. Bitte kontaktieren Sie den Administrator.",
    "Successfully sent email to %1$s" : "E-Mail erfolgreich versandt an %1$s",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Information: %s hat den Kalender »%s« veröffentlicht.",
    "Open »%s«" : "»%s« öffnen",
    "Cheers!" : "Noch einen schönen Tag!",
    "Upcoming events" : "Anstehende Termine",
    "No more events today" : "Heute keine weiteren Termine",
    "No upcoming events" : "Keine anstehenden Termine",
    "More events" : "Weitere Termine",
    "%1$s with %2$s" : "%1$s mit %2$s",
    "Calendar" : "Kalender",
    "New booking {booking}" : "Neue Buchung {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) hat den Termin \"{config_display_name}\" am {date_time} gebucht.",
    "Appointments" : "Termine",
    "Schedule appointment \"%s\"" : "Termin planen \"%s\"",
    "Schedule an appointment" : "Vereinbaren Sie einen Termin",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Vorbereitung auf %s",
    "Follow up for %s" : "Nachbereitung für %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Für Ihre Terminvereinbarung \"%s\" mit %s steht die Bestätigung noch aus.",
    "Dear %s, please confirm your booking" : "Sehr geehrte/r %s, bitte bestätigen Sie die Terminbuchung",
    "Confirm" : "Bestätigen",
    "Appointment with:" : "Termin mit:",
    "Description:" : "Beschreibung:",
    "This confirmation link expires in %s hours." : "Dieser Bestätigungslink läuft in %s Stunden ab.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Wenn Sie den Termin dennoch stornieren möchten, wenden Sie sich bitte an Ihren Organisator, indem Sie auf diese E-Mail antworten oder dessen Profilseite besuchen.",
    "Your appointment \"%s\" with %s has been accepted" : "Ihre Terminvereinbarung \"%s\" mit %s wurde angenommen.",
    "Dear %s, your booking has been accepted." : "Hallo %s, Ihre Buchung wurde akzeptiert.",
    "Appointment for:" : "Termin für:",
    "Date:" : "Datum:",
    "You will receive a link with the confirmation email" : "Mit der Bestätigungs-E-Mail erhalten Sie einen Link",
    "Where:" : "Wo:",
    "Comment:" : "Kommentar:",
    "You have a new appointment booking \"%s\" from %s" : "Sie haben eine neue Terminbuchung \"%s\" von %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Hallo %s, %s (%s) hat einen Termin mit Ihnen gebucht.",
    "A Calendar app for Nextcloud" : "Eine Kalender-App für Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Die Calendar-App ist die Oberfläche für Nextclouds CalDAV-Server. Termine können auf einfache Weise über verschiedene Geräte hinweg mit Nextcloud synchronisiert und online bearbeitet werden.\n\n* 🚀 ** Integration mit anderen Nextcloud Apps!** Aktuell Kontakte - weitere folgen.\n* 🌐 **WebCal-Unterstützung!** Möchten Sie die Spieltage Ihres Lieblingsteams in Ihrem Kalender verfolgen? Kein Problem!\n* 🙋 **Teilnehmer!** Laden Sie Teilnehmer zu Ihren Terminen ein.\n* ⌚️ **Frei/Besetzt:** Sehen Sie, wann Ihre Teilnehmer für ein Treffen verfügbar sind\n* ⏰ **Erinnerungen!** Erhalten Sie Alarme für Termine innerhalb Ihres Browsers und per E-Mail.\n* 🔍 Suche! Finden Sie Ihre Termine ganz einfach\n* ☑️ Aufgaben! Sehen Sie Ihre Aufgaben mit Fälligkeitsdatum direkt in Ihrem Kalender\n* 🙈 **Wir erfinden das Rad nicht neu!** Die App basiert auf den großartigen [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) und [fullcalendar](https://github.com/fullcalendar/fullcalendar) Bibliotheken.",
    "Previous day" : "Vorheriger Tag",
    "Previous week" : "Vorherige Woche",
    "Previous year" : "Vergangenes Jahr",
    "Previous month" : "Vorheriger Monat",
    "Next day" : "Nächster Tag",
    "Next week" : "Nächste Woche",
    "Next year" : "Nächstes Jahr",
    "Next month" : "Nächster Monat",
    "Event" : "Ereignis",
    "Create new event" : "Neuen Termin erstellen",
    "Today" : "Heute",
    "Day" : "Tag",
    "Week" : "Woche",
    "Month" : "Monat",
    "Year" : "Jahr",
    "List" : "Liste",
    "Preview" : "Vorschau",
    "Copy link" : "Link kopieren",
    "Edit" : "Bearbeiten",
    "Delete" : "Löschen",
    "Appointment link was copied to clipboard" : "Termin-Link wurde in die Zwischenablage kopiert",
    "Appointment link could not be copied to clipboard" : "Termin-Link konnte nicht in die Zwischenablage kopiert werden",
    "Appointment schedules" : "Terminpläne",
    "Create new" : "Neu erstellen",
    "Untitled calendar" : "Unbenannter Kalender",
    "Shared with you by" : "Mit Ihnen geteilt von",
    "Edit and share calendar" : "Kalender bearbeiten und teilen",
    "Edit calendar" : "Kalender bearbeiten",
    "Disable calendar \"{calendar}\"" : "Kalender \"{calendar}\" deaktivieren",
    "Disable untitled calendar" : "Kalender ohne Titel deaktivieren",
    "Enable calendar \"{calendar}\"" : "Kalender \"{calendar}\" aktivieren",
    "Enable untitled calendar" : "Kalender ohne Titel aktivieren",
    "An error occurred, unable to change visibility of the calendar." : "Es ist ein Fehler aufgetreten, die Sichtbarkeit des Kalenders konnte nicht geändert werden.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalenderfreigabe wird in {countdown} Sekunde beendet","Kalenderfreigabe wird in {countdown} Sekunden beendet"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalender wird in {countdown} Sekunden gelöscht","Kalender wird in {countdown} Sekunden gelöscht"],
    "Calendars" : "Kalender",
    "Add new" : "Neu hinzufügen",
    "New calendar" : "Neuer Kalender",
    "Name for new calendar" : "Name für neuen Kalender",
    "Creating calendar …" : "Erstelle Kalender …",
    "New calendar with task list" : "Neuer Kalender mit Aufgabenliste",
    "New subscription from link (read-only)" : "Neues Abonnement aus Link (schreibgeschützt)",
    "Creating subscription …" : "Erstelle Abonnement …",
    "Add public holiday calendar" : "Feiertagskalender hinzufügen",
    "Add custom public calendar" : "Benutzerdefinierten öffentlichen Kalender hinzufügen",
    "An error occurred, unable to create the calendar." : "Es ist ein Fehler aufgetreten, der Kalender konnte nicht erstellt werden.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Bitte geben Sie einen gültigen Link ein (beginnend mit http://, https://, webcal://, oder webcals://)",
    "Copy subscription link" : "Abonnement-Link kopieren",
    "Copying link …" : "Link wird kopiert …",
    "Copied link" : "Link kopiert",
    "Could not copy link" : "Link konnte nicht kopiert werden",
    "Export" : "Exportieren",
    "Calendar link copied to clipboard." : "Kalender-Link in die Zwischenablage kopiert.",
    "Calendar link could not be copied to clipboard." : "Kalender-Link konnte nicht in die Zwischenablage kopiert werden.",
    "Trash bin" : "Papierkorb",
    "Loading deleted items." : "Lade gelöschte Elemente.",
    "You do not have any deleted items." : "Sie haben keine gelöschten Elemente.",
    "Name" : "Name",
    "Deleted" : "Gelöscht",
    "Restore" : "Wiederherstellen",
    "Delete permanently" : "Endgültig löschen",
    "Empty trash bin" : "Papierkorb leeren",
    "Untitled item" : "Eintrag ohne Namen",
    "Unknown calendar" : "Unbekannter Kalender",
    "Could not load deleted calendars and objects" : "Gelöschte Kalender und Objekte konnten nicht geladen werden",
    "Could not restore calendar or event" : "Kalender oder Termin konnte nicht wiederhergestellt werden",
    "Do you really want to empty the trash bin?" : "Möchten Sie wirklich den Papierkorb leeren?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Elemente im Papierkorb werden nach {numDays} Tag gelöscht","Elemente im Papierkorb werden nach {numDays} Tagen gelöscht"],
    "Shared calendars" : "Freigegebene Kalender",
    "Deck" : "Deck",
    "Hidden" : "Verborgen",
    "Could not update calendar order." : "Kalenderreihenfolge konnte nicht aktualisiert werden.",
    "Internal link" : "Interner Link",
    "A private link that can be used with external clients" : "Ein privater Link, der mit externen Clients verwendet werden kann",
    "Copy internal link" : "Internen Link kopieren",
    "Share link" : "Link teilen",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Send link to calendar via email" : "Link zum Kalender als E-Mail verschicken",
    "Enter one address" : "Eine einzige Adresse eingeben",
    "Sending email …" : "Sende E-Mail …",
    "Copy embedding code" : "Einbettungscode kopieren",
    "Copying code …" : "Kopiere Code …",
    "Copied code" : "Code kopiert",
    "Could not copy code" : "Code konnte nicht kopiert werden",
    "Delete share link" : "Freigabe-Link löschen",
    "Deleting share link …" : "Freigabe-Link löschen …",
    "An error occurred, unable to publish calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht veröffentlicht werden.",
    "An error occurred, unable to send email." : "Es ist ein Fehler aufgetreten, E-Mail konnte nicht versandt werden.",
    "Embed code copied to clipboard." : "Einbettungscode in die Zwischenablage kopiert.",
    "Embed code could not be copied to clipboard." : "Einbettungscode konnte nicht in die Zwischenablage kopiert werden.",
    "Unpublishing calendar failed" : "Aufhebung der Veröffentlichung des Kalenders fehlgeschlagen",
    "can edit" : "kann bearbeiten",
    "Unshare with {displayName}" : "Mit {displayName} nicht mehr teilen",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Es ist ein Fehler beim Aufheben der Freigabe des Kalenders aufgetreten.",
    "An error occurred, unable to change the permission of the share." : "Es ist ein Fehler aufgetreten, die Berechtigung für die Freigabe konnte nicht geändert werden.",
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "No users or groups" : "Keine Benutzer oder Gruppen",
    "Calendar name …" : "Kalendername …",
    "Never show me as busy (set this calendar to transparent)" : "Mich nie als beschäftigt anzeigen (diesen Kalender auf transparent setzen)",
    "Share calendar" : "Kalender teilen",
    "Unshare from me" : "Nicht mehr mit mir teilen",
    "Save" : "Speichern",
    "Failed to save calendar name and color" : "Fehler beim Speichern von Kalendername und -farbe",
    "Import calendars" : "Kalender importieren",
    "Please select a calendar to import into …" : "Bitte wählen Sie einen Kalender aus, in den importiert werden soll …",
    "Filename" : "Dateiname",
    "Calendar to import into" : "Kalender in den importiert werden soll.",
    "Cancel" : "Abbrechen",
    "_Import calendar_::_Import calendars_" : ["Kalender importieren","Kalender importieren"],
    "Default attachments location" : "Standard-Speicherort für Anhänge",
    "Select the default location for attachments" : "Standard-Speicherort für Anhänge auswählen",
    "Pick" : "Auswählen",
    "Invalid location selected" : "Ungültigen Speicherort ausgewählt",
    "Attachments folder successfully saved." : "Anhangsordner gespeichert.",
    "Error on saving attachments folder." : "Fehler beim Speichern des Anhangsordners.",
    "{filename} could not be parsed" : "{filename} konnte nicht analysiert werden",
    "No valid files found, aborting import" : "Keine gültige Dateien gefunden, Import wird abgebrochen.",
    "Import partially failed. Imported {accepted} out of {total}." : "Der Import ist teilweise fehlgeschlagen. {accepted} von {total} importiert.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Erfolgreich %n Termin importiert","Erfolgreich %n Termine importiert"],
    "Automatic" : "Automatisch",
    "Automatic ({detected})" : "Automatisch ({detected})",
    "New setting was not saved successfully." : "Neue Einstellung konnte nicht gespeichert werden.",
    "Shortcut overview" : "Übersicht der Tastaturkürzel",
    "or" : "oder",
    "Navigation" : "Navigation",
    "Previous period" : "Vorherige Zeitspanne",
    "Next period" : "Nächste Zeitspanne",
    "Views" : "Ansichten",
    "Day view" : "Tagesansicht",
    "Week view" : "Wochenansicht",
    "Month view" : "Monatsansicht",
    "Year view" : "Jahresansicht",
    "List view" : "Listenansicht",
    "Actions" : "Aktionen",
    "Create event" : "Termin erstellen",
    "Show shortcuts" : "Tastaturkürzel anzeigen",
    "Editor" : "Editor",
    "Close editor" : "Bearbeitung schließen",
    "Save edited event" : "Bearbeiteten Termin speichern",
    "Delete edited event" : "Bearbeiteten Termin löschen",
    "Duplicate event" : "Termin duplizieren",
    "Enable birthday calendar" : "Geburtstagskalender aktivieren",
    "Show tasks in calendar" : "Aufgaben im Kalender anzeigen",
    "Enable simplified editor" : "Einfachen Editor aktivieren",
    "Limit the number of events displayed in the monthly view" : "Begrenzung der Anzahl der in der Monatsansicht angezeigten Termine",
    "Show weekends" : "Wochenenden anzeigen",
    "Show week numbers" : "Kalenderwochen anzeigen",
    "Time increments" : "Zeitschritte",
    "Default calendar for incoming invitations" : "Standardkalender für Einladungen und neue Termine",
    "Default reminder" : "Standarderinnerung",
    "Copy primary CalDAV address" : "Primäre CalDAV-Adresse kopieren",
    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV-Adresse kopieren",
    "Personal availability settings" : "Persönliche Verfügbarkeitseinstellungen",
    "Show keyboard shortcuts" : "Tastaturkürzel anzeigen",
    "Calendar settings" : "Kalender-Einstellungen",
    "At event start" : "Zu Beginn des Termins",
    "No reminder" : "Keine Erinnerung",
    "Failed to save default calendar" : "Fehler beim Speichern des Standardkalenders",
    "CalDAV link copied to clipboard." : "CalDAV-Link in die Zwischenablage kopiert.",
    "CalDAV link could not be copied to clipboard." : "CalDAV-Link konnte nicht in die Zwischenablage kopiert werden.",
    "Appointment schedule successfully created" : "Terminplan wurde erstellt",
    "Appointment schedule successfully updated" : "Terminplan wurde aktualisiert",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} Minute","{duration} Minuten"],
    "0 minutes" : "0 Minuten",
    "_{duration} hour_::_{duration} hours_" : ["{duration} Stunde","{duration} Stunden"],
    "_{duration} day_::_{duration} days_" : ["{duration} Tag","{duration} Tage"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} Woche","{duration} Wochen"],
    "_{duration} month_::_{duration} months_" : ["{duration} Monat","{duration} Monate"],
    "_{duration} year_::_{duration} years_" : ["{duration} Jahr","{duration} Jahre"],
    "To configure appointments, add your email address in personal settings." : "Um Termine zu vereinbaren, fügen Sie Ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu.",
    "Public – shown on the profile page" : "Öffentlich – auf der Profilseite angezeigt",
    "Private – only accessible via secret link" : "Privat – nur über geheimen Link erreichbar",
    "Appointment name" : "Terminname",
    "Location" : "Ort",
    "Create a Talk room" : "Einen Gesprächsraum erstellen",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Für jeden gebuchten Termin wird ein eindeutiger Link generiert und mit der Bestätigungs-E-Mail versendet",
    "Description" : "Beschreibung",
    "Visibility" : "Sichtbarkeit",
    "Duration" : "Dauer",
    "Increments" : "Schritte",
    "Additional calendars to check for conflicts" : "Zusätzliche Kalender zur Überprüfung auf Konflikte",
    "Pick time ranges where appointments are allowed" : "Wählen Sie Zeitbereiche, in denen Termine erlaubt sind",
    "to" : "bis",
    "Delete slot" : "Zeitfenster löschen",
    "No times set" : "Keine Zeiten gesetzt",
    "Add" : "Hinzufügen",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sunday" : "Sonntag",
    "Weekdays" : "Wochentage",
    "Add time before and after the event" : "Zeit vor und nach dem Termin hinzufügen",
    "Before the event" : "Vor dem Termin",
    "After the event" : "Nach dem Termin",
    "Planning restrictions" : "Planungsbeschränkungen",
    "Minimum time before next available slot" : "Mindestzeit bis zur nächsten verfügbaren Zeitfenster",
    "Max slots per day" : "Maximale Zeitfenster pro Tag",
    "Limit how far in the future appointments can be booked" : "Begrenzung, wie weit in der Zukunft Termine gebucht werden können",
    "It seems a rate limit has been reached. Please try again later." : "Es scheint, dass ein Ratenlimit erreicht wurde. Bitte versuchen Sie es später noch einmal.",
    "Appointment schedule saved" : "Terminplan gespeichert",
    "Create appointment schedule" : "Terminplan erstellen",
    "Edit appointment schedule" : "Terminplan bearbieten",
    "Update" : "Aktualisieren",
    "Please confirm your reservation" : "Bitte bestätigen Sie Ihre Reservierung",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Wir haben Ihnen eine E-Mail mit Details gesendet. Bitte bestätigen Sie Ihren Termin über den Link in der E-Mail. Sie können diese Seite jetzt schließen.",
    "Your name" : "Ihr Name",
    "Your email address" : "Ihre E-Mail-Adresse",
    "Please share anything that will help prepare for our meeting" : "Bitte senden Sie uns alles, was zur Vorbereitung unseres Treffens beiträgt.",
    "Could not book the appointment. Please try again later or contact the organizer." : "Termin konnte nicht gebucht werden. Bitte versuchen Sie es später erneut oder wenden Sie sich an den Organisator.",
    "Back" : "Zurück",
    "Book appointment" : "Termin buchen",
    "Reminder" : "Erinnerung",
    "before at" : "vorher um",
    "Notification" : "Benachrichtigung",
    "Email" : "E-Mail",
    "Audio notification" : "Audio-Benachrichtigung",
    "Other notification" : "Andere Benachrichtigung",
    "Relative to event" : "Bezogen auf Termin",
    "On date" : "Zum Datum",
    "Edit time" : "Zeit ändern",
    "Save time" : "Zeit speichern",
    "Remove reminder" : "Erinnerung entfernen",
    "on" : "am",
    "at" : "um",
    "+ Add reminder" : "+ Erinnerung hinzufügen",
    "Add reminder" : "Erinnerung hinzufügen",
    "_second_::_seconds_" : ["Sekunde","Sekunden"],
    "_minute_::_minutes_" : ["Minute","Minuten"],
    "_hour_::_hours_" : ["Stunde","Stunden"],
    "_day_::_days_" : ["Tag","Tage"],
    "_week_::_weeks_" : ["Woche","Wochen"],
    "No attachments" : "Keine Anhänge",
    "Add from Files" : "Aus Dateien auswählen",
    "Upload from device" : "Von Gerät hochladen",
    "Delete file" : "Datei löschen",
    "Confirmation" : "Bestätigung",
    "Choose a file to add as attachment" : "Wählen Sie eine Datei, die als Anhang angefügt werden soll",
    "Choose a file to share as a link" : "Wählen Sie eine Datei, die als Link geteilt werden soll",
    "Attachment {name} already exist!" : "Anhang {name} existiert bereits",
    "Could not upload attachment(s)" : "Anhänge konnten nicht hochgeladen werden",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Sie sind dabei, zu {host} zu navigieren. Möchten Sie wirklich fortfahren? Link: {link}",
    "Proceed" : "Fortsetzen",
    "_{count} attachment_::_{count} attachments_" : ["{count} Anhang","{count} Anhänge"],
    "Invitation accepted" : "Einladung angenommen",
    "Available" : "Verfügbar",
    "Suggested" : "Vorgeschlagen",
    "Participation marked as tentative" : "Teilnahme als vorläufig markiert",
    "Accepted {organizerName}'s invitation" : "Einladung von {organizerName} angenommen",
    "Not available" : "Nicht verfügbar",
    "Invitation declined" : "Einladung abgelehnt",
    "Declined {organizerName}'s invitation" : "Einladung von {organizerName} abgelehnt",
    "Invitation is delegated" : "Einladung ist delegiert",
    "Checking availability" : "Verfügbarkeit prüfen",
    "Awaiting response" : "Warte auf Antwort",
    "Has not responded to {organizerName}'s invitation yet" : "Hat noch nicht auf die Einladung von {organizerName} geantwortet",
    "Availability of attendees, resources and rooms" : "Verfügbarkeit von Teilnehmern, Resourcen und Räumen",
    "Find a time" : "Zeit auswählen",
    "with" : "mit",
    "Available times:" : "Verfügbare Zeiten:",
    "Suggestion accepted" : "Vorschlag angenommen",
    "Done" : "Erledigt",
    "Select automatic slot" : "Automatischen Bereich wählen",
    "chairperson" : "Vorsitz",
    "required participant" : "Benötigter Teilnehmer",
    "non-participant" : "Nicht-Teilnehmer",
    "optional participant" : "Optionaler Teilnehmer",
    "{organizer} (organizer)" : "{organizer} (Organisator)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Free" : "Frei",
    "Busy (tentative)" : "Beschäftigt (vorläufig)",
    "Busy" : "Beschäftigt",
    "Out of office" : "Nicht im Büro",
    "Unknown" : "Unbekannt",
    "Search room" : "Raum suchen",
    "Room name" : "Raumname",
    "Check room availability" : "Verfügbarkeit des Raums prüfen",
    "Accept" : "Annehmen",
    "Decline" : "Ablehnen",
    "Tentative" : "Vorläufig",
    "The invitation has been accepted successfully." : "Die Einladung wurde angenommen.",
    "Failed to accept the invitation." : "Einladung konnte nicht angenommen werden.",
    "The invitation has been declined successfully." : "Die Einladung wurde abgelehnt.",
    "Failed to decline the invitation." : "Fehler beim Ablehnen der Einladung.",
    "Your participation has been marked as tentative." : "Ihre Teilnahme wurde als vorläufig markiert.",
    "Failed to set the participation status to tentative." : "Fehler beim Markieren Ihrer Teilnahme als vorläufig.",
    "Attendees" : "Teilnehmer",
    "Create Talk room for this event" : "Besprechungsraum für diesen Termin erstellen",
    "No attendees yet" : "Keine Teilnehmer bislang",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} eingeladen, {confirmedCount} bestätigt",
    "Successfully appended link to talk room to location." : "Link des Talk-Raums zur Ortsangabe hinzugefügt.",
    "Successfully appended link to talk room to description." : "Link zur Beschreibung des Besprechungsraums hinzugefügt.",
    "Error creating Talk room" : "Fehler beim Erstellen des Besprechungsraumes",
    "_%n more guest_::_%n more guests_" : ["%n weiterer Gast","%n weitere Gäste"],
    "Request reply" : "Antwort anfordern",
    "Chairperson" : "Vorsitz",
    "Required participant" : "Benötigter Teilnehmer",
    "Optional participant" : "Optionaler Teilnehmer",
    "Non-participant" : "Nicht-Teilnehmer",
    "Remove group" : "Gruppe entfernen",
    "Remove attendee" : "Teilnehmer entfernen",
    "_%n member_::_%n members_" : ["%n Mitglied","%n Mitglieder"],
    "Search for emails, users, contacts, teams or groups" : "Nach E-Mails, Benutzern, Kontakten, Teams oder Gruppen suchen",
    "No match found" : "Keine Übereinstimmung gefunden",
    "Note that members of circles get invited but are not synced yet." : "Beachten Sie, dass Mitglieder von Kreisen eingeladen werden, aber noch nicht synchronisiert sind.",
    "Note that members of contact groups get invited but are not synced yet." : "Beachten Sie, dass Mitglieder von Kontaktgruppen eingeladen werden, aber noch nicht synchronisiert sind.",
    "(organizer)" : "(Organisator)",
    "Make {label} the organizer" : "{label} zum Organisator ernennen",
    "Make {label} the organizer and attend" : "{label} zum Organisator ernennen und teilnehmen",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Um das Versenden von Einladungen und deren Antworten zu ermöglichen, [linkopen] fügen Sie Ihre E-Mail-Adresse in den persönlichen Einstellungen hinzu.[linkclose].",
    "Remove color" : "Farbe entfernen",
    "Event title" : "Titel des Termins",
    "From" : "Von",
    "To" : "An",
    "All day" : "Ganztägig",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Die Einstellung ganztägig kann für sich wiederholende Termine nicht geändert werden.",
    "Repeat" : "Wiederholen",
    "End repeat" : "Wiederholung beenden",
    "Select to end repeat" : "Auswählen um Wiederholung beenden",
    "never" : "Niemals",
    "on date" : "zum Datum",
    "after" : "Nach",
    "_time_::_times_" : ["Mal","Mal"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Dieser Termin ist die Wiederholungsausnahme eines sich wiederholenden Termins. Sie können keine Wiederholungsregel hinzufügen.",
    "first" : "ersten",
    "third" : "dritten",
    "fourth" : "vierten",
    "fifth" : "fünften",
    "second to last" : "vorletzten",
    "last" : "letzten",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Änderungen an der Wiederholungsregel werden nur auf dieses und alle zukünftigen Vorkommen angewendet.",
    "Repeat every" : "Wiederhole jeden",
    "By day of the month" : "Nach Tag des Monats",
    "On the" : "Am",
    "_month_::_months_" : ["Monat","Monate"],
    "_year_::_years_" : ["Jahr","Jahre"],
    "weekday" : "Wochentag",
    "weekend day" : "Wochenendtag",
    "Does not repeat" : "Wiederholt sich nicht",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Die Wiederholungs-Definition dieses Termins wird nicht vollständig von Nextcloud unterstützt. Wenn Sie die Wiederholungs-Optionen bearbeiten, könnten bestimmte Wiederholungen verlorengehen.",
    "Suggestions" : "Vorschläge",
    "No rooms or resources yet" : "Noch keine Räume oder Ressourcen",
    "Add resource" : "Ressource hinzufügen",
    "Has a projector" : "Hat einen Projektor",
    "Has a whiteboard" : "Hat ein Whiteboard",
    "Wheelchair accessible" : "Barrierefrei",
    "Remove resource" : "Ressource entfernen",
    "Show all rooms" : "Alle Räume anzeigen",
    "Projector" : "Projektor",
    "Whiteboard" : "Whiteboard",
    "Search for resources or rooms" : "Nach Ressourcen oder Räumen suchen",
    "available" : "Verfügbar",
    "unavailable" : "Nicht verfügbar",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} Platz","{seatingCapacity} Plätze"],
    "Room type" : "Raum-Typ",
    "Any" : "Irgendein",
    "Minimum seating capacity" : "Mindestsitzplatzkapazität",
    "More details" : "Weitere Einzelheiten",
    "Update this and all future" : "Aktualisiere dieses und alle Künftigen",
    "Update this occurrence" : "Dieses Vorkommen aktualisieren",
    "Public calendar does not exist" : "Öffentlicher Kalender existiert nicht",
    "Maybe the share was deleted or has expired?" : "Vielleicht wurde die Freigabe gelöscht oder ist abgelaufen?",
    "Select a time zone" : "Eine Zeitzone auswählen",
    "Please select a time zone:" : "Bitte eine Zeitzone wählen:",
    "Pick a time" : "Zeit auswählen",
    "Pick a date" : "Datum auswählen",
    "from {formattedDate}" : "Von {formattedDate}",
    "to {formattedDate}" : "bis {formattedDate}",
    "on {formattedDate}" : "am {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "von {formattedDate} um {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "bis {formattedDate} um {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "am {formattedDate} um {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} um {formattedTime}",
    "Please enter a valid date" : "Bitte ein gültiges Datum angeben",
    "Please enter a valid date and time" : "Bitte gültiges Datum und Uhrzeit angeben",
    "Type to search time zone" : "Zum Suchen der Zeitzone tippen",
    "Global" : "Weltweit",
    "Public holiday calendars" : "Feiertagskalender",
    "Public calendars" : "Öffentliche Kalender",
    "No valid public calendars configured" : "Keine gültigen öffentlichen Kalender eingerichtet",
    "Speak to the server administrator to resolve this issue." : "Sprechen Sie die Administration an, um dieses Problem zu lösen.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Feiertagskalender werden von Thunderbird bereitgestellt. Kalenderdaten werden von {website} heruntergeladen.",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Diese öffentlichen Kalender werden von der Serveradministration vorgeschlagen. Kalenderdaten werden von der entsprechenden Webseite heruntergeladen.",
    "By {authors}" : "Von {authors}",
    "Subscribed" : "Abonniert",
    "Subscribe" : "Abonnieren",
    "Holidays in {region}" : "Feiertage in {region}",
    "An error occurred, unable to read public calendars." : "Es ist ein Fehler aufgetreten, öffentliche Kalender können nicht gelesen werden.",
    "An error occurred, unable to subscribe to calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht abonniert werden.",
    "Select a date" : "Datum auswählen",
    "Select slot" : "Zeitfenster auswählen",
    "No slots available" : "Keine Zeitfenster verfügbar",
    "Could not fetch slots" : "Abruf der Zeitfenster fehlgeschlagen",
    "The slot for your appointment has been confirmed" : "Das Zeitfenster für Ihren Termin wurde bestätigt",
    "Appointment Details:" : "Termindetails:",
    "Time:" : "Zeit:",
    "Booked for:" : "Gebucht für:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Danke schön. Ihre Buchung vom {startDate} bis {endDate} wurde bestätigt.",
    "Book another appointment:" : "Einen weiteren Termin buchen:",
    "See all available slots" : "Alle verfügbaren Zeitfenster anzeigen",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Das Zeitfenster für Ihren Termin von {startDate} bis {endDate} ist nicht mehr verfügbar.",
    "Please book a different slot:" : "Buchen Sie bitte ein anderes Zeitfenster:",
    "Book an appointment with {name}" : "Buchen Sie einen Termin mit {name}",
    "No public appointments found for {name}" : "Keine öffentlichen Termine für {name} gefunden",
    "Personal" : "Persönlich",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Die automatische Erkennung der Zeitzone hat als Ergebnis UTC ermittelt.\nDies ist meist das Ergebnis von Sicherheitsmaßnahmen Ihres Webbrowsers.\nBitte stellen Sie Ihre Zeitzone manuell in den Kalendereinstellungen ein.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Die konfigurierte Zeitzone ({timezoneId}) wurde nicht gefunden. Rückfall auf UTC.\nBitte die Zeitzone in den Einstellungen ändern und melden dieses Problem.",
    "Event does not exist" : "Der Termin existiert nicht",
    "Duplicate" : "Duplizieren",
    "Delete this occurrence" : "Dieses Vorkommen löschen",
    "Delete this and all future" : "Dieses und alle Künftigen löschen",
    "Details" : "Details",
    "Managing shared access" : "Geteilten Zugriff verwalten",
    "Deny access" : "Zugriff verweigern",
    "Invite" : "Einladen",
    "Resources" : "Ressourcen",
    "_User requires access to your file_::_Users require access to your file_" : ["Benutzer benötigen Zugang zu Ihrer Datei","Benutzer benötigen Zugang zu Ihren Dateien"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Anhang erfordert geteilten Zugriff","Anhänge erfordern geteilten Zugriff"],
    "Close" : "Schließen",
    "Untitled event" : "Unbenannter Termin",
    "Subscribe to {name}" : "{name} abonnieren",
    "Export {name}" : "{name} exportieren",
    "Anniversary" : "Jahrestag",
    "Appointment" : "Verabredung",
    "Business" : "Geschäftlich",
    "Education" : "Bildung",
    "Holiday" : "Feiertag",
    "Meeting" : "Treffen",
    "Miscellaneous" : "Verschiedenes",
    "Non-working hours" : "Arbeitsfreie Stunden",
    "Not in office" : "Nicht im Büro",
    "Phone call" : "Anruf",
    "Sick day" : "Krankheitstag",
    "Special occasion" : "Besondere Gelegenheit",
    "Travel" : "Reise",
    "Vacation" : "Urlaub",
    "Midnight on the day the event starts" : "Mitternacht am Tag des Starts des Termins",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n Tag vor dem Start des Termins um {formattedHourMinute}","%n Tage vor dem Start des Termins um {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n Woche vor dem Start des Termins um {formattedHourMinute}","%n Wochen vor dem Start des Termins um {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "Am Tag des Termins um {formattedHourMinute}",
    "at the event's start" : "Zu Beginn des Termins",
    "at the event's end" : "Am Ende des Termins",
    "{time} before the event starts" : "{time} vor Beginn des Termins",
    "{time} before the event ends" : "{time} vor Ende des Termins",
    "{time} after the event starts" : "{time} nach Beginn des Termins",
    "{time} after the event ends" : "{time} nach Ende des Termins",
    "on {time}" : "um {time}",
    "on {time} ({timezoneId})" : "um {time} ({timezoneId})",
    "Week {number} of {year}" : "Woche {number} aus {year}",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Monthly" : "Monatlich",
    "Yearly" : "Jährlich",
    "_Every %n day_::_Every %n days_" : ["Jeden %n Tag","Alle %n Tage"],
    "_Every %n week_::_Every %n weeks_" : ["Jede %n Woche","Alle %n Wochen"],
    "_Every %n month_::_Every %n months_" : ["Jeden %n Monat","Alle %n Monate"],
    "_Every %n year_::_Every %n years_" : ["Jedes %n Jahr","Alle %n Jahre"],
    "_on {weekday}_::_on {weekdays}_" : ["am {weekday}","am {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["am Tag {dayOfMonthList}","an den Tagen {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "am {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "im {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "im {monthNames} am {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "bis {untilDate}",
    "_%n time_::_%n times_" : ["%n mal","%n mal"],
    "Untitled task" : "Unbenannte Aufgabe",
    "Please ask your administrator to enable the Tasks App." : "Bitten Sie Ihren Administrator die Aufgaben-App (Tasks) zu aktivieren.",
    "W" : "W",
    "%n more" : "%n weitere",
    "No events to display" : "Keine Termine zum Anzeigen",
    "_+%n more_::_+%n more_" : ["+%n weitere","+%n weitere"],
    "No events" : "Keine Termine",
    "Create a new event or change the visible time-range" : "Neuen Termin erstellen oder den sichtbaren Zeitbereich ändern",
    "Failed to save event" : "Speichern des Termins fehlgeschlagen",
    "It might have been deleted, or there was a typo in a link" : "Möglicherweise wurde dies gelöscht oder es gab einen Tippfehler in einem Link",
    "It might have been deleted, or there was a typo in the link" : "Möglicherweise wurde dies gelöscht oder es gab einen Tippfehler in einem Link",
    "Meeting room" : "Besprechungsraum",
    "Lecture hall" : "Hörsaal",
    "Seminar room" : "Seminarraum",
    "Other" : "Sonstiges",
    "When shared show" : "Anzeigen, wenn geteilt",
    "When shared show full event" : "Wenn geteilt, zeige den vollständigen Termin an",
    "When shared show only busy" : "Wenn geteilt, zeige nur den Status \"beschäftigt\" an",
    "When shared hide this event" : "Wenn geteilt, zeige diesen Termin nicht an",
    "The visibility of this event in shared calendars." : "Sichtbarkeit dieses Termins in geteilten Kalendern.",
    "Add a location" : "Ort hinzufügen",
    "Add a description" : "Beschreibung hinzufügen",
    "Status" : "Status",
    "Confirmed" : "Bestätigt",
    "Canceled" : "Abgesagt",
    "Confirmation about the overall status of the event." : "Bestätigung über den Gesamtstatus des Termins.",
    "Show as" : "Anzeigen als",
    "Take this event into account when calculating free-busy information." : "Diesen Termin bei der Berechnung der Frei- / Beschäftigt-Informationen berücksichtigen.",
    "Categories" : "Kategorien",
    "Categories help you to structure and organize your events." : "Mithilfe von Kategorien können Sie Ihre Termine strukturieren und organisieren.",
    "Search or add categories" : "Suchen oder fügen Sie Kategorien hinzu",
    "Add this as a new category" : "Dies als neue Kategorie hinzufügen",
    "Custom color" : "Benutzerdefinierte Farbe",
    "Special color of this event. Overrides the calendar-color." : "Sonderfarbe für diesen Termin. Überschreibt die Kalenderfarbe.",
    "Error while sharing file" : "Fehler beim Teilen der Datei",
    "Error while sharing file with user" : "Fehler beim Teilen der Datei mit Benutzer",
    "Attachment {fileName} already exists!" : "Anhang {fileName} existiert bereits",
    "An error occurred during getting file information" : "Es ist ein Fehler beim Abrufen von Dateiinformationen aufgetreten",
    "Chat room for event" : "Chat-Raum für Termin",
    "An error occurred, unable to delete the calendar." : "Es ist ein Fehler aufgetreten, Kalender konnte nicht gelöscht werden.",
    "Imported {filename}" : "{filename} importiert ",
    "This is an event reminder." : "Dies ist eine Terminerinnerung.",
    "Error while parsing a PROPFIND error" : "Fehler beim Parsen eines PROPFIND-Fehlers",
    "Appointment not found" : "Termin nicht gefunden",
    "User not found" : "Benutzer nicht gefunden",
    "Default calendar for invitations and new events" : "Standardkalender für Einladungen und neue Termine",
    "Appointment was created successfully" : "Termin wurde erstellt",
    "Appointment was updated successfully" : "Termin wurde aktualisiert",
    "Create appointment" : "Termin erstellen",
    "Edit appointment" : "Termin bearbeiten",
    "Book the appointment" : "Den Termin buchen",
    "You do not own this calendar, so you cannot add attendees to this event" : "Sie sind nicht Eigentümer von diesem Kalender und können daher dieser Termin keine Teilnehmer hinzufügen",
    "Search for emails, users, contacts or groups" : "Nach E-Mails, Benutzern, Kontakten oder Gruppen suchen",
    "Select date" : "Datum auswählen",
    "Create a new event" : "Neuen Termin erstellen",
    "[Today]" : "[Heute]",
    "[Tomorrow]" : "[Morgen]",
    "[Yesterday]" : "[Gestern]",
    "[Last] dddd" : "[Letzten] dddd"
},
"nplurals=2; plural=(n != 1);");
