OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "已提供的電子郵件地址太長",
    "User-Session unexpectedly expired" : "使用者連線階段過期",
    "Provided email-address is not valid" : "提供的電子郵件地址無效",
    "%s has published the calendar »%s«" : "%s 發佈了日曆 »%s«",
    "Unexpected error sending email. Please contact your administrator." : "傳送電子郵件出現意外的錯誤。請聯絡您的管理者。",
    "Successfully sent email to %1$s" : "已成功傳送電子郵件至 %1$s",
    "Hello," : "嗨，",
    "We wanted to inform you that %s has published the calendar »%s«." : "通知您，%s 發佈了日曆 »%s«.",
    "Open »%s«" : "開啟 »%s«",
    "Cheers!" : "太棒了！",
    "Upcoming events" : "接下來的活動",
    "No more events today" : "今天沒有其他活動",
    "No upcoming events" : "沒有接下來的活動",
    "More events" : "更多活動",
    "%1$s with %2$s" : "由 %2$s 預訂的 %1$s",
    "Calendar" : "日曆",
    "New booking {booking}" : "新預約 {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) 在 {date_time} 預約了「{config_display_name}」。",
    "Appointments" : "預約",
    "Schedule appointment \"%s\"" : "安排預約「%s」",
    "Schedule an appointment" : "安排預約",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "準備 %s",
    "Follow up for %s" : "跟進 %s",
    "Your appointment \"%s\" with %s needs confirmation" : "您的預約「%s」包含 %s 需要確認",
    "Dear %s, please confirm your booking" : "親愛的 %s，請確認您的預約",
    "Confirm" : "確認",
    "Appointment with:" : "預約：",
    "Description:" : "描述：",
    "This confirmation link expires in %s hours." : "此確認連結將於 %s 小時後過期。",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "若您想要取消預約，請回覆此電子郵件或造訪他們的個人資料頁面與您的舉辦者聯絡。",
    "Your appointment \"%s\" with %s has been accepted" : "您的預約「%s」包含 %s 已被接受",
    "Dear %s, your booking has been accepted." : "親愛的 %s，您的預約已被接受。",
    "Appointment for:" : "預約：",
    "Date:" : "日期：",
    "You will receive a link with the confirmation email" : "您將會收到包含連結的確認電子郵件",
    "Where:" : "地點：",
    "Comment:" : "留言：",
    "You have a new appointment booking \"%s\" from %s" : "您有一個新預約「%s」，來自 %s",
    "Dear %s, %s (%s) booked an appointment with you." : "親愛的 %s，%s (%s) 與您預約了。",
    "A Calendar app for Nextcloud" : "Nextcloud 的日曆應用程式",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "日曆應用程式是 Nextcloud 的 CalDAV 伺服器的使用者介面。透過您的 Nextcloud 輕鬆同步來自各裝置的活動，並在線上編輯它們。\n\n* 🚀 **與其他 Nextcloud 應用程式的整合！** 目前為通訊錄，但還會有更多的。\n* 🌐 **支援 WebCal！** 想在您的日曆中檢視您最愛球隊的比賽日期？沒問題！\n* 🙋 **參與者！** 邀請夥伴來參加您的活動\n* ⌚️ **有空／忙碌！** 看看您的參與者們什麼時候可以見面\n* ⏰ **提醒！** 在您的瀏覽器中以及透過電子郵件取得警示\n* 🔍 搜尋！輕鬆找到您的活動\n* ☑️ 工作項目！直接在日曆中檢視工作項目的到期日\n* 🙈 **我們並未重新發明輪子！** 以超棒的 [c-dav 函式庫](https://github.com/nextcloud/cdav-library)、[ical.js](https://github.com/mozilla-comm/ical.js) 與 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 函式庫為基礎。",
    "Previous day" : "前一日",
    "Previous week" : "前週",
    "Previous year" : "前一年",
    "Previous month" : "上個月",
    "Next day" : "隔天",
    "Next week" : "下週",
    "Next year" : "明年",
    "Next month" : "下個月",
    "Event" : "事件",
    "Create new event" : "建立新事件",
    "Today" : "今天",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Year" : "年",
    "List" : "清單",
    "Preview" : "預覽",
    "Copy link" : "複製連結",
    "Edit" : "編輯",
    "Delete" : "刪除",
    "Appointment link was copied to clipboard" : "預約連結已複製到剪貼簿",
    "Appointment link could not be copied to clipboard" : "預約連結無法複製到剪貼簿",
    "Appointment schedules" : "預約時間表",
    "Create new" : "建立新的",
    "Untitled calendar" : "未命名日曆",
    "Shared with you by" : "分享給您藉由",
    "Edit and share calendar" : "編輯並分享行事曆",
    "Edit calendar" : "編輯行事曆",
    "Disable calendar \"{calendar}\"" : "停用行事曆 \"{calendar}\"",
    "Disable untitled calendar" : "停用未命名的行事曆",
    "Enable calendar \"{calendar}\"" : "啟用行事曆 \"{calendar}\"",
    "Enable untitled calendar" : "啟用未命名的行事曆",
    "An error occurred, unable to change visibility of the calendar." : "發生錯誤，無法改變日曆的能見度",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後取消分享日曆"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["將在 {countdown} 秒後刪除日曆"],
    "Calendars" : "日曆",
    "Add new" : "新增",
    "New calendar" : "新日曆",
    "Name for new calendar" : "新行事曆名稱",
    "Creating calendar …" : "正在建立日曆…",
    "New calendar with task list" : "新日曆及待辦清單",
    "New subscription from link (read-only)" : "自連結建立新訂閱（唯讀）",
    "Creating subscription …" : "正在建立新訂閱…",
    "Add public holiday calendar" : "新增公眾節日行事曆",
    "Add custom public calendar" : "新增自訂公開日曆",
    "An error occurred, unable to create the calendar." : "發生錯誤，無法建立日曆",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "請輸入有效的連結（以 http:// , https:// , webcal:// , 或 webcals:// 開頭）",
    "Copy subscription link" : "複製訂閱的連結",
    "Copying link …" : "正在複製連結…",
    "Copied link" : "連結已複製",
    "Could not copy link" : "無法複製連結",
    "Export" : "匯出",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼簿",
    "Calendar link could not be copied to clipboard." : "日曆連結無法複製到剪貼簿",
    "Trash bin" : "回收桶",
    "Loading deleted items." : "載入已刪除的項目。",
    "You do not have any deleted items." : "您沒有任何已刪除的項目。",
    "Name" : "名稱",
    "Deleted" : "已刪除",
    "Restore" : "還原",
    "Delete permanently" : "永久刪除",
    "Empty trash bin" : "清空回收桶",
    "Untitled item" : "未命名的項目",
    "Unknown calendar" : "未知行事曆",
    "Could not load deleted calendars and objects" : "無法載入已刪除的日曆與物件",
    "Could not restore calendar or event" : "無法復原日曆或活動",
    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["回收桶中的項目會在{numDays}天後刪除"],
    "Shared calendars" : "分享的行事曆",
    "Deck" : "Deck",
    "Hidden" : "隱藏",
    "Could not update calendar order." : "無法變更日曆順序",
    "Internal link" : "內部連結",
    "A private link that can be used with external clients" : "可與外部客戶端一起使用的私人連結",
    "Copy internal link" : "複製內部連結",
    "Share link" : "分享連結",
    "Copy public link" : "複製公開連結",
    "Send link to calendar via email" : "透過電子郵件傳送日曆連結",
    "Enter one address" : "輸入一個位址",
    "Sending email …" : "正在傳送電子郵件…",
    "Copy embedding code" : "複製內嵌程式碼",
    "Copying code …" : "正在複製程式碼…",
    "Copied code" : "已複製程式碼",
    "Could not copy code" : "無法複製程式碼",
    "Delete share link" : "刪除分享連結",
    "Deleting share link …" : "正在刪除共享連結…",
    "An error occurred, unable to publish calendar." : "發生錯誤，無法發佈日曆",
    "An error occurred, unable to send email." : "發生錯誤，無法寄送電子郵件",
    "Embed code copied to clipboard." : "內嵌程式碼已複製到剪貼簿",
    "Embed code could not be copied to clipboard." : "無法複製內嵌程式碼到剪貼簿",
    "Unpublishing calendar failed" : "取消發佈日曆失敗",
    "can edit" : "可編輯",
    "Unshare with {displayName}" : "取消與 {displayName} 的分享",
    "{teamDisplayName} (Team)" : "{teamDisplayName}（團隊）",
    "An error occurred while unsharing the calendar." : "取消分享行事曆時發生錯誤。",
    "An error occurred, unable to change the permission of the share." : "發生錯誤，無法變更分享權限",
    "Share with users or groups" : "與使用者或群組分享",
    "No users or groups" : "沒有使用者或群組",
    "Calendar name …" : "行事曆名稱……",
    "Never show me as busy (set this calendar to transparent)" : "永不顯示我為忙碌狀態（設定此行事曆為透明）",
    "Share calendar" : "分享行事曆",
    "Unshare from me" : "取消與我分享",
    "Save" : "儲存",
    "Failed to save calendar name and color" : "儲存行事曆名稱或色彩失敗",
    "Import calendars" : "匯入日曆",
    "Please select a calendar to import into …" : "請選擇將匯入的日曆",
    "Filename" : "檔案名稱",
    "Calendar to import into" : "將匯入的日曆",
    "Cancel" : "取消",
    "_Import calendar_::_Import calendars_" : ["匯入日曆"],
    "Default attachments location" : "預設附件位置",
    "Select the default location for attachments" : "選取附件的預設位置",
    "Pick" : "挑選",
    "Invalid location selected" : "選取無效的位置",
    "Attachments folder successfully saved." : "附件資料夾已成功儲存。",
    "Error on saving attachments folder." : "儲存附件資料夾時發生錯誤。",
    "{filename} could not be parsed" : "無法解析 {filename}",
    "No valid files found, aborting import" : "沒有找到有效的檔案，中斷匯入",
    "Import partially failed. Imported {accepted} out of {total}." : "匯入部分失敗，僅成功匯入 {total} 中的 {accepted} 項",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["成功匯入 %n 個活動"],
    "Automatic" : "自動",
    "Automatic ({detected})" : "自動（{detected}）",
    "New setting was not saved successfully." : "新設定未成功儲存",
    "Shortcut overview" : "捷徑簡介",
    "or" : "或者",
    "Navigation" : "導覽列",
    "Previous period" : "前一期間",
    "Next period" : "下一期間",
    "Views" : "顯示",
    "Day view" : "每日",
    "Week view" : "每週",
    "Month view" : "每月",
    "Year view" : "年檢視",
    "List view" : "清單檢視",
    "Actions" : "動作",
    "Create event" : "建立活動",
    "Show shortcuts" : "顯示捷徑",
    "Editor" : "編輯器",
    "Close editor" : "關閉編輯器",
    "Save edited event" : "儲存已編輯的事件",
    "Delete edited event" : "刪除已編輯的事件",
    "Duplicate event" : "重複事件",
    "Enable birthday calendar" : "啟用生日日曆",
    "Show tasks in calendar" : "在日曆上顯示待辦事項",
    "Enable simplified editor" : "啟用簡化的編輯器",
    "Limit the number of events displayed in the monthly view" : "限制行事曆月檢視模式中顯示的事件數量",
    "Show weekends" : "顯示週末",
    "Show week numbers" : "顯示週數",
    "Time increments" : "隨時間遞增",
    "Default calendar for incoming invitations" : "收到的邀請的預設行事曆",
    "Default reminder" : "預設提醒",
    "Copy primary CalDAV address" : "複製主要的 CalDAV 位址",
    "Copy iOS/macOS CalDAV address" : "複製 iOS/macOS 的 CalDAV 位址",
    "Personal availability settings" : "個人可用設定",
    "Show keyboard shortcuts" : "顯示快速鍵",
    "Calendar settings" : "行事曆設定",
    "At event start" : "活動開始時",
    "No reminder" : "無提醒",
    "Failed to save default calendar" : "儲存預設日曆失敗",
    "CalDAV link copied to clipboard." : "已複製 CalDAV 連結至剪貼簿",
    "CalDAV link could not be copied to clipboard." : "無法複製 CalDAV 連結至剪貼簿",
    "Appointment schedule successfully created" : "已成功建立預約時間表",
    "Appointment schedule successfully updated" : "已成功更新預約時間表",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} 分鐘"],
    "0 minutes" : "0分鐘",
    "_{duration} hour_::_{duration} hours_" : ["{duration} 小時"],
    "_{duration} day_::_{duration} days_" : ["{duration} 天"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} 週"],
    "_{duration} month_::_{duration} months_" : ["{duration} 月"],
    "_{duration} year_::_{duration} years_" : ["{duration} 年"],
    "To configure appointments, add your email address in personal settings." : "要設定預約，請在您的個人設定中新增電子郵件。",
    "Public – shown on the profile page" : "公開 – 在個人資料頁面上展示",
    "Private – only accessible via secret link" : "私人 – 僅能透過祕密連結存取",
    "Appointment name" : "約會名稱",
    "Location" : "地點",
    "Create a Talk room" : "建立 Talk 聊天室",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "將為每個預定的約會產生一個獨一無二的連結，並透過確認電子郵件寄送",
    "Description" : "描述",
    "Visibility" : "能見度",
    "Duration" : "持續時間",
    "Increments" : "遞增",
    "Additional calendars to check for conflicts" : "用於檢查衝突的其他行事曆",
    "Pick time ranges where appointments are allowed" : "選擇允許預約的時間範圍",
    "to" : "至",
    "Delete slot" : "刪除欄位",
    "No times set" : "未設定時間",
    "Add" : "新增",
    "Monday" : "週一",
    "Tuesday" : "週二",
    "Wednesday" : "週三",
    "Thursday" : "週四",
    "Friday" : "週五",
    "Saturday" : "週六",
    "Sunday" : "週日",
    "Weekdays" : "週間",
    "Add time before and after the event" : "新增活動前後的時間",
    "Before the event" : "活動前",
    "After the event" : "活動後",
    "Planning restrictions" : "規劃限制",
    "Minimum time before next available slot" : "下一個可用時段前的最短時間",
    "Max slots per day" : "每日最大時段數",
    "Limit how far in the future appointments can be booked" : "限制可以預訂未來多久的預約",
    "It seems a rate limit has been reached. Please try again later." : "似乎已達速率限制。請稍後再試。",
    "Appointment schedule saved" : "已儲存預約時間表",
    "Create appointment schedule" : "建立預約時間表",
    "Edit appointment schedule" : "編輯預約時間表",
    "Update" : "更新",
    "Please confirm your reservation" : "請確認您的預約",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "我們向您寄送了一封包含詳細資訊的電子郵件。請使用電子郵件中的連結確認您的預約。您現在可以關閉此頁面了。",
    "Your name" : "您的名字",
    "Your email address" : "您的電子郵件地址",
    "Please share anything that will help prepare for our meeting" : "請分享任何有助於為我們的會議做準備的資訊",
    "Could not book the appointment. Please try again later or contact the organizer." : "無法預約。請稍後再試或聯絡舉辦者。",
    "Back" : "返回",
    "Book appointment" : "預約",
    "Reminder" : "提醒",
    "before at" : "之前於",
    "Notification" : "通知",
    "Email" : "Email",
    "Audio notification" : "音訊通知",
    "Other notification" : "其他通知",
    "Relative to event" : "相對於活動",
    "On date" : "在特定日期",
    "Edit time" : "編輯時間",
    "Save time" : "儲存時間",
    "Remove reminder" : "刪除提醒",
    "on" : "在",
    "at" : "在",
    "+ Add reminder" : "+ 加入提醒",
    "Add reminder" : "新增提醒",
    "_second_::_seconds_" : ["秒"],
    "_minute_::_minutes_" : ["分鐘"],
    "_hour_::_hours_" : ["時"],
    "_day_::_days_" : ["天"],
    "_week_::_weeks_" : ["週"],
    "No attachments" : "無附件",
    "Add from Files" : "新增自檔案",
    "Upload from device" : "從裝置上傳",
    "Delete file" : "刪除檔案",
    "Confirmation" : "確認",
    "Choose a file to add as attachment" : "選擇要作為附件的檔案",
    "Choose a file to share as a link" : "選擇要作為連結分享的檔案",
    "Attachment {name} already exist!" : "附件 {name} 已存在！",
    "Could not upload attachment(s)" : "無法上傳附件",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "您即將前往 {host}。您確定要繼續嗎？連結：{link}",
    "Proceed" : "繼續",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個附件"],
    "Invitation accepted" : "已接受邀請",
    "Available" : "可用",
    "Suggested" : "建議",
    "Participation marked as tentative" : "將參與標記為暫定",
    "Accepted {organizerName}'s invitation" : "已接受 {organizerName} 的邀請",
    "Not available" : "無法使用",
    "Invitation declined" : "邀請被拒絕",
    "Declined {organizerName}'s invitation" : "已拒絕 {organizerName} 的邀請",
    "Invitation is delegated" : "邀請已配送",
    "Checking availability" : "正在檢查可用性。",
    "Awaiting response" : "等待回應",
    "Has not responded to {organizerName}'s invitation yet" : "尚未回覆 {organizerName} 的邀請",
    "Availability of attendees, resources and rooms" : "參與者、資源和空間的可用性",
    "Find a time" : "找個時間",
    "with" : "與",
    "Available times:" : "可用項目：",
    "Suggestion accepted" : "已接受建議",
    "Done" : "完成",
    "Select automatic slot" : "選取自動時段",
    "chairperson" : "主席",
    "required participant" : "必須出席的參與者",
    "non-participant" : "非參與者",
    "optional participant" : "可不出席的參與者",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Free" : "有空",
    "Busy (tentative)" : "忙碌（暫定）",
    "Busy" : "忙碌",
    "Out of office" : "不在辦公室",
    "Unknown" : "不明",
    "Search room" : "搜尋房間",
    "Room name" : "空間名稱",
    "Check room availability" : "檢查房間是否可供使用",
    "Accept" : "接受",
    "Decline" : "回絕",
    "Tentative" : "暫定",
    "The invitation has been accepted successfully." : "已成功接受邀請。",
    "Failed to accept the invitation." : "接受邀請失敗。",
    "The invitation has been declined successfully." : "已成功回絕邀請。",
    "Failed to decline the invitation." : "回絕邀請失敗。",
    "Your participation has been marked as tentative." : "您的參與已被標記為暫定。",
    "Failed to set the participation status to tentative." : "未能將參與狀態設定為暫定。",
    "Attendees" : "參與者",
    "Create Talk room for this event" : "建立此活動的線上會議室",
    "No attendees yet" : "還沒有任何參與者",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} 個已邀請，{confirmedCount} 個已確認",
    "Successfully appended link to talk room to location." : "成功將線上會議室的連結加至位置",
    "Successfully appended link to talk room to description." : "成功將線上會議室的連結加至活動細節",
    "Error creating Talk room" : "建立線上會議室發生錯誤",
    "_%n more guest_::_%n more guests_" : ["還有 %n 位來賓"],
    "Request reply" : "請求回覆",
    "Chairperson" : "主席",
    "Required participant" : "需出席的參與者",
    "Optional participant" : "可不出席的參與者",
    "Non-participant" : "非參與者",
    "Remove group" : "移除群組",
    "Remove attendee" : "移除參與者",
    "_%n member_::_%n members_" : ["%n 個成員"],
    "Search for emails, users, contacts, teams or groups" : "搜尋電子郵件、使用者、聯絡人、團隊或群組",
    "No match found" : "找不到符合的項目",
    "Note that members of circles get invited but are not synced yet." : "請注意，小圈圈成員已收到邀請，但尚未同步。",
    "Note that members of contact groups get invited but are not synced yet." : "請注意，聯絡人群組的成員已收到邀請，但尚未同步。",
    "(organizer)" : "（主辦人）",
    "Make {label} the organizer" : "讓 {label} 成為組織者",
    "Make {label} the organizer and attend" : "讓 {label} 成為組織者並參與",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "若要送出邀請函並處理回覆，[linkopen]請至個人設定頁加入您的電郵地址[linkclose]",
    "Remove color" : "移除顏色",
    "Event title" : "活動標題",
    "From" : "從",
    "To" : "至",
    "All day" : "全天",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "無法變更定期重複活動的全日設定。",
    "Repeat" : "重複",
    "End repeat" : "停止重複",
    "Select to end repeat" : "選擇以結束重複",
    "never" : "永不",
    "on date" : "在特定日期",
    "after" : "之後",
    "_time_::_times_" : ["次"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "此活動是一系列重複活動的特例，您無法針對它設定重複規則。",
    "first" : "第一",
    "third" : "第三",
    "fourth" : "第四",
    "fifth" : "第五",
    "second to last" : "倒數第二",
    "last" : "倒數第一",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "變更的重複規則只會套用至這項活動和重複的未來活動",
    "Repeat every" : "重複循環",
    "By day of the month" : "每月中特定日",
    "On the" : "在",
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "weekday" : "週間",
    "weekend day" : "週末",
    "Does not repeat" : "不要重複",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud 不完全支援此活動的重複。如果您編輯了重複選項，某些重複可能會遺失。",
    "Suggestions" : "建議",
    "No rooms or resources yet" : "還沒有聊天室或資源",
    "Add resource" : "新增資源",
    "Has a projector" : "有投影機",
    "Has a whiteboard" : "有白板",
    "Wheelchair accessible" : "無障礙通道",
    "Remove resource" : "移除資源",
    "Show all rooms" : "顯示所有房間",
    "Projector" : "投影機",
    "Whiteboard" : "白板",
    "Search for resources or rooms" : "搜尋資源或聊天室",
    "available" : "可用",
    "unavailable" : "不可用",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} 個座位"],
    "Room type" : "房間類型",
    "Any" : "任何",
    "Minimum seating capacity" : "最小座位數",
    "More details" : "更多詳細資訊",
    "Update this and all future" : "更新這次和所有未來的重複",
    "Update this occurrence" : "更新此重複",
    "Public calendar does not exist" : "公開日曆不存在",
    "Maybe the share was deleted or has expired?" : "分享是否已刪除或過期？",
    "Select a time zone" : "選取時區",
    "Please select a time zone:" : "請選取時區：",
    "Pick a time" : "挑選時間",
    "Pick a date" : "挑選日期",
    "from {formattedDate}" : "從 {formattedDate}",
    "to {formattedDate}" : "至 {formattedDate}",
    "on {formattedDate}" : "於 {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "從 {formattedDate} {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "至 {formattedDate} {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "於 {formattedDate} {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
    "Please enter a valid date" : "請輸入有效的日期",
    "Please enter a valid date and time" : "請輸入有效的日期和時間",
    "Type to search time zone" : "輸入以搜尋時區",
    "Global" : "全球",
    "Public holiday calendars" : "公眾節日行事曆",
    "Public calendars" : "公開日曆",
    "No valid public calendars configured" : "未設定有效的公開日曆",
    "Speak to the server administrator to resolve this issue." : "請與伺服器管理員聯絡以解決此問題。",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "公眾節日行事曆由 Thunderbird 提供。將會從 {website} 下載行事曆資料",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "這些公開日曆是伺服器管理員建議的。日曆資料將從對應的網站下載。",
    "By {authors}" : "作者為 {authors}",
    "Subscribed" : "已訂閱",
    "Subscribe" : "訂閱",
    "Holidays in {region}" : "{region} 的節日",
    "An error occurred, unable to read public calendars." : "發生錯誤，無法讀取公開日曆。",
    "An error occurred, unable to subscribe to calendar." : "發生錯誤，無法訂閱日曆。",
    "Select a date" : "選取日期",
    "Select slot" : "選取時段",
    "No slots available" : "無可用時段",
    "Could not fetch slots" : "無法擷取時段",
    "The slot for your appointment has been confirmed" : "您預約的時段已確認",
    "Appointment Details:" : "預約詳細資訊：",
    "Time:" : "時間：",
    "Booked for:" : "已預約：",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "感謝您。已確認您從 {startDate} 到 {endDate} 的預約。",
    "Book another appointment:" : "設定其他預約：",
    "See all available slots" : "檢視其他可用的時段",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "您從 {startDate} 至 {endDate} 的預約時段不再可用。",
    "Please book a different slot:" : "請選擇其他時段：",
    "Book an appointment with {name}" : "登記與 {name} 的預約",
    "No public appointments found for {name}" : "找不到 {name} 的公開預約",
    "Personal" : "私人",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動時區偵測認為您的時間是 UTC。\n這很可能視您的網路瀏覽器安全措施的結果。\n請在行事曆設定中手動設定您的時間。",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "找不到您設定的時間 ({timezoneId})。正在汰退至 UTC。\n請在設定中變更您的時區並回報此問題。",
    "Event does not exist" : "活動不存在",
    "Duplicate" : "重複",
    "Delete this occurrence" : "刪除這次活動",
    "Delete this and all future" : "刪除這次和所有未來重複",
    "Details" : "詳細資料",
    "Managing shared access" : "管理已分享的存取權限",
    "Deny access" : "拒絕存取",
    "Invite" : "邀請",
    "Resources" : "資源",
    "_User requires access to your file_::_Users require access to your file_" : ["使用者要求存取您的檔案"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["需要分享存取權限的附件"],
    "Close" : " 關閉",
    "Untitled event" : "未命名活動",
    "Subscribe to {name}" : "訂閱 {name}",
    "Export {name}" : "匯出 {name}",
    "Anniversary" : "週年",
    "Appointment" : "預約",
    "Business" : "商業",
    "Education" : "教育",
    "Holiday" : "假日",
    "Meeting" : "會議",
    "Miscellaneous" : "其他",
    "Non-working hours" : "下班時段",
    "Not in office" : "不在辦公室",
    "Phone call" : "通話",
    "Sick day" : "病假",
    "Special occasion" : "特殊場合",
    "Travel" : "旅行",
    "Vacation" : "度假",
    "Midnight on the day the event starts" : "活動開始日的午夜",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["於 {formattedHourMinute} 的活動 %n 天前"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["於 {formattedHourMinute} 的活動 %n 週前"],
    "on the day of the event at {formattedHourMinute}" : "於 {formattedHourMinute} 的活動當天",
    "at the event's start" : "在活動開始時",
    "at the event's end" : "在活動結束時",
    "{time} before the event starts" : "活動開始前 {time}",
    "{time} before the event ends" : "活動結束前 {time}",
    "{time} after the event starts" : "活動開始後 {time}",
    "{time} after the event ends" : "活動結束後 {time}",
    "on {time}" : "於 {time}",
    "on {time} ({timezoneId})" : "於 {time} ({timezoneId})",
    "Week {number} of {year}" : "{year} 的第 {number} 週",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Monthly" : "每月",
    "Yearly" : "每年",
    "_Every %n day_::_Every %n days_" : ["每 %n 天"],
    "_Every %n week_::_Every %n weeks_" : ["每 %n 週"],
    "_Every %n month_::_Every %n months_" : ["每 %n 月"],
    "_Every %n year_::_Every %n years_" : ["每 %n 年"],
    "_on {weekday}_::_on {weekdays}_" : ["於 {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["在 {dayOfMonthList} 天"],
    "on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet} 上",
    "in {monthNames}" : "於 {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "在 {ordinalNumber} {byDaySet} 於 {monthNames}",
    "until {untilDate}" : "到 {untilDate}",
    "_%n time_::_%n times_" : ["%n 次"],
    "Untitled task" : "未命名工作項目",
    "Please ask your administrator to enable the Tasks App." : "請要求您的管理員啟用工作項目應用程式。",
    "W" : "週",
    "%n more" : "其餘 %n 項",
    "No events to display" : "無可顯示的活動",
    "_+%n more_::_+%n more_" : ["* 和其他 %n 個"],
    "No events" : "無活動",
    "Create a new event or change the visible time-range" : "建立新活動或變更可見的時間範圍",
    "Failed to save event" : "儲存事件失敗",
    "It might have been deleted, or there was a typo in a link" : "其可能已經被刪除，或是連結中有錯字",
    "It might have been deleted, or there was a typo in the link" : "其可能已經被刪除，或是連結中有錯字",
    "Meeting room" : "會議室",
    "Lecture hall" : "演講廳",
    "Seminar room" : "研討室",
    "Other" : "其他",
    "When shared show" : "當分享顯示時",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "The visibility of this event in shared calendars." : "此活動在分享的日曆可見程度。",
    "Add a location" : "加入地點",
    "Add a description" : "加入描述",
    "Status" : "狀態",
    "Confirmed" : "已確認",
    "Canceled" : "已取消",
    "Confirmation about the overall status of the event." : "有關活動整體狀態的確認。",
    "Show as" : "顯示為",
    "Take this event into account when calculating free-busy information." : "計算有空與忙碌資訊時，請將此活動考慮在內。",
    "Categories" : "分類",
    "Categories help you to structure and organize your events." : "分類可以幫您整理您的活動",
    "Search or add categories" : "搜尋或加入分類",
    "Add this as a new category" : "將此加入為新分類",
    "Custom color" : "自訂顏色",
    "Special color of this event. Overrides the calendar-color." : "此活動的特殊顏色。覆寫日曆顏色。",
    "Error while sharing file" : "分享檔案時發生錯誤",
    "Error while sharing file with user" : "與使用者分享檔案時發生錯誤",
    "Attachment {fileName} already exists!" : "附件 {fileName} 已存在！",
    "An error occurred during getting file information" : "取得檔案資訊時發生錯誤",
    "Chat room for event" : "活動的聊天室",
    "An error occurred, unable to delete the calendar." : "發生錯誤，無法刪除日曆",
    "Imported {filename}" : "匯入的 {filename}",
    "This is an event reminder." : "這是一個事件提醒。",
    "Error while parsing a PROPFIND error" : "解析 PROFIND 錯誤時發生錯誤",
    "Appointment not found" : "找不到預約",
    "User not found" : "找不到使用者",
    "Default calendar for invitations and new events" : "邀請與新事件的預設日曆",
    "Appointment was created successfully" : "成功建立預約",
    "Appointment was updated successfully" : "成功更新預約",
    "Create appointment" : "建立預約",
    "Edit appointment" : "編輯預約",
    "Book the appointment" : "預約",
    "You do not own this calendar, so you cannot add attendees to this event" : "您並未擁有此行事曆，因此您無法新增參與者到此活動",
    "Search for emails, users, contacts or groups" : "搜尋電子郵件、使用者、聯絡人或群組",
    "Select date" : "選取日期",
    "Create a new event" : "建立新活動",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "[Yesterday]" : "[昨天]",
    "[Last] dddd" : "[上] dddd"
},
"nplurals=1; plural=0;");
