"use strict";(self.webpackChunkcalendar=self.webpackChunkcalendar||[]).push([["node_modules_nextcloud_dialogs_dist_chunks_index-CYiQsZoY_mjs"],{92424:(e,s,n)=>{n.d(s,{FilePickerVue:()=>o});const o=(0,n(7768).Mn)((()=>Promise.all([n.e("vendors-node_modules_core-js_internals_object-keys_js-node_modules_core-js_internals_v8-proto-6bc957"),n.e("vendors-node_modules_core-js_internals_object-define-properties_js-node_modules_core-js_inter-334b6b")]).then(n.bind(n,52476))))}}]);
//# sourceMappingURL=calendar-node_modules_nextcloud_dialogs_dist_chunks_index-CYiQsZoY_mjs.js.map?v=6d33ded1f1560b79224f