OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "تەمىنلەنگەن ئېلېكترونلۇق خەت ئادرېسى بەك ئۇزۇن",
    "User-Session unexpectedly expired" : "ئىشلەتكۈچى-يىغىن ئويلىمىغان يەردىن توشىدۇ",
    "Provided email-address is not valid" : "تەمىنلەنگەن ئېلېكترونلۇق خەت ئادرېسى ئىناۋەتلىك ئەمەس",
    "%s has published the calendar »%s«" : "% s كالېندارنى ئېلان قىلدى »% s«",
    "Unexpected error sending email. Please contact your administrator." : "ئېلېكترونلۇق خەت ئەۋەتىشتە كۈتۈلمىگەن خاتالىق. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Successfully sent email to %1$s" : "مۇۋەپپەقىيەتلىك ھالدا%1 $ s غا ئېلېكترونلۇق خەت ئەۋەتكەن",
    "Hello," : "ياخشىمۇسىز ،",
    "We wanted to inform you that %s has published the calendar »%s«." : "بىز سىزگە% s كالېندارنى ئېلان قىلدى »% s«.",
    "Open »%s«" : "ئېچىڭ »% s«",
    "Cheers!" : "خۇشال بولۇڭ!",
    "Upcoming events" : "ئالدىمىزدىكى ۋەقەلەر",
    "No more events today" : "بۈگۈن باشقا پائالىيەتلەر يوق",
    "No upcoming events" : "پات ئارىدا يۈز بېرىدىغان ئىشلار يوق",
    "More events" : "تېخىمۇ كۆپ ۋەقەلەر",
    "%1$s with %2$s" : "%1 $ s بىلەن%2 $ s",
    "Calendar" : "يىلنامە",
    "New booking {booking}" : "يېڭى زاكاز {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) {date_time} دا «{config_display_name}» تەيىنلەشنى زاكاس قىلدى.",
    "Appointments" : "تەيىنلەش",
    "Schedule appointment \"%s\"" : "ۋاقىت جەدۋىلى \"% s\"",
    "Schedule an appointment" : "ئۇچرىشىشنى ئورۇنلاشتۇرۇڭ",
    "%1$s - %2$s" : "%1 $ s -%2 $ s",
    "Prepare for %s" : "% S ئۈچۈن تەييارلىق قىلىڭ",
    "Follow up for %s" : "% S غا ئەگىشىڭ",
    "Your appointment \"%s\" with %s needs confirmation" : "سىزنىڭ% s بىلەن ئۇچرىشىشىڭىز جەزملەشتۈرۈشكە موھتاج",
    "Dear %s, please confirm your booking" : "ھۆرمەتلىك% s ، زاكاسلىرىڭىزنى جەزملەشتۈرۈڭ",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Appointment with:" : "تەيىنلەش:",
    "Description:" : "چۈشەندۈرۈش:",
    "This confirmation link expires in %s hours." : "بۇ جەزملەشتۈرۈش ئۇلىنىشى% s سائەت ئىچىدە توشىدۇ.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "زادى ئۇچرىشىشنى ئەمەلدىن قالدۇرماقچى بولسىڭىز ، بۇ ئېلېكترونلۇق خەتكە جاۋاب قايتۇرۇش ياكى ئۇلارنىڭ ئارخىپ بېتىنى زىيارەت قىلىش ئارقىلىق تەشكىللىگۈچىڭىز بىلەن ئالاقىلىشىڭ.",
    "Your appointment \"%s\" with %s has been accepted" : "سىزنىڭ% s بىلەن «% s» تەيىنلىنىشىڭىز قوبۇل قىلىندى",
    "Dear %s, your booking has been accepted." : "ھۆرمەتلىك% s ، زاكاس قوبۇل قىلىندى.",
    "Appointment for:" : "تەيىنلەش:",
    "Date:" : "چېسلا:",
    "You will receive a link with the confirmation email" : "جەزملەش ئېلخېتى بىلەن ئۇلىنىش تاپشۇرۇۋالىسىز",
    "Where:" : "قەيەردە:",
    "Comment:" : "باھا:",
    "You have a new appointment booking \"%s\" from %s" : "سىزدە% s دىن «% s» نى زاكاز قىلىش يېڭى زاكاس تالونى بار",
    "Dear %s, %s (%s) booked an appointment with you." : "ھۆرمەتلىك% s ،% s (% s) سىز بىلەن كۆرۈشۈشنى زاكاز قىلدى.",
    "A Calendar app for Nextcloud" : "Nextcloud ئۈچۈن كالېندار دېتالى",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "كالېندار دېتالى Nextcloud نىڭ CalDAV مۇلازىمېتىرى ئۈچۈن ئىشلەتكۈچى كۆرۈنمە يۈزى. Nextcloud ئارقىلىق ھەر خىل ئۈسكۈنىلەردىكى ۋەقەلەرنى ئاسانلا ماسقەدەملەڭ ۋە توردا تەھرىرلەڭ.\n\n* 🚀 ** باشقا Nextcloud ئەپلىرى بىلەن بىرلەشتۈرۈش! ** ھازىر ئالاقىلىشىش - تېخىمۇ كۆپ.\n* 🌐 ** WebCal قوللاش! ** كالېندارىڭىزدا ئۆزىڭىز ياقتۇرىدىغان كوماندىنىڭ مۇسابىقە كۈنلىرىنى كۆرۈشنى خالامسىز؟ چاتاق يوق!\n* 🙋 ** قاتناشقۇچىلار! ** كىشىلەرنى پائالىيەتلىرىڭىزگە تەكلىپ قىلىڭ\n* ⌚️ ** ھەقسىز / ئالدىراش! ** قاتناشقۇچىلارنىڭ قاچان كۆرۈشكىلى بولىدىغانلىقىنى كۆرۈڭ\n* ⏰ ** ئەسكەرتىش! ** توركۆرگۈڭىزدە ۋە ئېلېكترونلۇق خەت ئارقىلىق ۋەقەلەرگە ئاگاھلاندۇرۇش بېرىڭ\n* 🔍 ئىزدەش! ۋەقەلەرنى ئازادە تېپىڭ\n* Ks ۋەزىپە! كالېنداردا قەرەلى توشقان ۋەزىپىلەرنى بىۋاسىتە كۆرۈڭ\n* 🙈 ** بىز چاقنى ئەسلىگە كەلتۈرمەيمىز! ** ئېسىل [c-dav كۈتۈپخانىسى] (https://github.com/nextcloud/cdav-library) ، [ical.js] (https: // github.com/mozilla-comm/ical.js) ۋە [fullcalendar] (https://github.com/fullcalendar/fullcalendar) كۈتۈپخانىلار.",
    "Previous day" : "ئالدىنقى كۈن",
    "Previous week" : "ئالدىنقى ھەپتە",
    "Previous year" : "ئالدىنقى يىل",
    "Previous month" : "ئالدىنقى ئاي",
    "Next day" : "ئەتىسى",
    "Next week" : "كېلەر ھەپتە",
    "Next year" : "كېلەر يىلى",
    "Next month" : "كېلەر ئاي",
    "Event" : "Event",
    "Create new event" : "يېڭى پائالىيەت قۇر",
    "Today" : "بۈگۈن",
    "Day" : "كۈن",
    "Week" : "ھەپتە",
    "Month" : "ئاي",
    "Year" : "يىل",
    "List" : "تىزىملىك",
    "Preview" : "ئالدىن كۆرۈش",
    "Copy link" : "ئۇلانمىنى كۆچۈرۈڭ",
    "Edit" : "تەھرىر",
    "Delete" : "ئۆچۈر",
    "Appointment link was copied to clipboard" : "تەيىنلەش ئۇلانمىسى چاپلاش تاختىسىغا كۆچۈرۈلدى",
    "Appointment link could not be copied to clipboard" : "تەيىنلەش ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ",
    "Appointment schedules" : "تەيىنلەش ۋاقىت جەدۋىلى",
    "Create new" : "يېڭى قۇر",
    "Untitled calendar" : "نامسىز كالېندار",
    "Shared with you by" : "سىز بىلەن ئورتاقلاشتى",
    "Edit and share calendar" : "كالېندارنى تەھرىرلەش ۋە ئورتاقلىشىش",
    "Edit calendar" : "كالېندارنى تەھرىرلەش",
    "Disable calendar \"{calendar}\"" : "كالېندار \"{calendar}\" نى چەكلەڭ",
    "Disable untitled calendar" : "نامسىز كالېندارنى چەكلەڭ",
    "Enable calendar \"{calendar}\"" : "كالېندار \"{calendar}\" نى قوزغىتىڭ",
    "Enable untitled calendar" : "نامسىز كالېندارنى قوزغىتىڭ",
    "An error occurred, unable to change visibility of the calendar." : "كالېندارنىڭ كۆرۈنۈشچانلىقىنى ئۆزگەرتەلمەيدىغان خاتالىق كۆرۈلدى.",
    "Calendars" : "كالېندار",
    "Add new" : "يېڭى قوشۇڭ",
    "New calendar" : "يېڭى يىلنامە",
    "Name for new calendar" : "يېڭى كالېندارنىڭ ئىسمى",
    "Creating calendar …" : "كالېندار قۇرۇش…",
    "New calendar with task list" : "ۋەزىپە تىزىملىكى بىلەن يېڭى كالېندار",
    "New subscription from link (read-only)" : "ئۇلىنىشتىن يېڭى مۇشتەرىلىك (پەقەت ئوقۇشقىلا بولىدۇ)",
    "Creating subscription …" : "مۇشتەرى بولۇش…",
    "Add public holiday calendar" : "ئاممىۋى دەم ئېلىش كالېندارىنى قوشۇڭ",
    "Add custom public calendar" : "ئىختىيارىي كالېندارنى قوشۇڭ",
    "An error occurred, unable to create the calendar." : "كالېندارنى قۇرالماسلىقتا خاتالىق كۆرۈلدى.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "ئىناۋەتلىك ئۇلىنىشنى كىرگۈزۈڭ (http: // ، https: // ، webcal: // ياكى webcals: // دىن باشلاڭ)",
    "Copy subscription link" : "مۇشتەرىلىك ئۇلانمىسىنى كۆچۈرۈڭ",
    "Copying link …" : "كۆچۈرۈش ئۇلانمىسى…",
    "Copied link" : "كۆچۈرۈلگەن ئۇلىنىش",
    "Could not copy link" : "ئۇلانمىنى كۆچۈرەلمىدى",
    "Export" : "چىقار",
    "Calendar link copied to clipboard." : "كالېندار ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
    "Calendar link could not be copied to clipboard." : "كالېندار ئۇلىنىشىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "Trash bin" : "ئەخلەت ساندۇقى",
    "Loading deleted items." : "ئۆچۈرۈلگەن تۈرلەرنى يۈكلەۋاتىدۇ.",
    "You do not have any deleted items." : "ئۆچۈرۈلگەن تۈرلىرىڭىز يوق.",
    "Name" : "ئاتى",
    "Deleted" : "ئۆچۈرۈلدى",
    "Restore" : "ئەسلىگە كەلتۈرۈش",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "Empty trash bin" : "ئەخلەت ساندۇقى",
    "Untitled item" : "نامسىز تۈر",
    "Unknown calendar" : "نامەلۇم كالېندار",
    "Could not load deleted calendars and objects" : "ئۆچۈرۈلگەن كالېندار ۋە ئوبيېكتلارنى يۈكلىيەلمىدى",
    "Could not restore calendar or event" : "كالېندار ياكى ھادىسىنى ئەسلىگە كەلتۈرەلمىدى",
    "Do you really want to empty the trash bin?" : "ئەخلەت ساندۇقىنى بوشاتماقچىمۇ؟",
    "Shared calendars" : "ئورتاق كالېندار",
    "Deck" : "پالۋان",
    "Hidden" : "يۇشۇرۇن",
    "Could not update calendar order." : "كالېندار تەرتىپىنى يېڭىلىيالمىدى.",
    "Internal link" : "ئىچكى ئۇلىنىش",
    "A private link that can be used with external clients" : "سىرتقى خېرىدارلار بىلەن ئىشلىتىشكە بولىدىغان شەخسىي ئۇلىنىش",
    "Copy internal link" : "ئىچكى ئۇلىنىشنى كۆچۈرۈڭ",
    "Share link" : "Share link",
    "Copy public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Send link to calendar via email" : "ئېلېكترونلۇق خەت ئارقىلىق كالېندارغا ئۇلىنىش ئەۋەتىڭ",
    "Enter one address" : "بىر ئادرېسنى كىرگۈزۈڭ",
    "Sending email …" : "ئېلېكترونلۇق خەت ئەۋەتىش…",
    "Copy embedding code" : "قىستۇرما كودىنى كۆچۈرۈڭ",
    "Copying code …" : "كۆچۈرۈش كودى…",
    "Copied code" : "كۆچۈرۈلگەن كود",
    "Could not copy code" : "كودنى كۆچۈرەلمىدى",
    "Delete share link" : "ھەمبەھىر ئۇلىنىشنى ئۆچۈرۈڭ",
    "Deleting share link …" : "ھەمبەھىر ئۇلىنىشنى ئۆچۈرۈۋاتىدۇ…",
    "An error occurred, unable to publish calendar." : "كالېندارنى ئېلان قىلالماي خاتالىق كۆرۈلدى.",
    "An error occurred, unable to send email." : "ئېلېكترونلۇق خەت ئەۋەتەلمەي خاتالىق كۆرۈلدى.",
    "Embed code copied to clipboard." : "قىستۇرما تاختىغا كۆچۈرۈلگەن كود.",
    "Embed code could not be copied to clipboard." : "قىستۇرما كودنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "Unpublishing calendar failed" : "كالېندارنى ئېلان قىلىش مەغلۇب بولدى",
    "can edit" : "تەھرىرلىيەلەيدۇ",
    "Unshare with {displayName}" : "{displayName} بىلەن ئورتاقلاشماسلىق",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "كالېندارنى ھەمبەھىرلەۋاتقاندا خاتالىق كۆرۈلدى.",
    "An error occurred, unable to change the permission of the share." : "ئورتاقلىشىشنىڭ رۇخسىتىنى ئۆزگەرتەلمەي خاتالىق كۆرۈلدى.",
    "Share with users or groups" : "ئىشلەتكۈچىلەر ياكى گۇرۇپپىلار بىلەن ئورتاقلىشىڭ",
    "No users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا يوق",
    "Calendar name …" : "كالېندار ئىسمى…",
    "Never show me as busy (set this calendar to transparent)" : "مېنى ھەرگىز ئالدىراش دەپ كۆرسەتمەڭ (بۇ كالېندارنى سۈزۈك قىلىپ تەڭشەڭ)",
    "Share calendar" : "كالېندارنى ئورتاقلىشىش",
    "Unshare from me" : "مەندىن تەڭداشسىز",
    "Save" : "ساقلا",
    "Failed to save calendar name and color" : "كالېندار ئىسمى ۋە رەڭنى ساقلاش مەغلۇب بولدى",
    "Import calendars" : "كالېندار ئەكىرىڭ",
    "Please select a calendar to import into …" : "ئىمپورت قىلىدىغان كالېندارنى تاللاڭ.",
    "Filename" : "ھۆججەت ئىسمى",
    "Calendar to import into" : "كىرگۈزمەكچى بولغان كالېندار",
    "Cancel" : "ۋاز كەچ",
    "Default attachments location" : "كۆڭۈلدىكى قوشۇمچە ئورنى",
    "Select the default location for attachments" : "قوشۇمچە ھۆججەتلەرنىڭ سۈكۈتتىكى ئورنىنى تاللاڭ",
    "Pick" : "تاللاڭ",
    "Invalid location selected" : "ئىناۋەتسىز ئورۇن تاللانغان",
    "Attachments folder successfully saved." : "قوشۇمچە ھۆججەت قىسقۇچ مۇۋەپپەقىيەتلىك ساقلاندى.",
    "Error on saving attachments folder." : "قوشۇمچە ھۆججەت قىسقۇچنى ساقلاشتا خاتالىق.",
    "{filename} could not be parsed" : "{filename} ئىسمى} تەھلىل قىلىشقا بولمايدۇ",
    "No valid files found, aborting import" : "ئۈنۈملۈك ھۆججەت تېپىلمىدى ، ئىمپورتنى ئەمەلدىن قالدۇردى",
    "Import partially failed. Imported {accepted} out of {total}." : "ئىمپورت قىسمەن مەغلۇپ بولدى. {accepted} دىن ئىمپورت قىلىنغان {total} قىلىندى}.",
    "Automatic" : "ئاپتوماتىك",
    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
    "New setting was not saved successfully." : "يېڭى تەڭشەك مۇۋەپپەقىيەتلىك ساقلانمىدى.",
    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
    "or" : "ياكى",
    "Navigation" : "يول باشلاش",
    "Previous period" : "ئالدىنقى مەزگىل",
    "Next period" : "كېيىنكى مەزگىل",
    "Views" : "كۆرۈنۈشلەر",
    "Day view" : "كۈن كۆرۈنۈشى",
    "Week view" : "ھەپتە كۆرۈنۈشى",
    "Month view" : "ئاي كۆرۈنۈشى",
    "Year view" : "يىل كۆرۈنۈشى",
    "List view" : "تىزىملىك كۆرۈنۈشى",
    "Actions" : "مەشغۇلاتلار",
    "Create event" : "ھادىسە قۇرۇش",
    "Show shortcuts" : "تېزلەتمىلەرنى كۆرسەت",
    "Editor" : "تەھرىر",
    "Close editor" : "تەھرىرلىگۈچنى تاقاش",
    "Save edited event" : "تەھرىرلەنگەن پائالىيەتنى ساقلاڭ",
    "Delete edited event" : "تەھرىرلەنگەن ۋەقەنى ئۆچۈرۈڭ",
    "Duplicate event" : "كۆپەيتىلگەن ھادىسە",
    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
    "Time increments" : "ۋاقىت كۆپەيدى",
    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
    "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
    "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
    "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
    "Calendar settings" : "كالېندار تەڭشىكى",
    "At event start" : "پائالىيەت باشلانغاندا",
    "No reminder" : "ئەسكەرتىش يوق",
    "Failed to save default calendar" : "سۈكۈتتىكى كالېندارنى ساقلىيالمىدى",
    "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
    "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "Appointment schedule successfully created" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك قۇرۇلدى",
    "Appointment schedule successfully updated" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك يېڭىلاندى",
    "0 minutes" : "0 مىنۇت",
    "To configure appointments, add your email address in personal settings." : "ئۇچرىشىشنى تەڭشەش ئۈچۈن ئېلېكترونلۇق خەت ئادرېسىڭىزنى شەخسىي تەڭشەكلەرگە قوشۇڭ.",
    "Public – shown on the profile page" : "ئاممىۋى - ئارخىپ بېتىدە كۆرسىتىلدى",
    "Private – only accessible via secret link" : "شەخسىي - پەقەت مەخپىي ئۇلىنىش ئارقىلىقلا زىيارەت قىلغىلى بولىدۇ",
    "Appointment name" : "تەيىنلەش ئىسمى",
    "Location" : "ئورنى",
    "Create a Talk room" : "پاراڭلىشىش ئۆيى قۇرۇش",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "ھەر بىر زاكاس قىلىنغان ئۇچرىشىشتا ئۆزگىچە ئۇلىنىش ھاسىل قىلىنىدۇ ۋە جەزملەشتۈرۈش ئېلخېتى ئارقىلىق ئەۋەتىلىدۇ",
    "Description" : "چۈشەندۈرۈش",
    "Visibility" : "كۆرۈنۈشچانلىقى",
    "Duration" : "Duration",
    "Increments" : "كۆپەيتىش",
    "Additional calendars to check for conflicts" : "زىددىيەتلەرنى تەكشۈرۈش ئۈچۈن قوشۇمچە كالېندار",
    "Pick time ranges where appointments are allowed" : "ئۇچرىشىشقا رۇخسەت قىلىنغان ۋاقىت دائىرىسىنى تاللاڭ",
    "to" : "to",
    "Delete slot" : "ئورۇننى ئۆچۈرۈڭ",
    "No times set" : "ۋاقىت بەلگىلەنمىدى",
    "Add" : "قوش",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sunday" : "يەكشەنبە",
    "Weekdays" : "ھەپتە كۈنلىرى",
    "Add time before and after the event" : "پائالىيەتنىڭ ئالدى-كەينىدە ۋاقىت قوشۇڭ",
    "Before the event" : "پائالىيەتتىن ئىلگىرى",
    "After the event" : "پائالىيەتتىن كېيىن",
    "Planning restrictions" : "پىلان چەكلىمىسى",
    "Minimum time before next available slot" : "كېيىنكى ئىشلەتكىلى بولىدىغان ئورۇننىڭ ئەڭ تۆۋەن ۋاقتى",
    "Max slots per day" : "كۈنىگە ئەڭ چوڭ ئورۇن",
    "Limit how far in the future appointments can be booked" : "كەلگۈسىدىكى ئۇچرىشىشلارنىڭ قانچىلىك دەرىجىدە زاكاس قىلىنىدىغانلىقىنى چەكلەڭ",
    "It seems a rate limit has been reached. Please try again later." : "قارىماققا ئۆسۈم چېكىگە يەتكەندەك قىلىدۇ. كېيىن قايتا سىناڭ.",
    "Create appointment schedule" : "ئۇچرىشىش جەدۋىلىنى تۈزۈڭ",
    "Edit appointment schedule" : "تەيىنلەش جەدۋىلىنى تەھرىرلەڭ",
    "Update" : "يېڭىلا",
    "Please confirm your reservation" : "زاكاسلىرىڭىزنى جەزملەشتۈرۈڭ",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "بىز سىزگە تەپسىلاتلار بىلەن ئېلېكترونلۇق خەت ئەۋەتتۇق. ئېلېكترونلۇق خەتتىكى ئۇلىنىش ئارقىلىق ئۇچرىشىشىڭىزنى جەزملەشتۈرۈڭ. بۇ بەتنى ھازىر ياپالايسىز.",
    "Your name" : "ئىسمىڭىز",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Please share anything that will help prepare for our meeting" : "ئۇچرىشىشىمىزغا تەييارلىق قىلىشقا ياردىمى بولىدىغان نەرسىلەرنى ئورتاقلىشىڭ",
    "Could not book the appointment. Please try again later or contact the organizer." : "ئۇچرىشىشنى زاكاز قىلالمىدى. كېيىن قايتا سىناڭ ياكى تەشكىللىگۈچى بىلەن ئالاقىلىشىڭ.",
    "Back" : "قايتىش",
    "Reminder" : "ئەسكەرتىش",
    "before at" : "before at",
    "Notification" : "ئۇقتۇرۇش",
    "Email" : "تورخەت",
    "Audio notification" : "ئاۋازلىق ئۇقتۇرۇش",
    "Other notification" : "باشقا ئۇقتۇرۇش",
    "Relative to event" : "ۋەقەگە مۇناسىۋەتلىك",
    "On date" : "چېسلا",
    "Edit time" : "ۋاقىتنى تەھرىرلەش",
    "Save time" : "ۋاقىت تېجەڭ",
    "Remove reminder" : "ئەسكەرتىشنى ئۆچۈرۈڭ",
    "on" : "on",
    "at" : "at",
    "+ Add reminder" : "+ ئەسكەرتىش قوشۇڭ",
    "Add reminder" : "ئەسكەرتىش قوشۇڭ",
    "No attachments" : "قوشۇمچە ھۆججەت يوق",
    "Add from Files" : "ھۆججەتلەردىن قوشۇڭ",
    "Upload from device" : "ئۈسكۈنىدىن يۈكلەش",
    "Delete file" : "ھۆججەتنى ئۆچۈرۈڭ",
    "Confirmation" : "جەزملەشتۈرۈش",
    "Choose a file to add as attachment" : "قوشۇمچە قىلىپ قوشماقچى بولغان ھۆججەتنى تاللاڭ",
    "Choose a file to share as a link" : "ئۇلىنىش سۈپىتىدە ھەمبەھىرلىنىدىغان ھۆججەتنى تاللاڭ",
    "Attachment {name} already exist!" : "قوشۇمچە {name} مەۋجۇت!",
    "Could not upload attachment(s)" : "قوشۇمچە ھۆججەتلەرنى يۈكلىيەلمىدى",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "سىز {host} غا يۆتكىمەكچى بولۇۋاتىسىز. داۋاملاشتۇرامسىز؟ ئۇلىنىش: {link}",
    "Proceed" : "داۋاملاشتۇرۇڭ",
    "Invitation accepted" : "تەكلىپ قوبۇل قىلىندى",
    "Available" : "ئىشلەتكىلى بولىدۇ",
    "Suggested" : "تەكلىپ بەردى",
    "Participation marked as tentative" : "قاتنىشىش ۋاقتىنچە بەلگە قىلىندى",
    "Accepted {organizerName}'s invitation" : "{organizerName} ئىسمى} نىڭ تەكلىپىنى قوبۇل قىلدى",
    "Not available" : "ئىشلەتكىلى بولمايدۇ",
    "Invitation declined" : "تەكلىپ رەت قىلىندى",
    "Declined {organizerName}'s invitation" : "رەت قىلىنغان {organizerName} ئىسمى} نىڭ تەكلىپنامىسى",
    "Invitation is delegated" : "تەكلىپنامە ئەۋەتىلدى",
    "Checking availability" : "بار-يوقلۇقىنى تەكشۈرۈش",
    "Awaiting response" : "جاۋاب كۈتۈش",
    "Has not responded to {organizerName}'s invitation yet" : "{organizerName} نىڭ تەكلىپىگە تېخى جاۋاب بەرمىدى",
    "Availability of attendees, resources and rooms" : "قاتناشقۇچىلار ، بايلىق ۋە ياتاقلار",
    "Find a time" : "ۋاقىت تېپىڭ",
    "with" : "with",
    "Available times:" : "ئىشلەتكىلى بولىدىغان ۋاقىت:",
    "Suggestion accepted" : "تەكلىپ قوبۇل قىلىندى",
    "Done" : "تامام",
    "Select automatic slot" : "ئاپتوماتىك ئورۇننى تاللاڭ",
    "chairperson" : "رەئىس",
    "required participant" : "تەلەپچان قاتناشقۇچى",
    "non-participant" : "قاتناشمىغان",
    "optional participant" : "ئىختىيارى قاتناشقۇچى",
    "{organizer} (organizer)" : "{organizer} (تەشكىللىگۈچى)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Free" : "ھەقسىز",
    "Busy (tentative)" : "ئالدىراش (ۋاقىتلىق)",
    "Busy" : "ئالدىراش",
    "Out of office" : "ئىشخانىدىن چىقتى",
    "Unknown" : "نامەلۇم",
    "Search room" : "ئىزدەش ئۆيى",
    "Room name" : "ياتاق ئىسمى",
    "Check room availability" : "ياتاقنىڭ بار-يوقلۇقىنى تەكشۈرۈڭ",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "Tentative" : "Tentative",
    "The invitation has been accepted successfully." : "تەكلىپ مۇۋەپپەقىيەتلىك قوبۇل قىلىندى.",
    "Failed to accept the invitation." : "تەكلىپنى قوبۇل قىلالمىدى.",
    "The invitation has been declined successfully." : "تەكلىپ مۇۋەپپەقىيەتلىك رەت قىلىندى.",
    "Failed to decline the invitation." : "تەكلىپنى رەت قىلدى.",
    "Your participation has been marked as tentative." : "سىزنىڭ قاتنىشىشىڭىز ۋاقتىنچە بەلگە قىلىندى.",
    "Failed to set the participation status to tentative." : "قاتنىشىش ھالىتىنى ۋاقتىنچە بەلگىلىيەلمىدى.",
    "Attendees" : "قاتناشقۇچىلار",
    "Create Talk room for this event" : "بۇ پائالىيەت ئۈچۈن سۆھبەت ئۆيى قۇرۇش",
    "No attendees yet" : "ھازىرغىچە قاتناشقۇچىلار يوق",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} قىلىنغان سان} تەكلىپ قىلىنغان ، {confirmedCount} سان} جەزملەشتۈرۈلگەن",
    "Successfully appended link to talk room to location." : "مۇۋەپپەقىيەتلىك ھالدا پاراڭلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
    "Successfully appended link to talk room to description." : "مۇۋەپپەقىيەتلىك ھالدا سۆزلىشىش ئۆيىگە ئۇلىنىش قوشۇلدى.",
    "Error creating Talk room" : "سۆھبەت ئۆيى قۇرۇشتا خاتالىق",
    "Request reply" : "جاۋاب تەلەپ قىلىڭ",
    "Chairperson" : "رەئىس",
    "Required participant" : "تەلەپچان قاتناشقۇچى",
    "Optional participant" : "ئىختىيارى قاتناشقۇچى",
    "Non-participant" : "قاتناشمىغان",
    "Remove group" : "گۇرۇپپىنى ئۆچۈرۈڭ",
    "Remove attendee" : "قاتناشقۇچىلارنى ئېلىۋېتىڭ",
    "Search for emails, users, contacts, teams or groups" : "ئېلېكترونلۇق خەت ، ئىشلەتكۈچى ، ئالاقىداش ، گۇرۇپپا ياكى گۇرۇپپىلارنى ئىزدەڭ",
    "No match found" : "ماس كەلمىدى",
    "Note that members of circles get invited but are not synced yet." : "چەمبىرەك ئەزالىرىنىڭ تەكلىپ قىلىنغانلىقىغا دىققەت قىلىڭ ، ئەمما تېخى ماسلاشمىدى.",
    "(organizer)" : "(تەشكىللىگۈچى)",
    "Make {label} the organizer" : "{label} تەشكىللىگۈچى",
    "Make {label} the organizer and attend" : "{label} تەشكىللىگۈچى ۋە قاتنىشىڭ",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "تەكلىپنامە ئەۋەتىش ۋە جاۋابلارنى بىر تەرەپ قىلىش ئۈچۈن ، [linkopen] ئېلېكترونلۇق خەت ئادرېسىڭىزنى شەخسىي تەڭشەكلەرگە قوشۇڭ [linkclose].",
    "Remove color" : "رەڭنى ئۆچۈرۈڭ",
    "Event title" : "پائالىيەت ئىسمى",
    "From" : "From",
    "To" : "To",
    "All day" : "پۈتۈن كۈن",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "تەكرارلىنىشنىڭ بىر قىسمى بولغان ۋەقەلەرنىڭ پۈتۈن كۈنلۈك تەڭشىكىنى ئۆزگەرتەلمەيدۇ.",
    "Repeat" : "قايتىلا",
    "End repeat" : "تەكرارلاش",
    "Select to end repeat" : "تەكرارلاشنى ئاخىرلاشتۇرۇشنى تاللاڭ",
    "never" : "ھەرگىز",
    "on date" : "on date",
    "after" : "after",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "بۇ ھادىسە قايتا-قايتا تەكرارلانغاندىن باشقا. ئۇنىڭغا قايتا-قايتا قائىدە قوشالمايسىز.",
    "first" : "بىرىنچى",
    "third" : "ئۈچىنچىسى",
    "fourth" : "تۆتىنچى",
    "fifth" : "بەشىنچى",
    "second to last" : "ئىككىنچىدىن ئاخىرقىسى",
    "last" : "ئاخىرقى",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تەكرارلىنىش قائىدىسىگە ئۆزگەرتىش پەقەت مۇشۇ ۋە كەلگۈسىدىكى بارلىق ئىشلارغا ماس كېلىدۇ.",
    "Repeat every" : "ھەممىنى تەكرارلاڭ",
    "By day of the month" : "ئاينىڭ كۈنىگە قەدەر",
    "On the" : "ئۈستىدە",
    "weekday" : "ھەپتە",
    "weekend day" : "ھەپتە ئاخىرى",
    "Does not repeat" : "تەكرارلانمايدۇ",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "بۇ پائالىيەتنىڭ قايتا-قايتا ئېنىقلىنىشى Nextcloud تەرىپىدىن تولۇق قوللىمايدۇ. ئەگەر قايتا-قايتا تاللاشلارنى تەھرىرلىسىڭىز ، بەزى تەكرارلىنىشلار يوقاپ كېتىشى مۇمكىن.",
    "Suggestions" : "تەكلىپ",
    "No rooms or resources yet" : "ھازىرچە ياتاق ۋە بايلىق يوق",
    "Add resource" : "بايلىق قوشۇڭ",
    "Has a projector" : "بىر پروجېكتور بار",
    "Has a whiteboard" : "ئاق دوسكىسى بار",
    "Wheelchair accessible" : "چاقلىق ئورۇندۇقنى زىيارەت قىلغىلى بولىدۇ",
    "Remove resource" : "مەنبەنى ئۆچۈرۈڭ",
    "Show all rooms" : "بارلىق ئۆيلەرنى كۆرسەت",
    "Projector" : "Projector",
    "Whiteboard" : "ئاق دوسكا",
    "Search for resources or rooms" : "بايلىق ياكى ئۆي ئىزدەڭ",
    "available" : "ئىشلەتكىلى بولىدۇ",
    "unavailable" : "ئىشلەتكىلى بولمايدۇ",
    "Room type" : "ياتاق تىپى",
    "Any" : "ھەر قانداق",
    "Minimum seating capacity" : "ئەڭ تۆۋەن ئولتۇرۇش ئىقتىدارى",
    "More details" : "تېخىمۇ كۆپ تەپسىلاتلار",
    "Update this and all future" : "بۇنى ۋە كەلگۈسىنى يېڭىلاڭ",
    "Update this occurrence" : "بۇ ھادىسىنى يېڭىلاڭ",
    "Public calendar does not exist" : "ئاممىۋى كالېندار مەۋجۇت ئەمەس",
    "Maybe the share was deleted or has expired?" : "بەلكىم ھەمبەھىر ئۆچۈرۈلگەن ياكى ۋاقتى توشقان بولۇشى مۇمكىن؟",
    "Select a time zone" : "ۋاقىت رايونىنى تاللاڭ",
    "Please select a time zone:" : "ۋاقىت رايونىنى تاللاڭ:",
    "Pick a time" : "ۋاقىت تاللاڭ",
    "Pick a date" : "چېسلا تاللاڭ",
    "from {formattedDate}" : "from {formattedDate}",
    "to {formattedDate}" : "to {formattedDate}",
    "on {formattedDate}" : "on {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "{formattedDate} ۋاقىت} دىن {formattedTime} ۋاقىت} دىن",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} ۋاقىت} دىكى {formattedTime} ۋاقىت}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} ۋاقىت} دىكى {formattedTime} ۋاقىت}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} at {formattedTime}",
    "Please enter a valid date" : "ئىناۋەتلىك چېسلانى كىرگۈزۈڭ",
    "Please enter a valid date and time" : "ئىناۋەتلىك چېسلا ۋە ۋاقىتنى كىرگۈزۈڭ",
    "Type to search time zone" : "ئىزدەش ۋاقىت رايونىغا كىرگۈزۈڭ",
    "Global" : "Global",
    "Public holiday calendars" : "ئاممىۋى دەم ئېلىش كالېندارى",
    "Public calendars" : "ئاممىۋى كالېندار",
    "No valid public calendars configured" : "ئىناۋەتلىك ئاممىۋى كالېندار سەپلەنمىدى",
    "Speak to the server administrator to resolve this issue." : "بۇ مەسىلىنى ھەل قىلىش ئۈچۈن مۇلازىمېتىر باشقۇرغۇچىغا سۆزلەڭ.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "ئاممىۋى دەم ئېلىش كالېندارىنى Thunderbird تەمىنلەيدۇ. كالېندار سانلىق مەلۇماتلىرى {website} بېكىتى} دىن چۈشۈرۈلىدۇ",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "بۇ ئاممىۋى كالېندارلارنى كەسمە باشقۇرغۇچى تەۋسىيە قىلىدۇ. كالېندار سانلىق مەلۇماتلىرى مۇناسىۋەتلىك تور بەتتىن چۈشۈرۈلىدۇ.",
    "By {authors}" : "{authors}",
    "Subscribed" : "مۇشتەرى بولدى",
    "Subscribe" : "مۇشتەرى بولۇش",
    "Holidays in {region}" : "{region} دەم ئېلىش}",
    "An error occurred, unable to read public calendars." : "ئاممىۋى كالېندارنى ئوقۇيالماي خاتالىق كۆرۈلدى.",
    "An error occurred, unable to subscribe to calendar." : "كالېندارغا مۇشتەرى بولالمىغان خاتالىق كۆرۈلدى.",
    "Select a date" : "چېسلانى تاللاڭ",
    "Select slot" : "ئورۇننى تاللاڭ",
    "No slots available" : "ئورۇن يوق",
    "Could not fetch slots" : "ئورۇن ئالالمىدى",
    "The slot for your appointment has been confirmed" : "سىزنىڭ ۋەزىپىگە تەيىنلەنگەنلىكىڭىز جەزملەشتۈرۈلدى",
    "Appointment Details:" : "تەيىنلەش تەپسىلاتى:",
    "Time:" : "ۋاقىت:",
    "Booked for:" : "زاكاز قىلىندى:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "رەھمەت سىزگە. سىزنىڭ {startDate} دىن {endDate} گىچە زاكاس قىلىشىڭىز جەزملەشتۈرۈلدى.",
    "Book another appointment:" : "باشقا ئۇچرىشىشنى زاكاز قىلىڭ:",
    "See all available slots" : "بارلىق ئورۇنلارنى كۆرۈڭ",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "سىزنىڭ ئۇچرىشىشىڭىزنىڭ {startDate} دىن {endDate} غىچە بولغان ئورنى ئەمدى يوق.",
    "Please book a different slot:" : "باشقا بىر كىتابنى زاكاز قىلىڭ:",
    "Book an appointment with {name}" : "{name} بىلەن ئۇچرىشىشنى زاكاز قىلىڭ",
    "No public appointments found for {name}" : "{name} ئۈچۈن ئاممىۋى ئۇچرىشىش تېپىلمىدى",
    "Personal" : "شەخسىي",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "ئاپتوماتىك ۋاقىت رايونىنى تەكشۈرۈش سىزنىڭ ۋاقىت رايونىڭىزنىڭ UTC ئىكەنلىكىنى بەلگىلىدى.\nبۇ بەلكىم توركۆرگۈڭىزنىڭ بىخەتەرلىك تەدبىرلىرىنىڭ نەتىجىسى بولۇشى مۇمكىن.\nۋاقىت رايونىنى كالېندار تەڭشىكىدە قولدا تەڭشەڭ.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "تەڭشەلگەن ۋاقىت رايونىڭىز ({timezoneId}) تېپىلمىدى. UTC غا قايتىش.\nتەڭشەكتىكى ۋاقىت رايونىڭىزنى ئۆزگەرتىپ بۇ مەسىلىنى دوكلات قىلىڭ.",
    "Event does not exist" : "ھادىسە مەۋجۇت ئەمەس",
    "Duplicate" : "كۆپەيتىلگەن",
    "Delete this occurrence" : "بۇ ھادىسىنى ئۆچۈرۈڭ",
    "Delete this and all future" : "بۇنى ۋە كەلگۈسىنى ئۆچۈرۈڭ",
    "Details" : "تەپسىلاتى",
    "Managing shared access" : "ئورتاق زىيارەتنى باشقۇرۇش",
    "Deny access" : "زىيارەتنى رەت قىلىش",
    "Invite" : "تەكلىپ قىلىڭ",
    "Resources" : "بايلىق",
    "Close" : "ياپ",
    "Untitled event" : "نامسىز ھادىسە",
    "Subscribe to {name}" : "{name} غا مۇشتەرى بولۇڭ",
    "Export {name}" : "چىقىرىش {name}",
    "Anniversary" : "يىللىق خاتىرە كۈنى",
    "Appointment" : "تەيىنلەش",
    "Business" : "سودا",
    "Education" : "مائارىپ",
    "Holiday" : "دەم ئېلىش",
    "Meeting" : "يىغىن",
    "Miscellaneous" : "ھەرخىل",
    "Non-working hours" : "خىزمەت ۋاقتى يوق",
    "Not in office" : "ئىشخانىدا ئەمەس",
    "Phone call" : "تېلېفون",
    "Sick day" : "كېسەل كۈنى",
    "Special occasion" : "ئالاھىدە سورۇن",
    "Travel" : "ساياھەت",
    "Vacation" : "دەم ئېلىش",
    "Midnight on the day the event starts" : "پائالىيەت باشلانغان كۈنى يېرىم كېچىدە",
    "on the day of the event at {formattedHourMinute}" : "پائالىيەت كۈنى {formattedHourMinute} HourMinute} دىكى",
    "at the event's start" : "پائالىيەت باشلانغاندا",
    "at the event's end" : "پائالىيەت ئاخىرلاشقاندا",
    "{time} before the event starts" : "پائالىيەت باشلىنىشتىن بۇرۇن {time}",
    "{time} before the event ends" : "پائالىيەت ئاخىرلىشىشتىن بۇرۇن {time}",
    "{time} after the event starts" : "پائالىيەت باشلانغاندىن كېيىن {time}",
    "{time} after the event ends" : "پائالىيەت ئاخىرلاشقاندىن كېيىن {time}",
    "on {time}" : "on {time}",
    "on {time} ({timezoneId})" : "on {time} ({timezoneId})",
    "Week {number} of {year}" : "ھەپتە {سان} يىل}",
    "Daily" : "كۈندىلىك",
    "Weekly" : "ھەپتىلىك",
    "Monthly" : "ئايلىق",
    "Yearly" : "يىللىق",
    "on the {ordinalNumber} {byDaySet}" : "on {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "in nameNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames} دا {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "تاكى DateDate}",
    "Untitled task" : "نامسىز ۋەزىپە",
    "Please ask your administrator to enable the Tasks App." : "باشقۇرغۇچىدىن ۋەزىپە ئەپىنى قوزغىتىشنى تەلەپ قىلىڭ.",
    "W" : "W.",
    "%n more" : "% n تېخىمۇ كۆپ",
    "No events to display" : "كۆرسىتىدىغان ھېچقانداق ھادىسە يوق",
    "No events" : "ھېچقانداق ۋەقە يوق",
    "Create a new event or change the visible time-range" : "يېڭى ھادىسە قۇرۇڭ ياكى كۆرۈنگەن ۋاقىت دائىرىسىنى ئۆزگەرتىڭ",
    "Failed to save event" : "پائالىيەتنى ساقلىيالمىدى",
    "It might have been deleted, or there was a typo in a link" : "ئۇ ئۆچۈرۈلگەن بولۇشى مۇمكىن ، ياكى ئۇلىنىشتا خاتالىق بار",
    "It might have been deleted, or there was a typo in the link" : "ئۇ ئۆچۈرۈلگەن بولۇشى مۇمكىن ، ياكى ئۇلىنىشتا خاتالىق بار",
    "Meeting room" : "يىغىن زالى",
    "Lecture hall" : "لېكسىيە زالى",
    "Seminar room" : "مۇھاكىمە ئۆيى",
    "Other" : "باشقا",
    "When shared show" : "ھەمبەھىرلەنگەندە",
    "When shared show full event" : "ھەمبەھىرلەنگەندە تولۇق پائالىيەتنى كۆرسىتىدۇ",
    "When shared show only busy" : "ئورتاقلاشقاندا پەقەت ئالدىراش",
    "When shared hide this event" : "ئورتاقلاشقاندا بۇ پائالىيەتنى يوشۇرۇڭ",
    "The visibility of this event in shared calendars." : "ئورتاق كالېنداردا بۇ پائالىيەتنىڭ كۆرۈنۈشچانلىقى.",
    "Add a location" : "ئورۇن قوشۇڭ",
    "Add a description" : "چۈشەندۈرۈش قوشۇڭ",
    "Status" : "ھالەت",
    "Confirmed" : "جەزملەشتۈرۈلدى",
    "Canceled" : "ئەمەلدىن قالدۇرۇلدى",
    "Confirmation about the overall status of the event." : "پائالىيەتنىڭ ئومۇمىي ئەھۋالى توغرىسىدىكى جەزملەشتۈرۈش.",
    "Show as" : "كۆرسەت",
    "Take this event into account when calculating free-busy information." : "ھەقسىز ئالدىراش ئۇچۇرلارنى ھېسابلىغاندا بۇ پائالىيەتنى ئويلاڭ.",
    "Categories" : "سەھىپىلەر",
    "Categories help you to structure and organize your events." : "سەھىپىلەر سىزنىڭ پائالىيەتلىرىڭىزنى تەشكىللىشىڭىز ۋە تەشكىللىشىڭىزگە ياردەم بېرىدۇ.",
    "Search or add categories" : "تۈرلەرنى ئىزدەڭ ياكى قوشۇڭ",
    "Add this as a new category" : "بۇنى يېڭى سەھىپە قىلىپ قوشۇڭ",
    "Custom color" : "ئىختىيارى رەڭ",
    "Special color of this event. Overrides the calendar-color." : "بۇ پائالىيەتنىڭ ئالاھىدە رەڭگى. كالېندار-رەڭنى قاپلايدۇ.",
    "Error while sharing file" : "ھۆججەتنى ھەمبەھىرلەشتە خاتالىق",
    "Error while sharing file with user" : "ئىشلەتكۈچى بىلەن ھۆججەتنى ھەمبەھىرلەشتە خاتالىق",
    "Attachment {fileName} already exists!" : "قوشۇمچە ھۆججەت {fileName} مەۋجۇت!",
    "An error occurred during getting file information" : "ھۆججەت ئۇچۇرىغا ئېرىشىش جەريانىدا خاتالىق كۆرۈلدى",
    "Chat room for event" : "پائالىيەت ئۈچۈن پاراڭلىشىش ئۆيى",
    "An error occurred, unable to delete the calendar." : "كالېندارنى ئۆچۈرەلمەي خاتالىق كۆرۈلدى.",
    "Imported {filename}" : "ئىمپورت قىلىنغان {filename} ئىسمى}",
    "This is an event reminder." : "بۇ بىر ۋەقە ئەسكەرتىش.",
    "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
    "Appointment not found" : "تەيىنلەنمىدى",
    "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
    "Book the appointment" : "ئۇچرىشىشنى زاكاس قىلىڭ",
    "Select date" : "چېسلانى تاللاڭ",
    "[Today]" : "[بۈگۈن]",
    "[Tomorrow]" : "[ئەتە]",
    "[Yesterday]" : "[تۈنۈگۈن]"
},
"nplurals=2; plural=(n != 1);");
