OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "Указанный адрес электронной почты слишком длинный",
    "User-Session unexpectedly expired" : "Сеанс работы пользователя неожиданно завершён",
    "Provided email-address is not valid" : "Указанный адрес электронной почты недействителен",
    "%s has published the calendar »%s«" : "%s опубликовал календарь «%s»",
    "Unexpected error sending email. Please contact your administrator." : "Неожиданная ошибка отправки электронной почты. Сообщите об этом  администратору.",
    "Successfully sent email to %1$s" : "Письмо успешно отправлено по адресу %1$s",
    "Hello," : "Здравствуйте,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Хотим сообщить, что %s опубликовал(а) календарь «%s».",
    "Open »%s«" : "Открыть «%s»",
    "Cheers!" : "Удачи!",
    "Upcoming events" : "Приближающиеся события",
    "No more events today" : "На сегодня больше нет событий",
    "No upcoming events" : "Приближающиеся события отсуствуют",
    "More events" : "Следующие события",
    "%1$s with %2$s" : "%1$s с %2$s",
    "Calendar" : "Календарь",
    "New booking {booking}" : "Новое бронирование {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) заборонировал(а) встречу \"{config_display_name}\"  на {date_time}.",
    "Appointments" : "Мероприятия",
    "Schedule appointment \"%s\"" : "Запланировать встречу «%s»",
    "Schedule an appointment" : "Запланировать встречу",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Подготовиться к %s",
    "Follow up for %s" : "Последующие действия для %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Ваша встреча «%s» с %s требует подтверждения",
    "Dear %s, please confirm your booking" : "Уважаемый %s, подтвердите своё бронирование",
    "Confirm" : "Подтвердить",
    "Appointment with:" : "Встреча с:",
    "Description:" : "Описание:",
    "This confirmation link expires in %s hours." : "Срок действия этой ссылки для подтверждения истекает через %s часов.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Если вы всё равно хотите отменить встречу, свяжитесь с её организатором, ответив на это письмо или перейдите на страницу, указанную в профиле.",
    "Your appointment \"%s\" with %s has been accepted" : "Ваша встреча «%s» с %s была подтверждена",
    "Dear %s, your booking has been accepted." : "Уважаемый(-ая) %s, ваше бронирование было подтверждено.",
    "Appointment for:" : "Встреча с:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Вы получите ссылку с подтверждением по электронной почте",
    "Where:" : "Место:",
    "Comment:" : "Комментарий:",
    "You have a new appointment booking \"%s\" from %s" : "У вас новое бронирование встречи «%s» от %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Уважаемый(-ая) %s, %s (%s) забронировал(а) встречу с вами.",
    "A Calendar app for Nextcloud" : "Приложение Календарь для Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **We’re not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Приложение «Календарь» обеспечивает работу с календарями с использованием протокола CalDAV. Сервер Nextcloud позволяет синхронизировать  календарей между различными устройствами, а это приложение служит для работы из браузера. \n\n*🚀 **Интеграция с другими приложениями Nextcloud** В настоящее время поддерживается интеграция с приложением Контакты, готовится интеграция с другими приложениями;\n* 🌐 **Поддержка протокола WebCal** Возможно настроить синхронизацию и показ дней игр своей любимой команды в календаре;\n* 🙋 **Отправка приглашений участникам** Пригласите участников на свои мероприятия;\n* ⌚️ **Поддержка статусов занятого и свободного времени** позволяет назначать встречи в удобное время\n* ⏰ **Напоминания** Получение уведомлений в браузере и по электронной почте\n* 🔍 **Поиск** позволяет находить нужные события \n* ☑️  **Задачи** просмотр задач с датой выполнения прямо в календаре\n* 🙈 **Мы не изобретаем колесо** Приложение основано на отличных библиотеках [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) и [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Previous day" : "Предыдущий день",
    "Previous week" : "Предыдущая неделя",
    "Previous year" : "Предыдущий год",
    "Previous month" : "Предыдущий месяц",
    "Next day" : "Следующий день",
    "Next week" : "Следующая неделя",
    "Next year" : "Следующий год",
    "Next month" : "Следующий месяц",
    "Event" : "Событие",
    "Create new event" : "Создать событие",
    "Today" : "Сегодня",
    "Day" : "День",
    "Week" : "Неделя",
    "Month" : "Месяц",
    "Year" : "Год",
    "List" : "Список",
    "Preview" : "Предварительный просмотр",
    "Copy link" : "Копировать ссылку",
    "Edit" : "Редактировать",
    "Delete" : "Удалить",
    "Appointment link was copied to clipboard" : "Ссылка на эту встречу скопирована в буфер обмена",
    "Appointment link could not be copied to clipboard" : "Не удалось скопировать в буфер обмена ссылку на эту встречу",
    "Appointment schedules" : "Расписание встреч",
    "Create new" : "Создать",
    "Untitled calendar" : "Календарь без названия",
    "Shared with you by" : "Получено от",
    "Edit and share calendar" : "Редактировать и делиться календарем",
    "Edit calendar" : "Редактировать календарь",
    "Disable calendar \"{calendar}\"" : "Отключить календарь \"{calendar}\"",
    "Disable untitled calendar" : "Отключить безымянный календарь",
    "Enable calendar \"{calendar}\"" : "Включить календарь \"{calendar}\"",
    "Enable untitled calendar" : "Включить безымянный календарь",
    "An error occurred, unable to change visibility of the calendar." : "Произошла ошибка, не удалось изменить видимость календаря.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Закрытие общего доступа к календарю через {countdown} секунду","Закрытие общего доступа к календарю через {countdown} секунды","Закрытие общего доступа к календарю через {countdown} секунд","Закрытие общего доступа к календарю через {countdown} секунд"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календарь будет удалён через {countdown} секунду","Календарь будет удалён через {countdown} секунды","Календарь будет удалён через {countdown} секунд","Календарь будет удалён через {countdown} секунды"],
    "Calendars" : "Календари",
    "Add new" : "Добавить новое",
    "New calendar" : "Новый календарь",
    "Name for new calendar" : "Имя для нового календаря",
    "Creating calendar …" : "Создание календаря…",
    "New calendar with task list" : "Создать календарь со списком задач",
    "New subscription from link (read-only)" : "Создать подписку по ссылке (только чтение)",
    "Creating subscription …" : "Создание подписки…",
    "Add public holiday calendar" : "Добавить общий календарь праздников",
    "Add custom public calendar" : "Добавить собственный открытый календарь",
    "An error occurred, unable to create the calendar." : "Не удалось создать календарь.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Введите верный URL: адрес должен начинаться с http://, https://, webcal:// или webcals://",
    "Copy subscription link" : "Скопировать ссылку на подписку",
    "Copying link …" : "Копирование ссылки…",
    "Copied link" : "Ссылка скопирована",
    "Could not copy link" : "Не удалось скопировать ссылку",
    "Export" : "Экспорт",
    "Calendar link copied to clipboard." : "Ссылка на календарь скопирована в буфер обмена.",
    "Calendar link could not be copied to clipboard." : "Не удалось скопировать ссылку на календарь в буфер обмена.",
    "Trash bin" : "Корзина",
    "Loading deleted items." : "Загрузка удалённых объектов…",
    "You do not have any deleted items." : "Нет ни одного удалённого объекта.",
    "Name" : "Название",
    "Deleted" : "Удалено",
    "Restore" : "Восстановить",
    "Delete permanently" : "Удалить безвозвратно",
    "Empty trash bin" : "Очистить корзину",
    "Untitled item" : "Объект без названия",
    "Unknown calendar" : "Неизвестный календарь",
    "Could not load deleted calendars and objects" : "Не удалось загрузить удалённые календари и объекты",
    "Could not restore calendar or event" : "Не удалось восстановить календарь или событие",
    "Do you really want to empty the trash bin?" : "Вы действительно хотите очистить корзину ?",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Объекты будут удалены из корзины через {numDays} день","Объекты будут удалены из корзины через {numDays} дня","Объекты будут удалены из корзины через {numDays} дней","Объекты будут удалены из корзины через {numDays} дня"],
    "Shared calendars" : "Общие календари",
    "Deck" : "Карточки",
    "Hidden" : "Скрыто",
    "Could not update calendar order." : "Не удалось обновить порядок календарей.",
    "Internal link" : "Внутренняя ссылка",
    "A private link that can be used with external clients" : "Частная ссылка, которую можно использовать с внешними клиентами",
    "Copy internal link" : "Копировать внутреннюю ссылку",
    "Share link" : "Поделиться ссылкой",
    "Copy public link" : "Скопировать общедоступную ссылку",
    "Send link to calendar via email" : "Отправить ссылку на календарь по электронной почте",
    "Enter one address" : "Введите один адрес",
    "Sending email …" : "Отправка сообщения…",
    "Copy embedding code" : "Скопировать код встраивания",
    "Copying code …" : "Копирование кода…",
    "Copied code" : "Код скопирован",
    "Could not copy code" : "Не удалось скопировать код",
    "Delete share link" : "Удалить ссылку",
    "Deleting share link …" : "Удаление ссылки доступа…",
    "An error occurred, unable to publish calendar." : "Произошла ошибка, не удалось опубликовать календарь.",
    "An error occurred, unable to send email." : "Произошла ошибка, не удалось отправить email.",
    "Embed code copied to clipboard." : "Код встравивания скопирован в буфер обмена.",
    "Embed code could not be copied to clipboard." : "Код встравивания не может быть скопирован в буфер обмена.",
    "Unpublishing calendar failed" : "Не удалось закрыть публичный доступ к календарю",
    "can edit" : "может ред.",
    "Unshare with {displayName}" : "Отменить общий доступ для {displayName}",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Team)",
    "An error occurred while unsharing the calendar." : "Произошла ошибка при закрытии общего доступа к календарю.",
    "An error occurred, unable to change the permission of the share." : "Произошла ошибка, не удалось изменить разрешения для общего ресурса.",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "Calendar name …" : "Название календаря ...",
    "Never show me as busy (set this calendar to transparent)" : "Никогда не показывать меня занятым (сделать этот календарь прозрачным)",
    "Share calendar" : "Поделиться календарем",
    "Unshare from me" : "Отписаться",
    "Save" : "Сохранить",
    "Failed to save calendar name and color" : "Не удалось сохранить имя и цвет календаря",
    "Import calendars" : "Импортировать календари",
    "Please select a calendar to import into …" : "Выберите календарь для импорта…",
    "Filename" : "Имя файла",
    "Calendar to import into" : "Календарь для импорта",
    "Cancel" : "Отмена",
    "_Import calendar_::_Import calendars_" : ["Импорт календаря","Импорт календарей","Импорт календарей","Импорт календарей"],
    "Default attachments location" : "Расположение сохранения вложений по умолчанию",
    "Select the default location for attachments" : "Выберите расположение для сохранения вложений по умолчанию",
    "Pick" : "Выбирать",
    "Invalid location selected" : "Указано недействительное расположение",
    "Attachments folder successfully saved." : "Параметры расположения вложений сохранены.",
    "Error on saving attachments folder." : "Не удалось задать папку для хранения вложений.",
    "{filename} could not be parsed" : "Не удалось проанализировать файл {filename}",
    "No valid files found, aborting import" : "Не найдено файлов верного типа, импорт отменён",
    "Import partially failed. Imported {accepted} out of {total}." : "Импорт завершен частично. Импортировано {accepted} из {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Событие импортировано","Импортировано %n события","Импортировано %n событий","Импортировано %n событий"],
    "Automatic" : "Автоматически",
    "Automatic ({detected})" : "Автоматически ({detected})",
    "New setting was not saved successfully." : "Не удалось сохранить параметры.",
    "Shortcut overview" : "Обзор ссылок",
    "or" : "или",
    "Navigation" : "Навигация",
    "Previous period" : "Предыдущий период",
    "Next period" : "Следующий период",
    "Views" : "Просмотров",
    "Day view" : "Просмотров за день",
    "Week view" : "Просмотров за неделю",
    "Month view" : "Просмотров за месяц",
    "Year view" : "Просмотр за год",
    "List view" : "Вид списком",
    "Actions" : "Действия",
    "Create event" : "Создать событие",
    "Show shortcuts" : "Показать горячие клавиши",
    "Editor" : "Редактор",
    "Close editor" : "Закрыть редактор",
    "Save edited event" : "Сохранить изменённое событие",
    "Delete edited event" : "Удалить изменённое событие",
    "Duplicate event" : "Дублировать событие",
    "Enable birthday calendar" : "Включить календарь дней рождения",
    "Show tasks in calendar" : "Показывать задачи в календаре",
    "Enable simplified editor" : "Использовать упрощённый редактор",
    "Limit the number of events displayed in the monthly view" : "Ограничьте количество событий, отображаемых в ежемесячном представлении",
    "Show weekends" : "Показывать выходные",
    "Show week numbers" : "Показывать номера недель",
    "Time increments" : "Шаг изменения времени",
    "Default calendar for incoming invitations" : "Календарь для полученных приглашений по умолчанию",
    "Default reminder" : "Напоминание по умолчанию",
    "Copy primary CalDAV address" : "Скопировать основной адрес CalDAV",
    "Copy iOS/macOS CalDAV address" : "Скопировать адрес CalDAV для iOS/macOS",
    "Personal availability settings" : "Личные настройки доступности",
    "Show keyboard shortcuts" : "Показать горячие клавиши клавиатуры",
    "Calendar settings" : "Параметры календаря",
    "At event start" : "В начале мероприятия",
    "No reminder" : "Не напоминать",
    "Failed to save default calendar" : "Не удалось задать календарь по умолчанию",
    "CalDAV link copied to clipboard." : "Ссылка CalDAV скопирована в буфер обмена.",
    "CalDAV link could not be copied to clipboard." : "Не удалось скопировать ссылку CalDAV в буфер обмена.",
    "Appointment schedule successfully created" : "Рассписание встреч создано",
    "Appointment schedule successfully updated" : "Расписание встреч обновлено",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минута","{duration} минуты","{duration} минут","{duration} минут"],
    "0 minutes" : "0 минут",
    "_{duration} hour_::_{duration} hours_" : ["{duration} час","{duration} часа","{duration} часов","{duration} часов"],
    "_{duration} day_::_{duration} days_" : ["{duration} день ","{duration} дня","{duration} дней","{duration} дней"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} неделя","{duration} недели","{duration} недель","{duration} недель"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяца","{duration} месяцев","{duration} месяцев"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} года","{duration} лет","{duration} лет"],
    "To configure appointments, add your email address in personal settings." : "Для конфигурации встреч, добавьте свой адрес электронной почты в личных настройках.",
    "Public – shown on the profile page" : "Публичный - отображается на странице профиля",
    "Private – only accessible via secret link" : "Приватный - доступен только по секретной ссылке",
    "Appointment name" : "Название встречи",
    "Location" : "Местоположение",
    "Create a Talk room" : "Создать обсуждение",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Для каждой забронированной встречи будет сгенерирована уникальная ссылка, которая будет отправлена по электронной почте с подтверждением",
    "Description" : "Описание",
    "Visibility" : "Видимость",
    "Duration" : "Продолжительность",
    "Increments" : "Повышения",
    "Additional calendars to check for conflicts" : "Дополнительные календари для проверки на наличие конфликтов",
    "Pick time ranges where appointments are allowed" : "Выберите диапазон времени, когда разрешено назначать встречи",
    "to" : "по",
    "Delete slot" : "Удалить слот",
    "No times set" : "Время не установлено",
    "Add" : "Добавить",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sunday" : "Воскресенье",
    "Weekdays" : "Дни недели",
    "Add time before and after the event" : "Добавить время до и после мероприятия",
    "Before the event" : "До начала мероприятия",
    "After the event" : "После мероприятия",
    "Planning restrictions" : "Ограничения при планировании",
    "Minimum time before next available slot" : "Минимальное время до следующего доступного слота",
    "Max slots per day" : "Максимум слотов в день",
    "Limit how far in the future appointments can be booked" : "Лимит на то, как далеко в будущем можно записываться на встречу",
    "It seems a rate limit has been reached. Please try again later." : "Похоже, был достигнут лимит скорости. Пожалуйста, повторите попытку позже.",
    "Appointment schedule saved" : "Расписание встреч сохранено",
    "Create appointment schedule" : "Создать расписание встреч",
    "Edit appointment schedule" : "Редактировать расписание",
    "Update" : "Обновить",
    "Please confirm your reservation" : "Пожалуйста, подтвердите бронирование",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Мы отправили вам электронное письмо с подробной информацией. Пожалуйста, подтвердите свою встречу, используя ссылку в письме. Теперь вы можете закрыть эту страницу.",
    "Your name" : "Ваше имя",
    "Your email address" : "Ваш адрес электронной почты",
    "Please share anything that will help prepare for our meeting" : "Пожалуйста, поделитесь с нами тем, что поможет подготовиться к нашей встрече",
    "Could not book the appointment. Please try again later or contact the organizer." : "Не удалось забронировать встречу. Пожалуйста, повторите попытку позже или свяжитесь с организатором.",
    "Back" : "Назад",
    "Book appointment" : "Записаться на прием",
    "Reminder" : "Напоминание",
    "before at" : "ранее в",
    "Notification" : "Уведомление",
    "Email" : "Эл. почта",
    "Audio notification" : "Звуковое уведомление",
    "Other notification" : "Другое уведомление",
    "Relative to event" : "Относительно события",
    "On date" : "В указанную дату",
    "Edit time" : "Редактировать время",
    "Save time" : "Сохранить время",
    "Remove reminder" : "Удалить напоминание",
    "on" : "в",
    "at" : "в",
    "+ Add reminder" : "+ Создать напоминание",
    "Add reminder" : "Добавить напоминание",
    "_second_::_seconds_" : ["секунда","секунды","секунд","секунды"],
    "_minute_::_minutes_" : ["минута","минуты","минут","минуты"],
    "_hour_::_hours_" : ["час","часа","часов","часы"],
    "_day_::_days_" : ["день","дня","дней","дни"],
    "_week_::_weeks_" : ["неделя","недель","недель","недели"],
    "No attachments" : "Нет ни одного вложения",
    "Add from Files" : "Добавить из файлов",
    "Upload from device" : "Загрузить с устройства",
    "Delete file" : "Удалить файл",
    "Confirmation" : "Подтверждение",
    "Choose a file to add as attachment" : "Выбрать файл для вложения",
    "Choose a file to share as a link" : "Выберите файл для публикации ссылкой",
    "Attachment {name} already exist!" : "Файл вложения «{name}» уже существует.",
    "Could not upload attachment(s)" : "Не удалось загрузить вложение (вложения)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Вы собираетесь перейти к {host}. Вы уверены, что будете продолжать? Ссылка: {link}",
    "Proceed" : "Перейти",
    "_{count} attachment_::_{count} attachments_" : ["{count} вложение","{count} вложения","{count} вложений","{count} вложений"],
    "Invitation accepted" : "Приглашение принято",
    "Available" : "Доступный",
    "Suggested" : "Предложенный",
    "Participation marked as tentative" : "Участие обозначено как «под вопросом»",
    "Accepted {organizerName}'s invitation" : "Принято приглашение от {organizerName}",
    "Not available" : "Не доступен",
    "Invitation declined" : "Приглашение отклонено",
    "Declined {organizerName}'s invitation" : "Отклонено приглашение от {organizerName}",
    "Invitation is delegated" : "Приглашение делегировано",
    "Checking availability" : "Проверка доступности",
    "Awaiting response" : "Ожидание ответа",
    "Has not responded to {organizerName}'s invitation yet" : "Ответ на приглашение от {organizerName} ещё не отправлен",
    "Availability of attendees, resources and rooms" : "Доступность участников, ресурсов и комнат",
    "Find a time" : "Найди время",
    "with" : "с",
    "Available times:" : "Доступные варианты:",
    "Suggestion accepted" : "Предложение принято",
    "Done" : "Выполненные",
    "Select automatic slot" : "Выбрать интервал автоматически",
    "chairperson" : "Председатель",
    "required participant" : "Обязательный участник",
    "non-participant" : "Не является участником",
    "optional participant" : "Необязательный участник",
    "{organizer} (organizer)" : "{organizer} (организатор)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Free" : "Свободен",
    "Busy (tentative)" : "Занят (под вопросом)",
    "Busy" : "Занят",
    "Out of office" : "Вне офиса",
    "Unknown" : "Неизвестно",
    "Search room" : "Поиск комнаты",
    "Room name" : "Название комнаты",
    "Check room availability" : "Проверить наличие номеров",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Tentative" : "Под вопросом",
    "The invitation has been accepted successfully." : "Приглашение принято.",
    "Failed to accept the invitation." : "Не удалось принять приглашение.",
    "The invitation has been declined successfully." : "Приглашение отклонено.",
    "Failed to decline the invitation." : "Не удалось отклонить приглашение.",
    "Your participation has been marked as tentative." : "Выше участие было обозначено как «под вопросом».",
    "Failed to set the participation status to tentative." : "Не удалось обозначить свое участие как «под вопросом».",
    "Attendees" : "Участники",
    "Create Talk room for this event" : "Создать комнату этого события в приложении «Talk»",
    "No attendees yet" : "Ещё нет участников",
    "{invitedCount} invited, {confirmedCount} confirmed" : "Приглашено: {invitedCount}, подтвердили участие: {confirmedCount}",
    "Successfully appended link to talk room to location." : "Ссылка на переговорную комнату успешно добавлена.",
    "Successfully appended link to talk room to description." : "Ссылка на комнату приложения Talk добавлена в описание.",
    "Error creating Talk room" : "Не удалось создать комнату в приложении Talk.",
    "Request reply" : "Запросить ответ",
    "Chairperson" : "Председатель",
    "Required participant" : "Обязательный участник",
    "Optional participant" : "Необязательный участник",
    "Non-participant" : "Не участвует",
    "Remove group" : "Удалить группу",
    "Remove attendee" : "Удалить участника",
    "_%n member_::_%n members_" : ["%n участник","%n участника","%n участников","%n участника"],
    "Search for emails, users, contacts, teams or groups" : "Выполняйте поиск по электронной почте, пользователям, контактам, командам или группам",
    "No match found" : "Соответствий не найдено",
    "Note that members of circles get invited but are not synced yet." : "Обратите внимание, что участники кругов получают приглашения, но еще не синхронизированы.",
    "Note that members of contact groups get invited but are not synced yet." : "Обратите внимание, что члены контактных групп приглашаются, но еще не синхронизированы.",
    "(organizer)" : "(организатор)",
    "Make {label} the organizer" : "Сделать {label} организатором",
    "Make {label} the organizer and attend" : "Сделайте {label} организатором и примите участие",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Чтобы отправлять приглашения и обрабатывать ответы, [linkopen]добавьте свой адрес электронной почты в личные настройки[linkclose].",
    "Remove color" : "Убрать отметку цветом",
    "Event title" : "Название события",
    "From" : "От",
    "To" : "Кому",
    "All day" : "Весь день",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Изменение параметра «весь день» для повторяющегося события не поддерживается.",
    "Repeat" : "Повтор",
    "End repeat" : "Прекратить повтор",
    "Select to end repeat" : "Выбрать до последнего повторения",
    "never" : "никогда",
    "on date" : "в указанную дату",
    "after" : "после",
    "_time_::_times_" : ["раз","раз","раз","раз"],
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Невозможно задать правила повторения этого события, так как оно является исключением из правил повтора исходного события.",
    "first" : "первый",
    "third" : "третий",
    "fourth" : "четвёртый",
    "fifth" : "пятый",
    "second to last" : "предпоследний",
    "last" : "последний",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Изменение правила повторения повлияет только на это и все будущие повторения события.",
    "Repeat every" : "Повторять каждые",
    "By day of the month" : "В указанные дни месяца",
    "On the" : "По",
    "_month_::_months_" : ["месяц","месяца","месяцев","месяца"],
    "_year_::_years_" : ["год","года","лет","года"],
    "weekday" : "рабочий день",
    "weekend day" : "выходной день",
    "Does not repeat" : "Не повторять",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Заданные правила повторения этого события не полностью поддерживается Nextcloud. При изменении правил, некоторые повторения могут быть потеряны.",
    "Suggestions" : "Предложения",
    "No rooms or resources yet" : "Комнаты или ресурсы пока не назначены",
    "Add resource" : "Добавить ресурс",
    "Has a projector" : "Есть проектор",
    "Has a whiteboard" : "Имеет доску для записей",
    "Wheelchair accessible" : "Доступно для кресла-коляски",
    "Remove resource" : "Удалить ресурс",
    "Show all rooms" : "Показать все комнаты",
    "Projector" : "Проектор",
    "Whiteboard" : "Доска",
    "Search for resources or rooms" : "Поиск ресурсов или помещений",
    "available" : "доступный",
    "unavailable" : "недоступен",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} место","{seatingCapacity} места","{seatingCapacity} мест","{seatingCapacity} мест"],
    "Room type" : "Тип комнаты",
    "Any" : "Любой",
    "Minimum seating capacity" : "Минимальная вместимость",
    "More details" : "Подробнее",
    "Update this and all future" : "Обновить это и все будущие повторния",
    "Update this occurrence" : "Обновить это повторение",
    "Public calendar does not exist" : "Общедоступный календарь не существует",
    "Maybe the share was deleted or has expired?" : "Возможно общий ресурс был удалён или истёк срок действия доступа.",
    "Select a time zone" : "Выберите часовой пояс",
    "Please select a time zone:" : "Выберите часовой пояс:",
    "Pick a time" : "Выберите время",
    "Pick a date" : "Выберите дату",
    "from {formattedDate}" : "с {formattedDate}",
    "to {formattedDate}" : "по {formattedDate}",
    "on {formattedDate}" : " {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "с {formattedDate} в {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} в {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} в {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} в {formattedTime}",
    "Please enter a valid date" : "Введите верную дату",
    "Please enter a valid date and time" : "Введите верную дату и время",
    "Type to search time zone" : "Начните вводить название часового поиска",
    "Global" : "Общие",
    "Public holiday calendars" : "Общие календари праздников",
    "Public calendars" : "Публичные календари",
    "No valid public calendars configured" : "Не настроено ни одного допустимого публичного календаря.",
    "Speak to the server administrator to resolve this issue." : "Обратитесь к администратору сервера для решения этой проблемы.",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Общие календари праздников предоставляются Thunderbird. Данные календаря будут загружены с {website}",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Эти публичные календари предлагаются администратором сервера. Данные календаря будут загружены с соответствующего веб-сайта.",
    "By {authors}" : "{authors}",
    "Subscribed" : "Подписано",
    "Subscribe" : "Подписаться",
    "Holidays in {region}" : "Праздники в {region}",
    "An error occurred, unable to read public calendars." : "Произошла ошибка, невозможно прочитать публичные календари.",
    "An error occurred, unable to subscribe to calendar." : "Произошла ошибка, не удалось подписаться на календарь.",
    "Select a date" : "Выберите дату",
    "Select slot" : "Выбрать слот",
    "No slots available" : "Нет свободных мест",
    "Could not fetch slots" : "Не удалось получить слоты",
    "The slot for your appointment has been confirmed" : "Время вашей встречи было подтверждено",
    "Appointment Details:" : "Детали встречи:",
    "Time:" : "Время:",
    "Booked for:" : "Забронировано для:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Спасибо. Ваше бронирование с {startDate} по {endDate} подтверждено.",
    "Book another appointment:" : "Записаться на другую встречу:",
    "See all available slots" : "Посмотреть все доступные слоты",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Слот для вашей встречи с {startDate} по {endDate} больше не доступен.",
    "Please book a different slot:" : "Пожалуйста, забронируйте другое время:",
    "Book an appointment with {name}" : "Записаться на встречу к {name}",
    "No public appointments found for {name}" : "Не найдено ни одной публичной встречи для {name}",
    "Personal" : "Личный",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматическое определение часового пояса определило ваш часовой пояс как UTC. Скорее всего, это результат мер безопасности вашего веб-браузера. Пожалуйста, установите часовой пояс вручную в настройках календаря.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Настроенный вами часовой пояс ({timezoneId}) не найден. Возвращение к UTC. Пожалуйста, измените свой часовой пояс в настройках и сообщите об этой проблеме.",
    "Event does not exist" : "Событие не существует",
    "Duplicate" : "Дублировать",
    "Delete this occurrence" : "Удалить это повторение",
    "Delete this and all future" : "Удалить это и все будущие повторения",
    "Details" : "Подробности",
    "Managing shared access" : "Управление общим доступом ",
    "Deny access" : "Закрыть доступ",
    "Invite" : "Приглашение",
    "Resources" : "Ресурсы",
    "_User requires access to your file_::_Users require access to your file_" : ["Пользователю требуется доступ к вашему файлу","Пользователям требуется доступ к вашему файлу","Пользователям требуется доступ к вашему файлу","Пользователям требуется доступ к вашему файлу"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Вложение, требующие общего доступа","Вложения, требующие общего доступа","Вложения, требующие общего доступа","Вложения, требующие общего доступа"],
    "Close" : "Закрыть",
    "Untitled event" : "Событие без названия",
    "Subscribe to {name}" : "Подписаться на {name}",
    "Export {name}" : "Экспортировать {name}",
    "Anniversary" : "Годовщина",
    "Appointment" : "Встреча",
    "Business" : "Работа",
    "Education" : "Образование",
    "Holiday" : "Отпуск",
    "Meeting" : "Встреча",
    "Miscellaneous" : "Разное",
    "Non-working hours" : "Не рабочие часы",
    "Not in office" : "Не в офисе",
    "Phone call" : "Телефонный звонок",
    "Sick day" : "Больничный",
    "Special occasion" : "Особый случай",
    "Travel" : "Путешествие",
    "Vacation" : "Отпуск",
    "Midnight on the day the event starts" : "Полночь в день начала мероприятия",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n день до мероприятия в {formattedHourMinute}","%n дня до мероприятия в {formattedHourMinute}","%n дней до мероприятия в {formattedHourMinute}","%nдней до мероприятия в {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n неделя до мероприятия в {formattedHourMinute}","%n недели до мероприятия в {formattedHourMinute}","%n недель до мероприятия в {formattedHourMinute}","%n недель до мероприятия в {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "в день мероприятия в {formattedHourMinute}",
    "at the event's start" : "во время начала события",
    "at the event's end" : "во время окончания события",
    "{time} before the event starts" : "{time} до времени начала события",
    "{time} before the event ends" : "{time} до времени окончания события",
    "{time} after the event starts" : "{time} после времени начала события",
    "{time} after the event ends" : "{time} до времени окончания события",
    "on {time}" : "в {time}",
    "on {time} ({timezoneId})" : "в {time} ({timezoneId})",
    "Week {number} of {year}" : "{number} неделя {year} года",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Monthly" : "Ежемесячно",
    "Yearly" : "Ежегодно",
    "_Every %n day_::_Every %n days_" : ["Каждый %n день","Каждые %n дня","Каждые %n дней","Каждые %n дня"],
    "_Every %n week_::_Every %n weeks_" : ["Каждую %n неделю","Каждые %n недели","Каждые %n недель","Каждые %n недели"],
    "_Every %n month_::_Every %n months_" : ["Каждый %n месяц","Каждые %n месяца","Каждый %n месяцев","Каждые %n месяца"],
    "_Every %n year_::_Every %n years_" : ["Каждый %n год","Каждые %n года","Каждые %n лет","Каждые %n года"],
    "_on {weekday}_::_on {weekdays}_" : ["по {weekday}","по {weekday}","по {weekday}","по {weekday}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : [" {dayOfMonthList}"," {dayOfMonthList}"," {dayOfMonthList}"," {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "по {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "по {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "в {monthNames} по {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n раз","%n раза","%n раз","%n раза"],
    "Untitled task" : "Задача без названия",
    "Please ask your administrator to enable the Tasks App." : "Попросите администратора сервера активировать приложение «Задачи».",
    "W" : "Н",
    "%n more" : "и ещё %n",
    "No events to display" : "Отсутствуют события для показа",
    "_+%n more_::_+%n more_" : ["+ ещё %n","+ ещё %n","+ ещё %n","+ ещё %n"],
    "No events" : "Нет ни одного события",
    "Create a new event or change the visible time-range" : "Создать событие или изменить интервал видимости",
    "Failed to save event" : "Не удалось сохранить событие",
    "It might have been deleted, or there was a typo in a link" : "Возможно, оно было удалено или вы выполнили переход по неверной ссылке",
    "It might have been deleted, or there was a typo in the link" : "Возможно, оно было удалено или вы выполнили переход по неверной ссылке",
    "Meeting room" : "Комната для переговоров",
    "Lecture hall" : "Лекционный зал",
    "Seminar room" : "Комната для семинаров",
    "Other" : "Другое",
    "When shared show" : "Показывать при публикации",
    "When shared show full event" : "Показывать подробно при публикации",
    "When shared show only busy" : "Показывать только занятость при публикации",
    "When shared hide this event" : "Скрыть это событие при публикации",
    "The visibility of this event in shared calendars." : "Видимость этого события в опубликованных календарях. ",
    "Add a location" : "Добавить местоположение",
    "Add a description" : "Добавить описание",
    "Status" : "Состояние",
    "Confirmed" : "Подтверждено",
    "Canceled" : "Отменена",
    "Confirmation about the overall status of the event." : "Подтверждение об общем статусе события.",
    "Show as" : "Показать как",
    "Take this event into account when calculating free-busy information." : "Учитывать это событие при учёте свободного времени.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категории позволяют структурировать и упорядочивать свои события.",
    "Search or add categories" : "Поиск и добавление категорий",
    "Add this as a new category" : "Добавить как новую категорию",
    "Custom color" : "Свой цвет",
    "Special color of this event. Overrides the calendar-color." : "Задать свой цвет события, отличающийся от цвета календаря",
    "Error while sharing file" : "Ошибка сохранения файла",
    "Error while sharing file with user" : "Ошибка при обмене файлом с пользователем",
    "Attachment {fileName} already exists!" : "Вложение {fileName} уже существует!",
    "An error occurred during getting file information" : "Произошла ошибка при получении информации о файле",
    "Chat room for event" : "Комната в приложении Talk для этого события",
    "An error occurred, unable to delete the calendar." : "Произошла ошибка, не удалось удалить календарь.",
    "Imported {filename}" : "Файл {filename} импортирован",
    "This is an event reminder." : "Это напоминание о событии.",
    "Error while parsing a PROPFIND error" : "Ошибка при анализе ошибки PROPFIND",
    "Appointment not found" : "Встреча не найдена",
    "User not found" : "Пользователь не найден",
    "Default calendar for invitations and new events" : "Календарь по умолчанию для приглашений и новых событий",
    "Appointment was created successfully" : "Встреча была создана успешно",
    "Appointment was updated successfully" : "Встреча была успешно обновлена",
    "Create appointment" : "Создать мероприятие",
    "Edit appointment" : "Редактировать встречу",
    "Book the appointment" : "Записаться на встречу",
    "You do not own this calendar, so you cannot add attendees to this event" : "Вы не являетесь владельцем этого календаря, поэтому вы не можете добавлять участников на это мероприятие",
    "Search for emails, users, contacts or groups" : "Поиск адресов эл.почты, пользователей, контактов и групп",
    "Select date" : "Выбрать дату",
    "Create a new event" : "Создать событие",
    "[Today]" : "[Сегодня]",
    "[Tomorrow]" : "[Завтра]",
    "[Yesterday]" : "[Вчера]",
    "[Last] dddd" : "[Last] dddd"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
